# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/msg/textual/v1/textual.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/msg/textual/v1/textual.proto\x12\x15\x63osmos.msg.textual.v1\x1a google/protobuf/descriptor.proto:X\n\x16\x65xpert_custom_renderer\x12\x1f.google.protobuf.MessageOptions\x18\xf9\x8c\xa6\x05 \x01(\tR\x14\x65xpertCustomRendererB\xa0\x01\n\x19\x63om.cosmos.msg.textual.v1B\x0cTextualProtoP\x01\xa2\x02\x03\x43MT\xaa\x02\x15\x43osmos.Msg.Textual.V1\xca\x02\x15\x43osmos\\Msg\\Textual\\V1\xe2\x02!Cosmos\\Msg\\Textual\\V1\\GPBMetadata\xea\x02\x18\x43osmos::Msg::Textual::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.msg.textual.v1.textual_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.cosmos.msg.textual.v1B\014TextualProtoP\001\242\002\003CMT\252\002\025Cosmos.Msg.Textual.V1\312\002\025Cosmos\\Msg\\Textual\\V1\342\002!Cosmos\\Msg\\Textual\\V1\\GPBMetadata\352\002\030Cosmos::Msg::Textual::V1'
# @@protoc_insertion_point(module_scope)
