# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/erc20/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.erc20.v1beta1 import params_pb2 as injective_dot_erc20_dot_v1beta1_dot_params__pb2
from pyinjective.proto.injective.erc20.v1beta1 import erc20_pb2 as injective_dot_erc20_dot_v1beta1_dot_erc20__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%injective/erc20/v1beta1/genesis.proto\x12\x17injective.erc20.v1beta1\x1a\x14gogoproto/gogo.proto\x1a$injective/erc20/v1beta1/params.proto\x1a#injective/erc20/v1beta1/erc20.proto\"\x98\x01\n\x0cGenesisState\x12=\n\x06params\x18\x01 \x01(\x0b\x32\x1f.injective.erc20.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\x12I\n\x0btoken_pairs\x18\x02 \x03(\x0b\x32\".injective.erc20.v1beta1.TokenPairB\x04\xc8\xde\x1f\x00R\ntokenPairsB\xf6\x01\n\x1b\x63om.injective.erc20.v1beta1B\x0cGenesisProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/erc20/types\xa2\x02\x03IEX\xaa\x02\x17Injective.Erc20.V1beta1\xca\x02\x17Injective\\Erc20\\V1beta1\xe2\x02#Injective\\Erc20\\V1beta1\\GPBMetadata\xea\x02\x19Injective::Erc20::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.erc20.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.injective.erc20.v1beta1B\014GenesisProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/erc20/types\242\002\003IEX\252\002\027Injective.Erc20.V1beta1\312\002\027Injective\\Erc20\\V1beta1\342\002#Injective\\Erc20\\V1beta1\\GPBMetadata\352\002\031Injective::Erc20::V1beta1'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['token_pairs']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['token_pairs']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=164
  _globals['_GENESISSTATE']._serialized_end=316
# @@protoc_insertion_point(module_scope)
