# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_portfolio_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&exchange/injective_portfolio_rpc.proto\x12\x17injective_portfolio_rpc\"Y\n\x13TokenHoldersRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05limit\x18\x03 \x01(\x11R\x05limit\"t\n\x14TokenHoldersResponse\x12\x39\n\x07holders\x18\x01 \x03(\x0b\x32\x1f.injective_portfolio_rpc.HolderR\x07holders\x12!\n\x0cnext_cursors\x18\x02 \x03(\tR\x0bnextCursors\"K\n\x06Holder\x12\'\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x18\n\x07\x62\x61lance\x18\x02 \x01(\tR\x07\x62\x61lance\"B\n\x17\x41\x63\x63ountPortfolioRequest\x12\'\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tR\x0e\x61\x63\x63ountAddress\"\\\n\x18\x41\x63\x63ountPortfolioResponse\x12@\n\tportfolio\x18\x01 \x01(\x0b\x32\".injective_portfolio_rpc.PortfolioR\tportfolio\"\xa4\x02\n\tPortfolio\x12\'\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x42\n\rbank_balances\x18\x02 \x03(\x0b\x32\x1d.injective_portfolio_rpc.CoinR\x0c\x62\x61nkBalances\x12N\n\x0bsubaccounts\x18\x03 \x03(\x0b\x32,.injective_portfolio_rpc.SubaccountBalanceV2R\x0bsubaccounts\x12Z\n\x13positions_with_upnl\x18\x04 \x03(\x0b\x32*.injective_portfolio_rpc.PositionsWithUPNLR\x11positionsWithUpnl\"Q\n\x04\x43oin\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\x12\x1b\n\tusd_value\x18\x03 \x01(\tR\x08usdValue\"\x96\x01\n\x13SubaccountBalanceV2\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom\x12\x44\n\x07\x64\x65posit\x18\x03 \x01(\x0b\x32*.injective_portfolio_rpc.SubaccountDepositR\x07\x64\x65posit\"\xc5\x01\n\x11SubaccountDeposit\x12#\n\rtotal_balance\x18\x01 \x01(\tR\x0ctotalBalance\x12+\n\x11\x61vailable_balance\x18\x02 \x01(\tR\x10\x61vailableBalance\x12*\n\x11total_balance_usd\x18\x03 \x01(\tR\x0ftotalBalanceUsd\x12\x32\n\x15\x61vailable_balance_usd\x18\x04 \x01(\tR\x13\x61vailableBalanceUsd\"\x83\x01\n\x11PositionsWithUPNL\x12G\n\x08position\x18\x01 \x01(\x0b\x32+.injective_portfolio_rpc.DerivativePositionR\x08position\x12%\n\x0eunrealized_pnl\x18\x02 \x01(\tR\runrealizedPnl\"\xb0\x03\n\x12\x44\x65rivativePosition\x12\x16\n\x06ticker\x18\x01 \x01(\tR\x06ticker\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x03 \x01(\tR\x0csubaccountId\x12\x1c\n\tdirection\x18\x04 \x01(\tR\tdirection\x12\x1a\n\x08quantity\x18\x05 \x01(\tR\x08quantity\x12\x1f\n\x0b\x65ntry_price\x18\x06 \x01(\tR\nentryPrice\x12\x16\n\x06margin\x18\x07 \x01(\tR\x06margin\x12+\n\x11liquidation_price\x18\x08 \x01(\tR\x10liquidationPrice\x12\x1d\n\nmark_price\x18\t \x01(\tR\tmarkPrice\x12\x43\n\x1e\x61ggregate_reduce_only_quantity\x18\x0b \x01(\tR\x1b\x61ggregateReduceOnlyQuantity\x12\x1d\n\nupdated_at\x18\x0c \x01(\x12R\tupdatedAt\x12\x1d\n\ncreated_at\x18\r \x01(\x12R\tcreatedAt\"\\\n\x1f\x41\x63\x63ountPortfolioBalancesRequest\x12\'\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x10\n\x03usd\x18\x02 \x01(\x08R\x03usd\"l\n AccountPortfolioBalancesResponse\x12H\n\tportfolio\x18\x01 \x01(\x0b\x32*.injective_portfolio_rpc.PortfolioBalancesR\tportfolio\"\xed\x01\n\x11PortfolioBalances\x12\'\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x42\n\rbank_balances\x18\x02 \x03(\x0b\x32\x1d.injective_portfolio_rpc.CoinR\x0c\x62\x61nkBalances\x12N\n\x0bsubaccounts\x18\x03 \x03(\x0b\x32,.injective_portfolio_rpc.SubaccountBalanceV2R\x0bsubaccounts\x12\x1b\n\ttotal_usd\x18\x04 \x01(\tR\x08totalUsd\"\x81\x01\n\x1dStreamAccountPortfolioRequest\x12\'\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tR\x0e\x61\x63\x63ountAddress\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\"\xa5\x01\n\x1eStreamAccountPortfolioResponse\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom\x12\x16\n\x06\x61mount\x18\x03 \x01(\tR\x06\x61mount\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12\x1c\n\ttimestamp\x18\x05 \x01(\x12R\ttimestamp2\x9d\x04\n\x15InjectivePortfolioRPC\x12k\n\x0cTokenHolders\x12,.injective_portfolio_rpc.TokenHoldersRequest\x1a-.injective_portfolio_rpc.TokenHoldersResponse\x12w\n\x10\x41\x63\x63ountPortfolio\x12\x30.injective_portfolio_rpc.AccountPortfolioRequest\x1a\x31.injective_portfolio_rpc.AccountPortfolioResponse\x12\x8f\x01\n\x18\x41\x63\x63ountPortfolioBalances\x12\x38.injective_portfolio_rpc.AccountPortfolioBalancesRequest\x1a\x39.injective_portfolio_rpc.AccountPortfolioBalancesResponse\x12\x8b\x01\n\x16StreamAccountPortfolio\x12\x36.injective_portfolio_rpc.StreamAccountPortfolioRequest\x1a\x37.injective_portfolio_rpc.StreamAccountPortfolioResponse0\x01\x42\xc9\x01\n\x1b\x63om.injective_portfolio_rpcB\x1aInjectivePortfolioRpcProtoP\x01Z\x1a/injective_portfolio_rpcpb\xa2\x02\x03IXX\xaa\x02\x15InjectivePortfolioRpc\xca\x02\x15InjectivePortfolioRpc\xe2\x02!InjectivePortfolioRpc\\GPBMetadata\xea\x02\x15InjectivePortfolioRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_portfolio_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.injective_portfolio_rpcB\032InjectivePortfolioRpcProtoP\001Z\032/injective_portfolio_rpcpb\242\002\003IXX\252\002\025InjectivePortfolioRpc\312\002\025InjectivePortfolioRpc\342\002!InjectivePortfolioRpc\\GPBMetadata\352\002\025InjectivePortfolioRpc'
  _globals['_TOKENHOLDERSREQUEST']._serialized_start=67
  _globals['_TOKENHOLDERSREQUEST']._serialized_end=156
  _globals['_TOKENHOLDERSRESPONSE']._serialized_start=158
  _globals['_TOKENHOLDERSRESPONSE']._serialized_end=274
  _globals['_HOLDER']._serialized_start=276
  _globals['_HOLDER']._serialized_end=351
  _globals['_ACCOUNTPORTFOLIOREQUEST']._serialized_start=353
  _globals['_ACCOUNTPORTFOLIOREQUEST']._serialized_end=419
  _globals['_ACCOUNTPORTFOLIORESPONSE']._serialized_start=421
  _globals['_ACCOUNTPORTFOLIORESPONSE']._serialized_end=513
  _globals['_PORTFOLIO']._serialized_start=516
  _globals['_PORTFOLIO']._serialized_end=808
  _globals['_COIN']._serialized_start=810
  _globals['_COIN']._serialized_end=891
  _globals['_SUBACCOUNTBALANCEV2']._serialized_start=894
  _globals['_SUBACCOUNTBALANCEV2']._serialized_end=1044
  _globals['_SUBACCOUNTDEPOSIT']._serialized_start=1047
  _globals['_SUBACCOUNTDEPOSIT']._serialized_end=1244
  _globals['_POSITIONSWITHUPNL']._serialized_start=1247
  _globals['_POSITIONSWITHUPNL']._serialized_end=1378
  _globals['_DERIVATIVEPOSITION']._serialized_start=1381
  _globals['_DERIVATIVEPOSITION']._serialized_end=1813
  _globals['_ACCOUNTPORTFOLIOBALANCESREQUEST']._serialized_start=1815
  _globals['_ACCOUNTPORTFOLIOBALANCESREQUEST']._serialized_end=1907
  _globals['_ACCOUNTPORTFOLIOBALANCESRESPONSE']._serialized_start=1909
  _globals['_ACCOUNTPORTFOLIOBALANCESRESPONSE']._serialized_end=2017
  _globals['_PORTFOLIOBALANCES']._serialized_start=2020
  _globals['_PORTFOLIOBALANCES']._serialized_end=2257
  _globals['_STREAMACCOUNTPORTFOLIOREQUEST']._serialized_start=2260
  _globals['_STREAMACCOUNTPORTFOLIOREQUEST']._serialized_end=2389
  _globals['_STREAMACCOUNTPORTFOLIORESPONSE']._serialized_start=2392
  _globals['_STREAMACCOUNTPORTFOLIORESPONSE']._serialized_end=2557
  _globals['_INJECTIVEPORTFOLIORPC']._serialized_start=2560
  _globals['_INJECTIVEPORTFOLIORPC']._serialized_end=3101
# @@protoc_insertion_point(module_scope)
