# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/p2p/v1/pex.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.p2p.v1 import types_pb2 as cometbft_dot_p2p_dot_v1_dot_types__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x63ometbft/p2p/v1/pex.proto\x12\x0f\x63ometbft.p2p.v1\x1a\x1b\x63ometbft/p2p/v1/types.proto\x1a\x14gogoproto/gogo.proto\"\x0c\n\nPexRequest\"C\n\x08PexAddrs\x12\x37\n\x05\x61\x64\x64rs\x18\x01 \x03(\x0b\x32\x1b.cometbft.p2p.v1.NetAddressB\x04\xc8\xde\x1f\x00R\x05\x61\x64\x64rs\"\x8a\x01\n\x07Message\x12>\n\x0bpex_request\x18\x01 \x01(\x0b\x32\x1b.cometbft.p2p.v1.PexRequestH\x00R\npexRequest\x12\x38\n\tpex_addrs\x18\x02 \x01(\x0b\x32\x19.cometbft.p2p.v1.PexAddrsH\x00R\x08pexAddrsB\x05\n\x03sumB\xaf\x01\n\x13\x63om.cometbft.p2p.v1B\x08PexProtoP\x01Z0github.com/cometbft/cometbft/api/cometbft/p2p/v1\xa2\x02\x03\x43PX\xaa\x02\x0f\x43ometbft.P2p.V1\xca\x02\x0f\x43ometbft\\P2p\\V1\xe2\x02\x1b\x43ometbft\\P2p\\V1\\GPBMetadata\xea\x02\x11\x43ometbft::P2p::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.p2p.v1.pex_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.cometbft.p2p.v1B\010PexProtoP\001Z0github.com/cometbft/cometbft/api/cometbft/p2p/v1\242\002\003CPX\252\002\017Cometbft.P2p.V1\312\002\017Cometbft\\P2p\\V1\342\002\033Cometbft\\P2p\\V1\\GPBMetadata\352\002\021Cometbft::P2p::V1'
  _globals['_PEXADDRS'].fields_by_name['addrs']._loaded_options = None
  _globals['_PEXADDRS'].fields_by_name['addrs']._serialized_options = b'\310\336\037\000'
  _globals['_PEXREQUEST']._serialized_start=97
  _globals['_PEXREQUEST']._serialized_end=109
  _globals['_PEXADDRS']._serialized_start=111
  _globals['_PEXADDRS']._serialized_end=178
  _globals['_MESSAGE']._serialized_start=181
  _globals['_MESSAGE']._serialized_end=319
# @@protoc_insertion_point(module_scope)
