# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/evm/v1/tx_result.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.evm.v1 import transaction_logs_pb2 as injective_dot_evm_dot_v1_dot_transaction__logs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n injective/evm/v1/tx_result.proto\x12\x10injective.evm.v1\x1a\x14gogoproto/gogo.proto\x1a\'injective/evm/v1/transaction_logs.proto\"\x8b\x02\n\x08TxResult\x12\x46\n\x10\x63ontract_address\x18\x01 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"contract_address\"R\x0f\x63ontractAddress\x12\x14\n\x05\x62loom\x18\x02 \x01(\x0cR\x05\x62loom\x12R\n\x07tx_logs\x18\x03 \x01(\x0b\x32!.injective.evm.v1.TransactionLogsB\x16\xc8\xde\x1f\x00\xf2\xde\x1f\x0eyaml:\"tx_logs\"R\x06txLogs\x12\x10\n\x03ret\x18\x04 \x01(\x0cR\x03ret\x12\x1a\n\x08reverted\x18\x05 \x01(\x08R\x08reverted\x12\x19\n\x08gas_used\x18\x06 \x01(\x04R\x07gasUsed:\x04\x88\xa0\x1f\x00\x42\xd2\x01\n\x14\x63om.injective.evm.v1B\rTxResultProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\xa2\x02\x03IEX\xaa\x02\x10Injective.Evm.V1\xca\x02\x10Injective\\Evm\\V1\xe2\x02\x1cInjective\\Evm\\V1\\GPBMetadata\xea\x02\x12Injective::Evm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.evm.v1.tx_result_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.injective.evm.v1B\rTxResultProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\242\002\003IEX\252\002\020Injective.Evm.V1\312\002\020Injective\\Evm\\V1\342\002\034Injective\\Evm\\V1\\GPBMetadata\352\002\022Injective::Evm::V1'
  _globals['_TXRESULT'].fields_by_name['contract_address']._loaded_options = None
  _globals['_TXRESULT'].fields_by_name['contract_address']._serialized_options = b'\362\336\037\027yaml:\"contract_address\"'
  _globals['_TXRESULT'].fields_by_name['tx_logs']._loaded_options = None
  _globals['_TXRESULT'].fields_by_name['tx_logs']._serialized_options = b'\310\336\037\000\362\336\037\016yaml:\"tx_logs\"'
  _globals['_TXRESULT']._loaded_options = None
  _globals['_TXRESULT']._serialized_options = b'\210\240\037\000'
  _globals['_TXRESULT']._serialized_start=118
  _globals['_TXRESULT']._serialized_end=385
# @@protoc_insertion_point(module_scope)
