# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/services/pruning/v1/service.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.services.pruning.v1 import pruning_pb2 as cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cometbft/services/pruning/v1/service.proto\x12\x1c\x63ometbft.services.pruning.v1\x1a*cometbft/services/pruning/v1/pruning.proto2\xfc\t\n\x0ePruningService\x12\x8d\x01\n\x14SetBlockRetainHeight\x12\x39.cometbft.services.pruning.v1.SetBlockRetainHeightRequest\x1a:.cometbft.services.pruning.v1.SetBlockRetainHeightResponse\x12\x8d\x01\n\x14GetBlockRetainHeight\x12\x39.cometbft.services.pruning.v1.GetBlockRetainHeightRequest\x1a:.cometbft.services.pruning.v1.GetBlockRetainHeightResponse\x12\xa2\x01\n\x1bSetBlockResultsRetainHeight\x12@.cometbft.services.pruning.v1.SetBlockResultsRetainHeightRequest\x1a\x41.cometbft.services.pruning.v1.SetBlockResultsRetainHeightResponse\x12\xa2\x01\n\x1bGetBlockResultsRetainHeight\x12@.cometbft.services.pruning.v1.GetBlockResultsRetainHeightRequest\x1a\x41.cometbft.services.pruning.v1.GetBlockResultsRetainHeightResponse\x12\x99\x01\n\x18SetTxIndexerRetainHeight\x12=.cometbft.services.pruning.v1.SetTxIndexerRetainHeightRequest\x1a>.cometbft.services.pruning.v1.SetTxIndexerRetainHeightResponse\x12\x99\x01\n\x18GetTxIndexerRetainHeight\x12=.cometbft.services.pruning.v1.GetTxIndexerRetainHeightRequest\x1a>.cometbft.services.pruning.v1.GetTxIndexerRetainHeightResponse\x12\xa2\x01\n\x1bSetBlockIndexerRetainHeight\x12@.cometbft.services.pruning.v1.SetBlockIndexerRetainHeightRequest\x1a\x41.cometbft.services.pruning.v1.SetBlockIndexerRetainHeightResponse\x12\xa2\x01\n\x1bGetBlockIndexerRetainHeight\x12@.cometbft.services.pruning.v1.GetBlockIndexerRetainHeightRequest\x1a\x41.cometbft.services.pruning.v1.GetBlockIndexerRetainHeightResponseB\xc3\x01\n com.cometbft.services.pruning.v1B\x0cServiceProtoP\x01\xa2\x02\x03\x43SP\xaa\x02\x1c\x43ometbft.Services.Pruning.V1\xca\x02\x1c\x43ometbft\\Services\\Pruning\\V1\xe2\x02(Cometbft\\Services\\Pruning\\V1\\GPBMetadata\xea\x02\x1f\x43ometbft::Services::Pruning::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.services.pruning.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.cometbft.services.pruning.v1B\014ServiceProtoP\001\242\002\003CSP\252\002\034Cometbft.Services.Pruning.V1\312\002\034Cometbft\\Services\\Pruning\\V1\342\002(Cometbft\\Services\\Pruning\\V1\\GPBMetadata\352\002\037Cometbft::Services::Pruning::V1'
  _globals['_PRUNINGSERVICE']._serialized_start=121
  _globals['_PRUNINGSERVICE']._serialized_end=1397
# @@protoc_insertion_point(module_scope)
