# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/channel/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from pyinjective.proto.ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2
from pyinjective.proto.ibc.core.channel.v1 import upgrade_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_upgrade__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cibc/core/channel/v1/tx.proto\x12\x13ibc.core.channel.v1\x1a\x14gogoproto/gogo.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x1fibc/core/client/v1/client.proto\x1a!ibc/core/channel/v1/channel.proto\x1a!ibc/core/channel/v1/upgrade.proto\"\x94\x01\n\x12MsgChannelOpenInit\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12<\n\x07\x63hannel\x18\x02 \x01(\x0b\x32\x1c.ibc.core.channel.v1.ChannelB\x04\xc8\xde\x1f\x00R\x07\x63hannel\x12\x16\n\x06signer\x18\x03 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"[\n\x1aMsgChannelOpenInitResponse\x12\x1d\n\nchannel_id\x18\x01 \x01(\tR\tchannelId\x12\x18\n\x07version\x18\x02 \x01(\tR\x07version:\x04\x88\xa0\x1f\x00\"\xde\x02\n\x11MsgChannelOpenTry\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x32\n\x13previous_channel_id\x18\x02 \x01(\tB\x02\x18\x01R\x11previousChannelId\x12<\n\x07\x63hannel\x18\x03 \x01(\x0b\x32\x1c.ibc.core.channel.v1.ChannelB\x04\xc8\xde\x1f\x00R\x07\x63hannel\x12\x31\n\x14\x63ounterparty_version\x18\x04 \x01(\tR\x13\x63ounterpartyVersion\x12\x1d\n\nproof_init\x18\x05 \x01(\x0cR\tproofInit\x12\x43\n\x0cproof_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x07 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"Z\n\x19MsgChannelOpenTryResponse\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId:\x04\x88\xa0\x1f\x00\"\xc1\x02\n\x11MsgChannelOpenAck\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x36\n\x17\x63ounterparty_channel_id\x18\x03 \x01(\tR\x15\x63ounterpartyChannelId\x12\x31\n\x14\x63ounterparty_version\x18\x04 \x01(\tR\x13\x63ounterpartyVersion\x12\x1b\n\tproof_try\x18\x05 \x01(\x0cR\x08proofTry\x12\x43\n\x0cproof_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x07 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x1b\n\x19MsgChannelOpenAckResponse\"\xda\x01\n\x15MsgChannelOpenConfirm\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x1b\n\tproof_ack\x18\x03 \x01(\x0cR\x08proofAck\x12\x43\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x05 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x1f\n\x1dMsgChannelOpenConfirmResponse\"v\n\x13MsgChannelCloseInit\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x16\n\x06signer\x18\x03 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x1d\n\x1bMsgChannelCloseInitResponse\"\xa1\x02\n\x16MsgChannelCloseConfirm\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x1d\n\nproof_init\x18\x03 \x01(\x0cR\tproofInit\x12\x43\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x05 \x01(\tR\x06signer\x12\x42\n\x1d\x63ounterparty_upgrade_sequence\x18\x06 \x01(\x04R\x1b\x63ounterpartyUpgradeSequence:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\" \n\x1eMsgChannelCloseConfirmResponse\"\xe3\x01\n\rMsgRecvPacket\x12\x39\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00R\x06packet\x12)\n\x10proof_commitment\x18\x02 \x01(\x0cR\x0fproofCommitment\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x04 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"^\n\x15MsgRecvPacketResponse\x12?\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultTypeR\x06result:\x04\x88\xa0\x1f\x00\"\x8e\x02\n\nMsgTimeout\x12\x39\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00R\x06packet\x12)\n\x10proof_unreceived\x18\x02 \x01(\x0cR\x0fproofUnreceived\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12,\n\x12next_sequence_recv\x18\x04 \x01(\x04R\x10nextSequenceRecv\x12\x16\n\x06signer\x18\x05 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"[\n\x12MsgTimeoutResponse\x12?\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultTypeR\x06result:\x04\x88\xa0\x1f\x00\"\xfa\x02\n\x11MsgTimeoutOnClose\x12\x39\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00R\x06packet\x12)\n\x10proof_unreceived\x18\x02 \x01(\x0cR\x0fproofUnreceived\x12\x1f\n\x0bproof_close\x18\x03 \x01(\x0cR\nproofClose\x12\x43\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12,\n\x12next_sequence_recv\x18\x05 \x01(\x04R\x10nextSequenceRecv\x12\x16\n\x06signer\x18\x06 \x01(\tR\x06signer\x12\x42\n\x1d\x63ounterparty_upgrade_sequence\x18\x07 \x01(\x04R\x1b\x63ounterpartyUpgradeSequence:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"b\n\x19MsgTimeoutOnCloseResponse\x12?\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultTypeR\x06result:\x04\x88\xa0\x1f\x00\"\x88\x02\n\x12MsgAcknowledgement\x12\x39\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00R\x06packet\x12(\n\x0f\x61\x63knowledgement\x18\x02 \x01(\x0cR\x0f\x61\x63knowledgement\x12\x1f\n\x0bproof_acked\x18\x03 \x01(\x0cR\nproofAcked\x12\x43\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x05 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"c\n\x1aMsgAcknowledgementResponse\x12?\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultTypeR\x06result:\x04\x88\xa0\x1f\x00\"\xba\x01\n\x15MsgChannelUpgradeInit\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12@\n\x06\x66ields\x18\x03 \x01(\x0b\x32\".ibc.core.channel.v1.UpgradeFieldsB\x04\xc8\xde\x1f\x00R\x06\x66ields\x12\x16\n\x06signer\x18\x04 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x8e\x01\n\x1dMsgChannelUpgradeInitResponse\x12<\n\x07upgrade\x18\x01 \x01(\x0b\x32\x1c.ibc.core.channel.v1.UpgradeB\x04\xc8\xde\x1f\x00R\x07upgrade\x12)\n\x10upgrade_sequence\x18\x02 \x01(\x04R\x0fupgradeSequence:\x04\x88\xa0\x1f\x00\"\xfd\x03\n\x14MsgChannelUpgradeTry\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12G\n proposed_upgrade_connection_hops\x18\x03 \x03(\tR\x1dproposedUpgradeConnectionHops\x12h\n\x1b\x63ounterparty_upgrade_fields\x18\x04 \x01(\x0b\x32\".ibc.core.channel.v1.UpgradeFieldsB\x04\xc8\xde\x1f\x00R\x19\x63ounterpartyUpgradeFields\x12\x42\n\x1d\x63ounterparty_upgrade_sequence\x18\x05 \x01(\x04R\x1b\x63ounterpartyUpgradeSequence\x12#\n\rproof_channel\x18\x06 \x01(\x0cR\x0cproofChannel\x12#\n\rproof_upgrade\x18\x07 \x01(\x0cR\x0cproofUpgrade\x12\x43\n\x0cproof_height\x18\x08 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\t \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\xce\x01\n\x1cMsgChannelUpgradeTryResponse\x12<\n\x07upgrade\x18\x01 \x01(\x0b\x32\x1c.ibc.core.channel.v1.UpgradeB\x04\xc8\xde\x1f\x00R\x07upgrade\x12)\n\x10upgrade_sequence\x18\x02 \x01(\x04R\x0fupgradeSequence\x12?\n\x06result\x18\x03 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultTypeR\x06result:\x04\x88\xa0\x1f\x00\"\xdd\x02\n\x14MsgChannelUpgradeAck\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12U\n\x14\x63ounterparty_upgrade\x18\x03 \x01(\x0b\x32\x1c.ibc.core.channel.v1.UpgradeB\x04\xc8\xde\x1f\x00R\x13\x63ounterpartyUpgrade\x12#\n\rproof_channel\x18\x04 \x01(\x0cR\x0cproofChannel\x12#\n\rproof_upgrade\x18\x05 \x01(\x0cR\x0cproofUpgrade\x12\x43\n\x0cproof_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x07 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"e\n\x1cMsgChannelUpgradeAckResponse\x12?\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultTypeR\x06result:\x04\x88\xa0\x1f\x00\"\xbb\x03\n\x18MsgChannelUpgradeConfirm\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12X\n\x1a\x63ounterparty_channel_state\x18\x03 \x01(\x0e\x32\x1a.ibc.core.channel.v1.StateR\x18\x63ounterpartyChannelState\x12U\n\x14\x63ounterparty_upgrade\x18\x04 \x01(\x0b\x32\x1c.ibc.core.channel.v1.UpgradeB\x04\xc8\xde\x1f\x00R\x13\x63ounterpartyUpgrade\x12#\n\rproof_channel\x18\x05 \x01(\x0cR\x0cproofChannel\x12#\n\rproof_upgrade\x18\x06 \x01(\x0cR\x0cproofUpgrade\x12\x43\n\x0cproof_height\x18\x07 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x08 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"i\n MsgChannelUpgradeConfirmResponse\x12?\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultTypeR\x06result:\x04\x88\xa0\x1f\x00\"\x80\x03\n\x15MsgChannelUpgradeOpen\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12X\n\x1a\x63ounterparty_channel_state\x18\x03 \x01(\x0e\x32\x1a.ibc.core.channel.v1.StateR\x18\x63ounterpartyChannelState\x12\x42\n\x1d\x63ounterparty_upgrade_sequence\x18\x04 \x01(\x04R\x1b\x63ounterpartyUpgradeSequence\x12#\n\rproof_channel\x18\x05 \x01(\x0cR\x0cproofChannel\x12\x43\n\x0cproof_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x07 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x1f\n\x1dMsgChannelUpgradeOpenResponse\"\xbc\x02\n\x18MsgChannelUpgradeTimeout\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12U\n\x14\x63ounterparty_channel\x18\x03 \x01(\x0b\x32\x1c.ibc.core.channel.v1.ChannelB\x04\xc8\xde\x1f\x00R\x13\x63ounterpartyChannel\x12#\n\rproof_channel\x18\x04 \x01(\x0cR\x0cproofChannel\x12\x43\n\x0cproof_height\x18\x05 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x06 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\"\n MsgChannelUpgradeTimeoutResponse\"\xbd\x02\n\x17MsgChannelUpgradeCancel\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12L\n\rerror_receipt\x18\x03 \x01(\x0b\x32!.ibc.core.channel.v1.ErrorReceiptB\x04\xc8\xde\x1f\x00R\x0c\x65rrorReceipt\x12.\n\x13proof_error_receipt\x18\x04 \x01(\x0cR\x11proofErrorReceipt\x12\x43\n\x0cproof_height\x18\x05 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x06 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"!\n\x1fMsgChannelUpgradeCancelResponse\"~\n\x0fMsgUpdateParams\x12\x1c\n\tauthority\x18\x01 \x01(\tR\tauthority\x12\x39\n\x06params\x18\x02 \x01(\x0b\x32\x1b.ibc.core.channel.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:\x12\x88\xa0\x1f\x00\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse\"\x91\x01\n\x18MsgPruneAcknowledgements\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x14\n\x05limit\x18\x03 \x01(\x04R\x05limit\x12\x16\n\x06signer\x18\x04 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x94\x01\n MsgPruneAcknowledgementsResponse\x12\x34\n\x16total_pruned_sequences\x18\x01 \x01(\x04R\x14totalPrunedSequences\x12:\n\x19total_remaining_sequences\x18\x02 \x01(\x04R\x17totalRemainingSequences*\xd8\x01\n\x12ResponseResultType\x12\x35\n RESPONSE_RESULT_TYPE_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUNSPECIFIED\x12\'\n\x19RESPONSE_RESULT_TYPE_NOOP\x10\x01\x1a\x08\x8a\x9d \x04NOOP\x12-\n\x1cRESPONSE_RESULT_TYPE_SUCCESS\x10\x02\x1a\x0b\x8a\x9d \x07SUCCESS\x12-\n\x1cRESPONSE_RESULT_TYPE_FAILURE\x10\x03\x1a\x0b\x8a\x9d \x07\x46\x41ILURE\x1a\x04\x88\xa3\x1e\x00\x32\xec\x10\n\x03Msg\x12k\n\x0f\x43hannelOpenInit\x12\'.ibc.core.channel.v1.MsgChannelOpenInit\x1a/.ibc.core.channel.v1.MsgChannelOpenInitResponse\x12h\n\x0e\x43hannelOpenTry\x12&.ibc.core.channel.v1.MsgChannelOpenTry\x1a..ibc.core.channel.v1.MsgChannelOpenTryResponse\x12h\n\x0e\x43hannelOpenAck\x12&.ibc.core.channel.v1.MsgChannelOpenAck\x1a..ibc.core.channel.v1.MsgChannelOpenAckResponse\x12t\n\x12\x43hannelOpenConfirm\x12*.ibc.core.channel.v1.MsgChannelOpenConfirm\x1a\x32.ibc.core.channel.v1.MsgChannelOpenConfirmResponse\x12n\n\x10\x43hannelCloseInit\x12(.ibc.core.channel.v1.MsgChannelCloseInit\x1a\x30.ibc.core.channel.v1.MsgChannelCloseInitResponse\x12w\n\x13\x43hannelCloseConfirm\x12+.ibc.core.channel.v1.MsgChannelCloseConfirm\x1a\x33.ibc.core.channel.v1.MsgChannelCloseConfirmResponse\x12\\\n\nRecvPacket\x12\".ibc.core.channel.v1.MsgRecvPacket\x1a*.ibc.core.channel.v1.MsgRecvPacketResponse\x12S\n\x07Timeout\x12\x1f.ibc.core.channel.v1.MsgTimeout\x1a\'.ibc.core.channel.v1.MsgTimeoutResponse\x12h\n\x0eTimeoutOnClose\x12&.ibc.core.channel.v1.MsgTimeoutOnClose\x1a..ibc.core.channel.v1.MsgTimeoutOnCloseResponse\x12k\n\x0f\x41\x63knowledgement\x12\'.ibc.core.channel.v1.MsgAcknowledgement\x1a/.ibc.core.channel.v1.MsgAcknowledgementResponse\x12t\n\x12\x43hannelUpgradeInit\x12*.ibc.core.channel.v1.MsgChannelUpgradeInit\x1a\x32.ibc.core.channel.v1.MsgChannelUpgradeInitResponse\x12q\n\x11\x43hannelUpgradeTry\x12).ibc.core.channel.v1.MsgChannelUpgradeTry\x1a\x31.ibc.core.channel.v1.MsgChannelUpgradeTryResponse\x12q\n\x11\x43hannelUpgradeAck\x12).ibc.core.channel.v1.MsgChannelUpgradeAck\x1a\x31.ibc.core.channel.v1.MsgChannelUpgradeAckResponse\x12}\n\x15\x43hannelUpgradeConfirm\x12-.ibc.core.channel.v1.MsgChannelUpgradeConfirm\x1a\x35.ibc.core.channel.v1.MsgChannelUpgradeConfirmResponse\x12t\n\x12\x43hannelUpgradeOpen\x12*.ibc.core.channel.v1.MsgChannelUpgradeOpen\x1a\x32.ibc.core.channel.v1.MsgChannelUpgradeOpenResponse\x12}\n\x15\x43hannelUpgradeTimeout\x12-.ibc.core.channel.v1.MsgChannelUpgradeTimeout\x1a\x35.ibc.core.channel.v1.MsgChannelUpgradeTimeoutResponse\x12z\n\x14\x43hannelUpgradeCancel\x12,.ibc.core.channel.v1.MsgChannelUpgradeCancel\x1a\x34.ibc.core.channel.v1.MsgChannelUpgradeCancelResponse\x12i\n\x13UpdateChannelParams\x12$.ibc.core.channel.v1.MsgUpdateParams\x1a,.ibc.core.channel.v1.MsgUpdateParamsResponse\x12}\n\x15PruneAcknowledgements\x12-.ibc.core.channel.v1.MsgPruneAcknowledgements\x1a\x35.ibc.core.channel.v1.MsgPruneAcknowledgementsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xcc\x01\n\x17\x63om.ibc.core.channel.v1B\x07TxProtoP\x01Z9github.com/cosmos/ibc-go/v8/modules/core/04-channel/types\xa2\x02\x03ICC\xaa\x02\x13Ibc.Core.Channel.V1\xca\x02\x13Ibc\\Core\\Channel\\V1\xe2\x02\x1fIbc\\Core\\Channel\\V1\\GPBMetadata\xea\x02\x16Ibc::Core::Channel::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.channel.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.ibc.core.channel.v1B\007TxProtoP\001Z9github.com/cosmos/ibc-go/v8/modules/core/04-channel/types\242\002\003ICC\252\002\023Ibc.Core.Channel.V1\312\002\023Ibc\\Core\\Channel\\V1\342\002\037Ibc\\Core\\Channel\\V1\\GPBMetadata\352\002\026Ibc::Core::Channel::V1'
  _globals['_RESPONSERESULTTYPE']._loaded_options = None
  _globals['_RESPONSERESULTTYPE']._serialized_options = b'\210\243\036\000'
  _globals['_RESPONSERESULTTYPE'].values_by_name["RESPONSE_RESULT_TYPE_UNSPECIFIED"]._loaded_options = None
  _globals['_RESPONSERESULTTYPE'].values_by_name["RESPONSE_RESULT_TYPE_UNSPECIFIED"]._serialized_options = b'\212\235 \013UNSPECIFIED'
  _globals['_RESPONSERESULTTYPE'].values_by_name["RESPONSE_RESULT_TYPE_NOOP"]._loaded_options = None
  _globals['_RESPONSERESULTTYPE'].values_by_name["RESPONSE_RESULT_TYPE_NOOP"]._serialized_options = b'\212\235 \004NOOP'
  _globals['_RESPONSERESULTTYPE'].values_by_name["RESPONSE_RESULT_TYPE_SUCCESS"]._loaded_options = None
  _globals['_RESPONSERESULTTYPE'].values_by_name["RESPONSE_RESULT_TYPE_SUCCESS"]._serialized_options = b'\212\235 \007SUCCESS'
  _globals['_RESPONSERESULTTYPE'].values_by_name["RESPONSE_RESULT_TYPE_FAILURE"]._loaded_options = None
  _globals['_RESPONSERESULTTYPE'].values_by_name["RESPONSE_RESULT_TYPE_FAILURE"]._serialized_options = b'\212\235 \007FAILURE'
  _globals['_MSGCHANNELOPENINIT'].fields_by_name['channel']._loaded_options = None
  _globals['_MSGCHANNELOPENINIT'].fields_by_name['channel']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELOPENINIT']._loaded_options = None
  _globals['_MSGCHANNELOPENINIT']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELOPENINITRESPONSE']._loaded_options = None
  _globals['_MSGCHANNELOPENINITRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGCHANNELOPENTRY'].fields_by_name['previous_channel_id']._loaded_options = None
  _globals['_MSGCHANNELOPENTRY'].fields_by_name['previous_channel_id']._serialized_options = b'\030\001'
  _globals['_MSGCHANNELOPENTRY'].fields_by_name['channel']._loaded_options = None
  _globals['_MSGCHANNELOPENTRY'].fields_by_name['channel']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELOPENTRY'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELOPENTRY'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELOPENTRY']._loaded_options = None
  _globals['_MSGCHANNELOPENTRY']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELOPENTRYRESPONSE']._loaded_options = None
  _globals['_MSGCHANNELOPENTRYRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGCHANNELOPENACK'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELOPENACK'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELOPENACK']._loaded_options = None
  _globals['_MSGCHANNELOPENACK']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELOPENCONFIRM'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELOPENCONFIRM'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELOPENCONFIRM']._loaded_options = None
  _globals['_MSGCHANNELOPENCONFIRM']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELCLOSEINIT']._loaded_options = None
  _globals['_MSGCHANNELCLOSEINIT']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELCLOSECONFIRM'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELCLOSECONFIRM'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELCLOSECONFIRM']._loaded_options = None
  _globals['_MSGCHANNELCLOSECONFIRM']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGRECVPACKET'].fields_by_name['packet']._loaded_options = None
  _globals['_MSGRECVPACKET'].fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _globals['_MSGRECVPACKET'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGRECVPACKET'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGRECVPACKET']._loaded_options = None
  _globals['_MSGRECVPACKET']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGRECVPACKETRESPONSE']._loaded_options = None
  _globals['_MSGRECVPACKETRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGTIMEOUT'].fields_by_name['packet']._loaded_options = None
  _globals['_MSGTIMEOUT'].fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _globals['_MSGTIMEOUT'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGTIMEOUT'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGTIMEOUT']._loaded_options = None
  _globals['_MSGTIMEOUT']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGTIMEOUTRESPONSE']._loaded_options = None
  _globals['_MSGTIMEOUTRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGTIMEOUTONCLOSE'].fields_by_name['packet']._loaded_options = None
  _globals['_MSGTIMEOUTONCLOSE'].fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _globals['_MSGTIMEOUTONCLOSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGTIMEOUTONCLOSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGTIMEOUTONCLOSE']._loaded_options = None
  _globals['_MSGTIMEOUTONCLOSE']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGTIMEOUTONCLOSERESPONSE']._loaded_options = None
  _globals['_MSGTIMEOUTONCLOSERESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGACKNOWLEDGEMENT'].fields_by_name['packet']._loaded_options = None
  _globals['_MSGACKNOWLEDGEMENT'].fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _globals['_MSGACKNOWLEDGEMENT'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGACKNOWLEDGEMENT'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGACKNOWLEDGEMENT']._loaded_options = None
  _globals['_MSGACKNOWLEDGEMENT']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGACKNOWLEDGEMENTRESPONSE']._loaded_options = None
  _globals['_MSGACKNOWLEDGEMENTRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGCHANNELUPGRADEINIT'].fields_by_name['fields']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEINIT'].fields_by_name['fields']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADEINIT']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEINIT']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELUPGRADEINITRESPONSE'].fields_by_name['upgrade']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEINITRESPONSE'].fields_by_name['upgrade']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADEINITRESPONSE']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEINITRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGCHANNELUPGRADETRY'].fields_by_name['counterparty_upgrade_fields']._loaded_options = None
  _globals['_MSGCHANNELUPGRADETRY'].fields_by_name['counterparty_upgrade_fields']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADETRY'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELUPGRADETRY'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADETRY']._loaded_options = None
  _globals['_MSGCHANNELUPGRADETRY']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELUPGRADETRYRESPONSE'].fields_by_name['upgrade']._loaded_options = None
  _globals['_MSGCHANNELUPGRADETRYRESPONSE'].fields_by_name['upgrade']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADETRYRESPONSE']._loaded_options = None
  _globals['_MSGCHANNELUPGRADETRYRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGCHANNELUPGRADEACK'].fields_by_name['counterparty_upgrade']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEACK'].fields_by_name['counterparty_upgrade']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADEACK'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEACK'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADEACK']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEACK']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELUPGRADEACKRESPONSE']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEACKRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGCHANNELUPGRADECONFIRM'].fields_by_name['counterparty_upgrade']._loaded_options = None
  _globals['_MSGCHANNELUPGRADECONFIRM'].fields_by_name['counterparty_upgrade']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADECONFIRM'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELUPGRADECONFIRM'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADECONFIRM']._loaded_options = None
  _globals['_MSGCHANNELUPGRADECONFIRM']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELUPGRADECONFIRMRESPONSE']._loaded_options = None
  _globals['_MSGCHANNELUPGRADECONFIRMRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGCHANNELUPGRADEOPEN'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEOPEN'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADEOPEN']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEOPEN']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELUPGRADETIMEOUT'].fields_by_name['counterparty_channel']._loaded_options = None
  _globals['_MSGCHANNELUPGRADETIMEOUT'].fields_by_name['counterparty_channel']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADETIMEOUT'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELUPGRADETIMEOUT'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADETIMEOUT']._loaded_options = None
  _globals['_MSGCHANNELUPGRADETIMEOUT']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELUPGRADECANCEL'].fields_by_name['error_receipt']._loaded_options = None
  _globals['_MSGCHANNELUPGRADECANCEL'].fields_by_name['error_receipt']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADECANCEL'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELUPGRADECANCEL'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADECANCEL']._loaded_options = None
  _globals['_MSGCHANNELUPGRADECANCEL']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\210\240\037\000\202\347\260*\tauthority'
  _globals['_MSGPRUNEACKNOWLEDGEMENTS']._loaded_options = None
  _globals['_MSGPRUNEACKNOWLEDGEMENTS']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_RESPONSERESULTTYPE']._serialized_start=7165
  _globals['_RESPONSERESULTTYPE']._serialized_end=7381
  _globals['_MSGCHANNELOPENINIT']._serialized_start=204
  _globals['_MSGCHANNELOPENINIT']._serialized_end=352
  _globals['_MSGCHANNELOPENINITRESPONSE']._serialized_start=354
  _globals['_MSGCHANNELOPENINITRESPONSE']._serialized_end=445
  _globals['_MSGCHANNELOPENTRY']._serialized_start=448
  _globals['_MSGCHANNELOPENTRY']._serialized_end=798
  _globals['_MSGCHANNELOPENTRYRESPONSE']._serialized_start=800
  _globals['_MSGCHANNELOPENTRYRESPONSE']._serialized_end=890
  _globals['_MSGCHANNELOPENACK']._serialized_start=893
  _globals['_MSGCHANNELOPENACK']._serialized_end=1214
  _globals['_MSGCHANNELOPENACKRESPONSE']._serialized_start=1216
  _globals['_MSGCHANNELOPENACKRESPONSE']._serialized_end=1243
  _globals['_MSGCHANNELOPENCONFIRM']._serialized_start=1246
  _globals['_MSGCHANNELOPENCONFIRM']._serialized_end=1464
  _globals['_MSGCHANNELOPENCONFIRMRESPONSE']._serialized_start=1466
  _globals['_MSGCHANNELOPENCONFIRMRESPONSE']._serialized_end=1497
  _globals['_MSGCHANNELCLOSEINIT']._serialized_start=1499
  _globals['_MSGCHANNELCLOSEINIT']._serialized_end=1617
  _globals['_MSGCHANNELCLOSEINITRESPONSE']._serialized_start=1619
  _globals['_MSGCHANNELCLOSEINITRESPONSE']._serialized_end=1648
  _globals['_MSGCHANNELCLOSECONFIRM']._serialized_start=1651
  _globals['_MSGCHANNELCLOSECONFIRM']._serialized_end=1940
  _globals['_MSGCHANNELCLOSECONFIRMRESPONSE']._serialized_start=1942
  _globals['_MSGCHANNELCLOSECONFIRMRESPONSE']._serialized_end=1974
  _globals['_MSGRECVPACKET']._serialized_start=1977
  _globals['_MSGRECVPACKET']._serialized_end=2204
  _globals['_MSGRECVPACKETRESPONSE']._serialized_start=2206
  _globals['_MSGRECVPACKETRESPONSE']._serialized_end=2300
  _globals['_MSGTIMEOUT']._serialized_start=2303
  _globals['_MSGTIMEOUT']._serialized_end=2573
  _globals['_MSGTIMEOUTRESPONSE']._serialized_start=2575
  _globals['_MSGTIMEOUTRESPONSE']._serialized_end=2666
  _globals['_MSGTIMEOUTONCLOSE']._serialized_start=2669
  _globals['_MSGTIMEOUTONCLOSE']._serialized_end=3047
  _globals['_MSGTIMEOUTONCLOSERESPONSE']._serialized_start=3049
  _globals['_MSGTIMEOUTONCLOSERESPONSE']._serialized_end=3147
  _globals['_MSGACKNOWLEDGEMENT']._serialized_start=3150
  _globals['_MSGACKNOWLEDGEMENT']._serialized_end=3414
  _globals['_MSGACKNOWLEDGEMENTRESPONSE']._serialized_start=3416
  _globals['_MSGACKNOWLEDGEMENTRESPONSE']._serialized_end=3515
  _globals['_MSGCHANNELUPGRADEINIT']._serialized_start=3518
  _globals['_MSGCHANNELUPGRADEINIT']._serialized_end=3704
  _globals['_MSGCHANNELUPGRADEINITRESPONSE']._serialized_start=3707
  _globals['_MSGCHANNELUPGRADEINITRESPONSE']._serialized_end=3849
  _globals['_MSGCHANNELUPGRADETRY']._serialized_start=3852
  _globals['_MSGCHANNELUPGRADETRY']._serialized_end=4361
  _globals['_MSGCHANNELUPGRADETRYRESPONSE']._serialized_start=4364
  _globals['_MSGCHANNELUPGRADETRYRESPONSE']._serialized_end=4570
  _globals['_MSGCHANNELUPGRADEACK']._serialized_start=4573
  _globals['_MSGCHANNELUPGRADEACK']._serialized_end=4922
  _globals['_MSGCHANNELUPGRADEACKRESPONSE']._serialized_start=4924
  _globals['_MSGCHANNELUPGRADEACKRESPONSE']._serialized_end=5025
  _globals['_MSGCHANNELUPGRADECONFIRM']._serialized_start=5028
  _globals['_MSGCHANNELUPGRADECONFIRM']._serialized_end=5471
  _globals['_MSGCHANNELUPGRADECONFIRMRESPONSE']._serialized_start=5473
  _globals['_MSGCHANNELUPGRADECONFIRMRESPONSE']._serialized_end=5578
  _globals['_MSGCHANNELUPGRADEOPEN']._serialized_start=5581
  _globals['_MSGCHANNELUPGRADEOPEN']._serialized_end=5965
  _globals['_MSGCHANNELUPGRADEOPENRESPONSE']._serialized_start=5967
  _globals['_MSGCHANNELUPGRADEOPENRESPONSE']._serialized_end=5998
  _globals['_MSGCHANNELUPGRADETIMEOUT']._serialized_start=6001
  _globals['_MSGCHANNELUPGRADETIMEOUT']._serialized_end=6317
  _globals['_MSGCHANNELUPGRADETIMEOUTRESPONSE']._serialized_start=6319
  _globals['_MSGCHANNELUPGRADETIMEOUTRESPONSE']._serialized_end=6353
  _globals['_MSGCHANNELUPGRADECANCEL']._serialized_start=6356
  _globals['_MSGCHANNELUPGRADECANCEL']._serialized_end=6673
  _globals['_MSGCHANNELUPGRADECANCELRESPONSE']._serialized_start=6675
  _globals['_MSGCHANNELUPGRADECANCELRESPONSE']._serialized_end=6708
  _globals['_MSGUPDATEPARAMS']._serialized_start=6710
  _globals['_MSGUPDATEPARAMS']._serialized_end=6836
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=6838
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=6863
  _globals['_MSGPRUNEACKNOWLEDGEMENTS']._serialized_start=6866
  _globals['_MSGPRUNEACKNOWLEDGEMENTS']._serialized_end=7011
  _globals['_MSGPRUNEACKNOWLEDGEMENTSRESPONSE']._serialized_start=7014
  _globals['_MSGPRUNEACKNOWLEDGEMENTSRESPONSE']._serialized_end=7162
  _globals['_MSG']._serialized_start=7384
  _globals['_MSG']._serialized_end=9540
# @@protoc_insertion_point(module_scope)
