# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/insurance/v1beta1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.injective.insurance.v1beta1 import insurance_pb2 as injective_dot_insurance_dot_v1beta1_dot_insurance__pb2
from pyinjective.proto.injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$injective/insurance/v1beta1/tx.proto\x12\x1binjective.insurance.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a+injective/insurance/v1beta1/insurance.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a\x11\x61mino/amino.proto\"\x90\x03\n\x16MsgCreateInsuranceFund\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x16\n\x06ticker\x18\x02 \x01(\tR\x06ticker\x12\x1f\n\x0bquote_denom\x18\x03 \x01(\tR\nquoteDenom\x12\x1f\n\x0boracle_base\x18\x04 \x01(\tR\noracleBase\x12!\n\x0coracle_quote\x18\x05 \x01(\tR\x0boracleQuote\x12\x45\n\x0boracle_type\x18\x06 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleTypeR\noracleType\x12\x16\n\x06\x65xpiry\x18\x07 \x01(\x03R\x06\x65xpiry\x12H\n\x0finitial_deposit\x18\x08 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x0einitialDeposit:8\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0* insurance/MsgCreateInsuranceFund\" \n\x1eMsgCreateInsuranceFundResponse\"\xb0\x01\n\rMsgUnderwrite\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x39\n\x07\x64\x65posit\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x07\x64\x65posit:/\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x17insurance/MsgUnderwrite\"\x17\n\x15MsgUnderwriteResponse\"\xbc\x01\n\x14MsgRequestRedemption\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x37\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount:6\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1einsurance/MsgRequestRedemption\"\x1e\n\x1cMsgRequestRedemptionResponse\"\xba\x01\n\x0fMsgUpdateParams\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12\x41\n\x06params\x18\x02 \x01(\x0b\x32#.injective.insurance.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:,\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x19insurance/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse2\xfc\x03\n\x03Msg\x12\x87\x01\n\x13\x43reateInsuranceFund\x12\x33.injective.insurance.v1beta1.MsgCreateInsuranceFund\x1a;.injective.insurance.v1beta1.MsgCreateInsuranceFundResponse\x12l\n\nUnderwrite\x12*.injective.insurance.v1beta1.MsgUnderwrite\x1a\x32.injective.insurance.v1beta1.MsgUnderwriteResponse\x12\x81\x01\n\x11RequestRedemption\x12\x31.injective.insurance.v1beta1.MsgRequestRedemption\x1a\x39.injective.insurance.v1beta1.MsgRequestRedemptionResponse\x12r\n\x0cUpdateParams\x12,.injective.insurance.v1beta1.MsgUpdateParams\x1a\x34.injective.insurance.v1beta1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x89\x02\n\x1f\x63om.injective.insurance.v1beta1B\x07TxProtoP\x01ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types\xa2\x02\x03IIX\xaa\x02\x1bInjective.Insurance.V1beta1\xca\x02\x1bInjective\\Insurance\\V1beta1\xe2\x02\'Injective\\Insurance\\V1beta1\\GPBMetadata\xea\x02\x1dInjective::Insurance::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.insurance.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.injective.insurance.v1beta1B\007TxProtoP\001ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types\242\002\003IIX\252\002\033Injective.Insurance.V1beta1\312\002\033Injective\\Insurance\\V1beta1\342\002\'Injective\\Insurance\\V1beta1\\GPBMetadata\352\002\035Injective::Insurance::V1beta1'
  _globals['_MSGCREATEINSURANCEFUND'].fields_by_name['initial_deposit']._loaded_options = None
  _globals['_MSGCREATEINSURANCEFUND'].fields_by_name['initial_deposit']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATEINSURANCEFUND']._loaded_options = None
  _globals['_MSGCREATEINSURANCEFUND']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260* insurance/MsgCreateInsuranceFund'
  _globals['_MSGUNDERWRITE'].fields_by_name['deposit']._loaded_options = None
  _globals['_MSGUNDERWRITE'].fields_by_name['deposit']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUNDERWRITE']._loaded_options = None
  _globals['_MSGUNDERWRITE']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\027insurance/MsgUnderwrite'
  _globals['_MSGREQUESTREDEMPTION'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGREQUESTREDEMPTION'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_MSGREQUESTREDEMPTION']._loaded_options = None
  _globals['_MSGREQUESTREDEMPTION']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\036insurance/MsgRequestRedemption'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\031insurance/MsgUpdateParams'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGCREATEINSURANCEFUND']._serialized_start=279
  _globals['_MSGCREATEINSURANCEFUND']._serialized_end=679
  _globals['_MSGCREATEINSURANCEFUNDRESPONSE']._serialized_start=681
  _globals['_MSGCREATEINSURANCEFUNDRESPONSE']._serialized_end=713
  _globals['_MSGUNDERWRITE']._serialized_start=716
  _globals['_MSGUNDERWRITE']._serialized_end=892
  _globals['_MSGUNDERWRITERESPONSE']._serialized_start=894
  _globals['_MSGUNDERWRITERESPONSE']._serialized_end=917
  _globals['_MSGREQUESTREDEMPTION']._serialized_start=920
  _globals['_MSGREQUESTREDEMPTION']._serialized_end=1108
  _globals['_MSGREQUESTREDEMPTIONRESPONSE']._serialized_start=1110
  _globals['_MSGREQUESTREDEMPTIONRESPONSE']._serialized_end=1140
  _globals['_MSGUPDATEPARAMS']._serialized_start=1143
  _globals['_MSGUPDATEPARAMS']._serialized_end=1329
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=1331
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=1356
  _globals['_MSG']._serialized_start=1359
  _globals['_MSG']._serialized_end=1867
# @@protoc_insertion_point(module_scope)
