# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/mempool/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63ometbft/mempool/v1/types.proto\x12\x13\x63ometbft.mempool.v1\"\x17\n\x03Txs\x12\x10\n\x03txs\x18\x01 \x03(\x0cR\x03txs\">\n\x07Message\x12,\n\x03txs\x18\x01 \x01(\x0b\x32\x18.cometbft.mempool.v1.TxsH\x00R\x03txsB\x05\n\x03sumB\xc9\x01\n\x17\x63om.cometbft.mempool.v1B\nTypesProtoP\x01Z4github.com/cometbft/cometbft/api/cometbft/mempool/v1\xa2\x02\x03\x43MX\xaa\x02\x13\x43ometbft.Mempool.V1\xca\x02\x13\x43ometbft\\Mempool\\V1\xe2\x02\x1f\x43ometbft\\Mempool\\V1\\GPBMetadata\xea\x02\x15\x43ometbft::Mempool::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.mempool.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.cometbft.mempool.v1B\nTypesProtoP\001Z4github.com/cometbft/cometbft/api/cometbft/mempool/v1\242\002\003CMX\252\002\023Cometbft.Mempool.V1\312\002\023Cometbft\\Mempool\\V1\342\002\037Cometbft\\Mempool\\V1\\GPBMetadata\352\002\025Cometbft::Mempool::V1'
  _globals['_TXS']._serialized_start=56
  _globals['_TXS']._serialized_end=79
  _globals['_MESSAGE']._serialized_start=81
  _globals['_MESSAGE']._serialized_end=143
# @@protoc_insertion_point(module_scope)
