# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/permissions/v1beta1/permissions.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/injective/permissions/v1beta1/permissions.proto\x12\x1dinjective.permissions.v1beta1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\"\x81\x04\n\tNamespace\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12#\n\rcontract_hook\x18\x02 \x01(\tR\x0c\x63ontractHook\x12N\n\x10role_permissions\x18\x03 \x03(\x0b\x32#.injective.permissions.v1beta1.RoleR\x0frolePermissions\x12J\n\x0b\x61\x63tor_roles\x18\x04 \x03(\x0b\x32).injective.permissions.v1beta1.ActorRolesR\nactorRoles\x12O\n\rrole_managers\x18\x05 \x03(\x0b\x32*.injective.permissions.v1beta1.RoleManagerR\x0croleManagers\x12T\n\x0fpolicy_statuses\x18\x06 \x03(\x0b\x32+.injective.permissions.v1beta1.PolicyStatusR\x0epolicyStatuses\x12v\n\x1bpolicy_manager_capabilities\x18\x07 \x03(\x0b\x32\x36.injective.permissions.v1beta1.PolicyManagerCapabilityR\x19policyManagerCapabilities\"8\n\nActorRoles\x12\x14\n\x05\x61\x63tor\x18\x01 \x01(\tR\x05\x61\x63tor\x12\x14\n\x05roles\x18\x02 \x03(\tR\x05roles\"8\n\nRoleActors\x12\x12\n\x04role\x18\x01 \x01(\tR\x04role\x12\x16\n\x06\x61\x63tors\x18\x02 \x03(\tR\x06\x61\x63tors\"=\n\x0bRoleManager\x12\x18\n\x07manager\x18\x01 \x01(\tR\x07manager\x12\x14\n\x05roles\x18\x02 \x03(\tR\x05roles\"\x8b\x01\n\x0cPolicyStatus\x12=\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32%.injective.permissions.v1beta1.ActionR\x06\x61\x63tion\x12\x1f\n\x0bis_disabled\x18\x02 \x01(\x08R\nisDisabled\x12\x1b\n\tis_sealed\x18\x03 \x01(\x08R\x08isSealed\"U\n\x04Role\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x17\n\x07role_id\x18\x02 \x01(\rR\x06roleId\x12 \n\x0bpermissions\x18\x03 \x01(\rR\x0bpermissions\"\xae\x01\n\x17PolicyManagerCapability\x12\x18\n\x07manager\x18\x01 \x01(\tR\x07manager\x12=\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32%.injective.permissions.v1beta1.ActionR\x06\x61\x63tion\x12\x1f\n\x0b\x63\x61n_disable\x18\x03 \x01(\x08R\ncanDisable\x12\x19\n\x08\x63\x61n_seal\x18\x04 \x01(\x08R\x07\x63\x61nSeal\"$\n\x07RoleIDs\x12\x19\n\x08role_ids\x18\x01 \x03(\rR\x07roleIds\"\xa5\x01\n\x0e\x41\x64\x64ressVoucher\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12y\n\x07voucher\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xc8\xde\x1f\x00\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\xea\xde\x1f\x11voucher,omitemptyR\x07voucher*\xd0\x01\n\x06\x41\x63tion\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04MINT\x10\x01\x12\x0b\n\x07RECEIVE\x10\x02\x12\x08\n\x04\x42URN\x10\x04\x12\x08\n\x04SEND\x10\x08\x12\x0e\n\nSUPER_BURN\x10\x10\x12\x1d\n\x16MODIFY_POLICY_MANAGERS\x10\x80\x80\x80@\x12\x1c\n\x14MODIFY_CONTRACT_HOOK\x10\x80\x80\x80\x80\x01\x12\x1f\n\x17MODIFY_ROLE_PERMISSIONS\x10\x80\x80\x80\x80\x02\x12\x1c\n\x14MODIFY_ROLE_MANAGERS\x10\x80\x80\x80\x80\x04\x42\x9e\x02\n!com.injective.permissions.v1beta1B\x10PermissionsProtoP\x01ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/permissions/types\xa2\x02\x03IPX\xaa\x02\x1dInjective.Permissions.V1beta1\xca\x02\x1dInjective\\Permissions\\V1beta1\xe2\x02)Injective\\Permissions\\V1beta1\\GPBMetadata\xea\x02\x1fInjective::Permissions::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.permissions.v1beta1.permissions_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.injective.permissions.v1beta1B\020PermissionsProtoP\001ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/permissions/types\242\002\003IPX\252\002\035Injective.Permissions.V1beta1\312\002\035Injective\\Permissions\\V1beta1\342\002)Injective\\Permissions\\V1beta1\\GPBMetadata\352\002\037Injective::Permissions::V1beta1'
  _globals['_ADDRESSVOUCHER'].fields_by_name['voucher']._loaded_options = None
  _globals['_ADDRESSVOUCHER'].fields_by_name['voucher']._serialized_options = b'\310\336\037\000\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin\352\336\037\021voucher,omitempty'
  _globals['_ACTION']._serialized_start=1444
  _globals['_ACTION']._serialized_end=1652
  _globals['_NAMESPACE']._serialized_start=137
  _globals['_NAMESPACE']._serialized_end=650
  _globals['_ACTORROLES']._serialized_start=652
  _globals['_ACTORROLES']._serialized_end=708
  _globals['_ROLEACTORS']._serialized_start=710
  _globals['_ROLEACTORS']._serialized_end=766
  _globals['_ROLEMANAGER']._serialized_start=768
  _globals['_ROLEMANAGER']._serialized_end=829
  _globals['_POLICYSTATUS']._serialized_start=832
  _globals['_POLICYSTATUS']._serialized_end=971
  _globals['_ROLE']._serialized_start=973
  _globals['_ROLE']._serialized_end=1058
  _globals['_POLICYMANAGERCAPABILITY']._serialized_start=1061
  _globals['_POLICYMANAGERCAPABILITY']._serialized_end=1235
  _globals['_ROLEIDS']._serialized_start=1237
  _globals['_ROLEIDS']._serialized_end=1273
  _globals['_ADDRESSVOUCHER']._serialized_start=1276
  _globals['_ADDRESSVOUCHER']._serialized_end=1441
# @@protoc_insertion_point(module_scope)
