# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/crypto/v1/keys.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63ometbft/crypto/v1/keys.proto\x12\x12\x63ometbft.crypto.v1\x1a\x14gogoproto/gogo.proto\"v\n\tPublicKey\x12\x1a\n\x07\x65\x64\x32\x35\x35\x31\x39\x18\x01 \x01(\x0cH\x00R\x07\x65\x64\x32\x35\x35\x31\x39\x12\x1e\n\tsecp256k1\x18\x02 \x01(\x0cH\x00R\tsecp256k1\x12\x1c\n\x08\x62ls12381\x18\x03 \x01(\x0cH\x00R\x08\x62ls12381:\x08\xe8\xa0\x1f\x01\xe8\xa1\x1f\x01\x42\x05\n\x03sumB\xc2\x01\n\x16\x63om.cometbft.crypto.v1B\tKeysProtoP\x01Z3github.com/cometbft/cometbft/api/cometbft/crypto/v1\xa2\x02\x03\x43\x43X\xaa\x02\x12\x43ometbft.Crypto.V1\xca\x02\x12\x43ometbft\\Crypto\\V1\xe2\x02\x1e\x43ometbft\\Crypto\\V1\\GPBMetadata\xea\x02\x14\x43ometbft::Crypto::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.crypto.v1.keys_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.cometbft.crypto.v1B\tKeysProtoP\001Z3github.com/cometbft/cometbft/api/cometbft/crypto/v1\242\002\003CCX\252\002\022Cometbft.Crypto.V1\312\002\022Cometbft\\Crypto\\V1\342\002\036Cometbft\\Crypto\\V1\\GPBMetadata\352\002\024Cometbft::Crypto::V1'
  _globals['_PUBLICKEY']._loaded_options = None
  _globals['_PUBLICKEY']._serialized_options = b'\350\240\037\001\350\241\037\001'
  _globals['_PUBLICKEY']._serialized_start=75
  _globals['_PUBLICKEY']._serialized_end=193
# @@protoc_insertion_point(module_scope)
