# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/p2p/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63ometbft/p2p/v1/types.proto\x12\x0f\x63ometbft.p2p.v1\x1a\x14gogoproto/gogo.proto\"P\n\nNetAddress\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xe2\xde\x1f\x02IDR\x02id\x12\x16\n\x02ip\x18\x02 \x01(\tB\x06\xe2\xde\x1f\x02IPR\x02ip\x12\x12\n\x04port\x18\x03 \x01(\rR\x04port\"T\n\x0fProtocolVersion\x12\x19\n\x03p2p\x18\x01 \x01(\x04\x42\x07\xe2\xde\x1f\x03P2PR\x03p2p\x12\x14\n\x05\x62lock\x18\x02 \x01(\x04R\x05\x62lock\x12\x10\n\x03\x61pp\x18\x03 \x01(\x04R\x03\x61pp\"\xed\x02\n\x0f\x44\x65\x66\x61ultNodeInfo\x12Q\n\x10protocol_version\x18\x01 \x01(\x0b\x32 .cometbft.p2p.v1.ProtocolVersionB\x04\xc8\xde\x1f\x00R\x0fprotocolVersion\x12\x39\n\x0f\x64\x65\x66\x61ult_node_id\x18\x02 \x01(\tB\x11\xe2\xde\x1f\rDefaultNodeIDR\rdefaultNodeId\x12\x1f\n\x0blisten_addr\x18\x03 \x01(\tR\nlistenAddr\x12\x18\n\x07network\x18\x04 \x01(\tR\x07network\x12\x18\n\x07version\x18\x05 \x01(\tR\x07version\x12\x1a\n\x08\x63hannels\x18\x06 \x01(\x0cR\x08\x63hannels\x12\x18\n\x07moniker\x18\x07 \x01(\tR\x07moniker\x12\x41\n\x05other\x18\x08 \x01(\x0b\x32%.cometbft.p2p.v1.DefaultNodeInfoOtherB\x04\xc8\xde\x1f\x00R\x05other\"b\n\x14\x44\x65\x66\x61ultNodeInfoOther\x12\x19\n\x08tx_index\x18\x01 \x01(\tR\x07txIndex\x12/\n\x0brpc_address\x18\x02 \x01(\tB\x0e\xe2\xde\x1f\nRPCAddressR\nrpcAddressB\xb1\x01\n\x13\x63om.cometbft.p2p.v1B\nTypesProtoP\x01Z0github.com/cometbft/cometbft/api/cometbft/p2p/v1\xa2\x02\x03\x43PX\xaa\x02\x0f\x43ometbft.P2p.V1\xca\x02\x0f\x43ometbft\\P2p\\V1\xe2\x02\x1b\x43ometbft\\P2p\\V1\\GPBMetadata\xea\x02\x11\x43ometbft::P2p::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.p2p.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.cometbft.p2p.v1B\nTypesProtoP\001Z0github.com/cometbft/cometbft/api/cometbft/p2p/v1\242\002\003CPX\252\002\017Cometbft.P2p.V1\312\002\017Cometbft\\P2p\\V1\342\002\033Cometbft\\P2p\\V1\\GPBMetadata\352\002\021Cometbft::P2p::V1'
  _globals['_NETADDRESS'].fields_by_name['id']._loaded_options = None
  _globals['_NETADDRESS'].fields_by_name['id']._serialized_options = b'\342\336\037\002ID'
  _globals['_NETADDRESS'].fields_by_name['ip']._loaded_options = None
  _globals['_NETADDRESS'].fields_by_name['ip']._serialized_options = b'\342\336\037\002IP'
  _globals['_PROTOCOLVERSION'].fields_by_name['p2p']._loaded_options = None
  _globals['_PROTOCOLVERSION'].fields_by_name['p2p']._serialized_options = b'\342\336\037\003P2P'
  _globals['_DEFAULTNODEINFO'].fields_by_name['protocol_version']._loaded_options = None
  _globals['_DEFAULTNODEINFO'].fields_by_name['protocol_version']._serialized_options = b'\310\336\037\000'
  _globals['_DEFAULTNODEINFO'].fields_by_name['default_node_id']._loaded_options = None
  _globals['_DEFAULTNODEINFO'].fields_by_name['default_node_id']._serialized_options = b'\342\336\037\rDefaultNodeID'
  _globals['_DEFAULTNODEINFO'].fields_by_name['other']._loaded_options = None
  _globals['_DEFAULTNODEINFO'].fields_by_name['other']._serialized_options = b'\310\336\037\000'
  _globals['_DEFAULTNODEINFOOTHER'].fields_by_name['rpc_address']._loaded_options = None
  _globals['_DEFAULTNODEINFOOTHER'].fields_by_name['rpc_address']._serialized_options = b'\342\336\037\nRPCAddress'
  _globals['_NETADDRESS']._serialized_start=70
  _globals['_NETADDRESS']._serialized_end=150
  _globals['_PROTOCOLVERSION']._serialized_start=152
  _globals['_PROTOCOLVERSION']._serialized_end=236
  _globals['_DEFAULTNODEINFO']._serialized_start=239
  _globals['_DEFAULTNODEINFO']._serialized_end=604
  _globals['_DEFAULTNODEINFOOTHER']._serialized_start=606
  _globals['_DEFAULTNODEINFOOTHER']._serialized_end=704
# @@protoc_insertion_point(module_scope)
