# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/proposal.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'injective/oracle/v1beta1/proposal.proto\x12\x18injective.oracle.v1beta1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a\x11\x61mino/amino.proto\"\xca\x01\n GrantBandOraclePrivilegeProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x1a\n\x08relayers\x18\x03 \x03(\tR\x08relayers:R\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*\'oracle/GrantBandOraclePrivilegeProposal\"\xcc\x01\n!RevokeBandOraclePrivilegeProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x1a\n\x08relayers\x18\x03 \x03(\tR\x08relayers:S\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*(oracle/RevokeBandOraclePrivilegeProposal\"\xf6\x01\n!GrantPriceFeederPrivilegeProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x12\n\x04\x62\x61se\x18\x03 \x01(\tR\x04\x62\x61se\x12\x14\n\x05quote\x18\x04 \x01(\tR\x05quote\x12\x1a\n\x08relayers\x18\x05 \x03(\tR\x08relayers:S\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*(oracle/GrantPriceFeederPrivilegeProposal\"\xe2\x01\n\x1eGrantProviderPrivilegeProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x1a\n\x08provider\x18\x03 \x01(\tR\x08provider\x12\x1a\n\x08relayers\x18\x04 \x03(\tR\x08relayers:P\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*%oracle/GrantProviderPrivilegeProposal\"\xe4\x01\n\x1fRevokeProviderPrivilegeProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x1a\n\x08provider\x18\x03 \x01(\tR\x08provider\x12\x1a\n\x08relayers\x18\x05 \x03(\tR\x08relayers:Q\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*&oracle/RevokeProviderPrivilegeProposal\"\xf8\x01\n\"RevokePriceFeederPrivilegeProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x12\n\x04\x62\x61se\x18\x03 \x01(\tR\x04\x62\x61se\x12\x14\n\x05quote\x18\x04 \x01(\tR\x05quote\x12\x1a\n\x08relayers\x18\x05 \x03(\tR\x08relayers:T\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*)oracle/RevokePriceFeederPrivilegeProposal\"\xff\x01\n\"AuthorizeBandOracleRequestProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12K\n\x07request\x18\x03 \x01(\x0b\x32+.injective.oracle.v1beta1.BandOracleRequestB\x04\xc8\xde\x1f\x00R\x07request:T\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*)oracle/AuthorizeBandOracleRequestProposal\"\xbb\x02\n\x1fUpdateBandOracleRequestProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12,\n\x12\x64\x65lete_request_ids\x18\x03 \x03(\x04R\x10\x64\x65leteRequestIds\x12_\n\x15update_oracle_request\x18\x04 \x01(\x0b\x32+.injective.oracle.v1beta1.BandOracleRequestR\x13updateOracleRequest:Q\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*&oracle/UpdateBandOracleRequestProposal\"\xef\x01\n\x15\x45nableBandIBCProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12U\n\x0f\x62\x61nd_ibc_params\x18\x03 \x01(\x0b\x32\'.injective.oracle.v1beta1.BandIBCParamsB\x04\xc8\xde\x1f\x00R\rbandIbcParams:G\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*\x1coracle/EnableBandIBCProposal\"\xe1\x01\n$GrantStorkPublisherPrivilegeProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12)\n\x10stork_publishers\x18\x03 \x03(\tR\x0fstorkPublishers:V\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*+oracle/GrantStorkPublisherPrivilegeProposal\"\xe3\x01\n%RevokeStorkPublisherPrivilegeProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12)\n\x10stork_publishers\x18\x03 \x03(\tR\x0fstorkPublishers:W\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*,oracle/RevokeStorkPublisherPrivilegeProposalB\xfd\x01\n\x1c\x63om.injective.oracle.v1beta1B\rProposalProtoP\x01ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\xa2\x02\x03IOX\xaa\x02\x18Injective.Oracle.V1beta1\xca\x02\x18Injective\\Oracle\\V1beta1\xe2\x02$Injective\\Oracle\\V1beta1\\GPBMetadata\xea\x02\x1aInjective::Oracle::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.oracle.v1beta1.proposal_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.injective.oracle.v1beta1B\rProposalProtoP\001ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\242\002\003IOX\252\002\030Injective.Oracle.V1beta1\312\002\030Injective\\Oracle\\V1beta1\342\002$Injective\\Oracle\\V1beta1\\GPBMetadata\352\002\032Injective::Oracle::V1beta1'
  _globals['_GRANTBANDORACLEPRIVILEGEPROPOSAL']._loaded_options = None
  _globals['_GRANTBANDORACLEPRIVILEGEPROPOSAL']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*\'oracle/GrantBandOraclePrivilegeProposal'
  _globals['_REVOKEBANDORACLEPRIVILEGEPROPOSAL']._loaded_options = None
  _globals['_REVOKEBANDORACLEPRIVILEGEPROPOSAL']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*(oracle/RevokeBandOraclePrivilegeProposal'
  _globals['_GRANTPRICEFEEDERPRIVILEGEPROPOSAL']._loaded_options = None
  _globals['_GRANTPRICEFEEDERPRIVILEGEPROPOSAL']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*(oracle/GrantPriceFeederPrivilegeProposal'
  _globals['_GRANTPROVIDERPRIVILEGEPROPOSAL']._loaded_options = None
  _globals['_GRANTPROVIDERPRIVILEGEPROPOSAL']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*%oracle/GrantProviderPrivilegeProposal'
  _globals['_REVOKEPROVIDERPRIVILEGEPROPOSAL']._loaded_options = None
  _globals['_REVOKEPROVIDERPRIVILEGEPROPOSAL']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*&oracle/RevokeProviderPrivilegeProposal'
  _globals['_REVOKEPRICEFEEDERPRIVILEGEPROPOSAL']._loaded_options = None
  _globals['_REVOKEPRICEFEEDERPRIVILEGEPROPOSAL']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*)oracle/RevokePriceFeederPrivilegeProposal'
  _globals['_AUTHORIZEBANDORACLEREQUESTPROPOSAL'].fields_by_name['request']._loaded_options = None
  _globals['_AUTHORIZEBANDORACLEREQUESTPROPOSAL'].fields_by_name['request']._serialized_options = b'\310\336\037\000'
  _globals['_AUTHORIZEBANDORACLEREQUESTPROPOSAL']._loaded_options = None
  _globals['_AUTHORIZEBANDORACLEREQUESTPROPOSAL']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*)oracle/AuthorizeBandOracleRequestProposal'
  _globals['_UPDATEBANDORACLEREQUESTPROPOSAL']._loaded_options = None
  _globals['_UPDATEBANDORACLEREQUESTPROPOSAL']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*&oracle/UpdateBandOracleRequestProposal'
  _globals['_ENABLEBANDIBCPROPOSAL'].fields_by_name['band_ibc_params']._loaded_options = None
  _globals['_ENABLEBANDIBCPROPOSAL'].fields_by_name['band_ibc_params']._serialized_options = b'\310\336\037\000'
  _globals['_ENABLEBANDIBCPROPOSAL']._loaded_options = None
  _globals['_ENABLEBANDIBCPROPOSAL']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*\034oracle/EnableBandIBCProposal'
  _globals['_GRANTSTORKPUBLISHERPRIVILEGEPROPOSAL']._loaded_options = None
  _globals['_GRANTSTORKPUBLISHERPRIVILEGEPROPOSAL']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*+oracle/GrantStorkPublisherPrivilegeProposal'
  _globals['_REVOKESTORKPUBLISHERPRIVILEGEPROPOSAL']._loaded_options = None
  _globals['_REVOKESTORKPUBLISHERPRIVILEGEPROPOSAL']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*,oracle/RevokeStorkPublisherPrivilegeProposal'
  _globals['_GRANTBANDORACLEPRIVILEGEPROPOSAL']._serialized_start=209
  _globals['_GRANTBANDORACLEPRIVILEGEPROPOSAL']._serialized_end=411
  _globals['_REVOKEBANDORACLEPRIVILEGEPROPOSAL']._serialized_start=414
  _globals['_REVOKEBANDORACLEPRIVILEGEPROPOSAL']._serialized_end=618
  _globals['_GRANTPRICEFEEDERPRIVILEGEPROPOSAL']._serialized_start=621
  _globals['_GRANTPRICEFEEDERPRIVILEGEPROPOSAL']._serialized_end=867
  _globals['_GRANTPROVIDERPRIVILEGEPROPOSAL']._serialized_start=870
  _globals['_GRANTPROVIDERPRIVILEGEPROPOSAL']._serialized_end=1096
  _globals['_REVOKEPROVIDERPRIVILEGEPROPOSAL']._serialized_start=1099
  _globals['_REVOKEPROVIDERPRIVILEGEPROPOSAL']._serialized_end=1327
  _globals['_REVOKEPRICEFEEDERPRIVILEGEPROPOSAL']._serialized_start=1330
  _globals['_REVOKEPRICEFEEDERPRIVILEGEPROPOSAL']._serialized_end=1578
  _globals['_AUTHORIZEBANDORACLEREQUESTPROPOSAL']._serialized_start=1581
  _globals['_AUTHORIZEBANDORACLEREQUESTPROPOSAL']._serialized_end=1836
  _globals['_UPDATEBANDORACLEREQUESTPROPOSAL']._serialized_start=1839
  _globals['_UPDATEBANDORACLEREQUESTPROPOSAL']._serialized_end=2154
  _globals['_ENABLEBANDIBCPROPOSAL']._serialized_start=2157
  _globals['_ENABLEBANDIBCPROPOSAL']._serialized_end=2396
  _globals['_GRANTSTORKPUBLISHERPRIVILEGEPROPOSAL']._serialized_start=2399
  _globals['_GRANTSTORKPUBLISHERPRIVILEGEPROPOSAL']._serialized_end=2624
  _globals['_REVOKESTORKPUBLISHERPRIVILEGEPROPOSAL']._serialized_start=2627
  _globals['_REVOKESTORKPUBLISHERPRIVILEGEPROPOSAL']._serialized_end=2854
# @@protoc_insertion_point(module_scope)
