# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/msgs.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.injective.peggy.v1 import types_pb2 as injective_dot_peggy_dot_v1_dot_types__pb2
from pyinjective.proto.injective.peggy.v1 import params_pb2 as injective_dot_peggy_dot_v1_dot_params__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dinjective/peggy/v1/msgs.proto\x12\x12injective.peggy.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1einjective/peggy/v1/types.proto\x1a\x1finjective/peggy/v1/params.proto\x1a\x19google/protobuf/any.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\xad\x01\n\x1bMsgSetOrchestratorAddresses\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\"\n\x0corchestrator\x18\x02 \x01(\tR\x0corchestrator\x12\x1f\n\x0b\x65th_address\x18\x03 \x01(\tR\nethAddress:1\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*!peggy/MsgSetOrchestratorAddresses\"%\n#MsgSetOrchestratorAddressesResponse\"\xb9\x01\n\x10MsgValsetConfirm\x12\x14\n\x05nonce\x18\x01 \x01(\x04R\x05nonce\x12\"\n\x0corchestrator\x18\x02 \x01(\tR\x0corchestrator\x12\x1f\n\x0b\x65th_address\x18\x03 \x01(\tR\nethAddress\x12\x1c\n\tsignature\x18\x04 \x01(\tR\tsignature:,\x82\xe7\xb0*\x0corchestrator\x8a\xe7\xb0*\x16peggy/MsgValsetConfirm\"\x1a\n\x18MsgValsetConfirmResponse\"\xde\x01\n\x0cMsgSendToEth\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x19\n\x08\x65th_dest\x18\x02 \x01(\tR\x07\x65thDest\x12\x37\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount\x12>\n\nbridge_fee\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\tbridgeFee:\"\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x12peggy/MsgSendToEth\"\x16\n\x14MsgSendToEthResponse\"x\n\x0fMsgRequestBatch\x12\"\n\x0corchestrator\x18\x01 \x01(\tR\x0corchestrator\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom:+\x82\xe7\xb0*\x0corchestrator\x8a\xe7\xb0*\x15peggy/MsgRequestBatch\"\x19\n\x17MsgRequestBatchResponse\"\xdc\x01\n\x0fMsgConfirmBatch\x12\x14\n\x05nonce\x18\x01 \x01(\x04R\x05nonce\x12%\n\x0etoken_contract\x18\x02 \x01(\tR\rtokenContract\x12\x1d\n\neth_signer\x18\x03 \x01(\tR\tethSigner\x12\"\n\x0corchestrator\x18\x04 \x01(\tR\x0corchestrator\x12\x1c\n\tsignature\x18\x05 \x01(\tR\tsignature:+\x82\xe7\xb0*\x0corchestrator\x8a\xe7\xb0*\x15peggy/MsgConfirmBatch\"\x19\n\x17MsgConfirmBatchResponse\"\xea\x02\n\x0fMsgDepositClaim\x12\x1f\n\x0b\x65vent_nonce\x18\x01 \x01(\x04R\neventNonce\x12!\n\x0c\x62lock_height\x18\x02 \x01(\x04R\x0b\x62lockHeight\x12%\n\x0etoken_contract\x18\x03 \x01(\tR\rtokenContract\x12\x35\n\x06\x61mount\x18\x04 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x06\x61mount\x12\'\n\x0f\x65thereum_sender\x18\x05 \x01(\tR\x0e\x65thereumSender\x12\'\n\x0f\x63osmos_receiver\x18\x06 \x01(\tR\x0e\x63osmosReceiver\x12\"\n\x0corchestrator\x18\x07 \x01(\tR\x0corchestrator\x12\x12\n\x04\x64\x61ta\x18\x08 \x01(\tR\x04\x64\x61ta:+\x82\xe7\xb0*\x0corchestrator\x8a\xe7\xb0*\x15peggy/MsgDepositClaim\"\x19\n\x17MsgDepositClaimResponse\"\xf0\x01\n\x10MsgWithdrawClaim\x12\x1f\n\x0b\x65vent_nonce\x18\x01 \x01(\x04R\neventNonce\x12!\n\x0c\x62lock_height\x18\x02 \x01(\x04R\x0b\x62lockHeight\x12\x1f\n\x0b\x62\x61tch_nonce\x18\x03 \x01(\x04R\nbatchNonce\x12%\n\x0etoken_contract\x18\x04 \x01(\tR\rtokenContract\x12\"\n\x0corchestrator\x18\x05 \x01(\tR\x0corchestrator:,\x82\xe7\xb0*\x0corchestrator\x8a\xe7\xb0*\x16peggy/MsgWithdrawClaim\"\x1a\n\x18MsgWithdrawClaimResponse\"\xc4\x02\n\x15MsgERC20DeployedClaim\x12\x1f\n\x0b\x65vent_nonce\x18\x01 \x01(\x04R\neventNonce\x12!\n\x0c\x62lock_height\x18\x02 \x01(\x04R\x0b\x62lockHeight\x12!\n\x0c\x63osmos_denom\x18\x03 \x01(\tR\x0b\x63osmosDenom\x12%\n\x0etoken_contract\x18\x04 \x01(\tR\rtokenContract\x12\x12\n\x04name\x18\x05 \x01(\tR\x04name\x12\x16\n\x06symbol\x18\x06 \x01(\tR\x06symbol\x12\x1a\n\x08\x64\x65\x63imals\x18\x07 \x01(\x04R\x08\x64\x65\x63imals\x12\"\n\x0corchestrator\x18\x08 \x01(\tR\x0corchestrator:1\x82\xe7\xb0*\x0corchestrator\x8a\xe7\xb0*\x1bpeggy/MsgERC20DeployedClaim\"\x1f\n\x1dMsgERC20DeployedClaimResponse\"}\n\x12MsgCancelSendToEth\x12%\n\x0etransaction_id\x18\x01 \x01(\x04R\rtransactionId\x12\x16\n\x06sender\x18\x02 \x01(\tR\x06sender:(\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x18peggy/MsgCancelSendToEth\"\x1c\n\x1aMsgCancelSendToEthResponse\"\xba\x01\n\x1dMsgSubmitBadSignatureEvidence\x12.\n\x07subject\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\x07subject\x12\x1c\n\tsignature\x18\x02 \x01(\tR\tsignature\x12\x16\n\x06sender\x18\x03 \x01(\tR\x06sender:3\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*#peggy/MsgSubmitBadSignatureEvidence\"\'\n%MsgSubmitBadSignatureEvidenceResponse\"\xfb\x02\n\x15MsgValsetUpdatedClaim\x12\x1f\n\x0b\x65vent_nonce\x18\x01 \x01(\x04R\neventNonce\x12!\n\x0cvalset_nonce\x18\x02 \x01(\x04R\x0bvalsetNonce\x12!\n\x0c\x62lock_height\x18\x03 \x01(\x04R\x0b\x62lockHeight\x12=\n\x07members\x18\x04 \x03(\x0b\x32#.injective.peggy.v1.BridgeValidatorR\x07members\x12\x42\n\rreward_amount\x18\x05 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x0crewardAmount\x12!\n\x0creward_token\x18\x06 \x01(\tR\x0brewardToken\x12\"\n\x0corchestrator\x18\x07 \x01(\tR\x0corchestrator:1\x82\xe7\xb0*\x0corchestrator\x8a\xe7\xb0*\x1bpeggy/MsgValsetUpdatedClaim\"\x1f\n\x1dMsgValsetUpdatedClaimResponse\"\xad\x01\n\x0fMsgUpdateParams\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12\x38\n\x06params\x18\x02 \x01(\x0b\x32\x1a.injective.peggy.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:(\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x15peggy/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"\x9d\x01\n\x1dMsgBlacklistEthereumAddresses\x12\x16\n\x06signer\x18\x01 \x01(\tR\x06signer\x12/\n\x13\x62lacklist_addresses\x18\x02 \x03(\tR\x12\x62lacklistAddresses:3\x82\xe7\xb0*\x06signer\x8a\xe7\xb0*#peggy/MsgBlacklistEthereumAddresses\"\'\n%MsgBlacklistEthereumAddressesResponse\"\x97\x01\n\x1aMsgRevokeEthereumBlacklist\x12\x16\n\x06signer\x18\x01 \x01(\tR\x06signer\x12/\n\x13\x62lacklist_addresses\x18\x02 \x03(\tR\x12\x62lacklistAddresses:0\x82\xe7\xb0*\x06signer\x8a\xe7\xb0* peggy/MsgRevokeEthereumBlacklist\"$\n\"MsgRevokeEthereumBlacklistResponse2\xbe\x10\n\x03Msg\x12\x8f\x01\n\rValsetConfirm\x12$.injective.peggy.v1.MsgValsetConfirm\x1a,.injective.peggy.v1.MsgValsetConfirmResponse\"*\x82\xd3\xe4\x93\x02$\"\"/injective/peggy/v1/valset_confirm\x12\x80\x01\n\tSendToEth\x12 .injective.peggy.v1.MsgSendToEth\x1a(.injective.peggy.v1.MsgSendToEthResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1f/injective/peggy/v1/send_to_eth\x12\x8b\x01\n\x0cRequestBatch\x12#.injective.peggy.v1.MsgRequestBatch\x1a+.injective.peggy.v1.MsgRequestBatchResponse\")\x82\xd3\xe4\x93\x02#\"!/injective/peggy/v1/request_batch\x12\x8b\x01\n\x0c\x43onfirmBatch\x12#.injective.peggy.v1.MsgConfirmBatch\x1a+.injective.peggy.v1.MsgConfirmBatchResponse\")\x82\xd3\xe4\x93\x02#\"!/injective/peggy/v1/confirm_batch\x12\x8b\x01\n\x0c\x44\x65positClaim\x12#.injective.peggy.v1.MsgDepositClaim\x1a+.injective.peggy.v1.MsgDepositClaimResponse\")\x82\xd3\xe4\x93\x02#\"!/injective/peggy/v1/deposit_claim\x12\x8f\x01\n\rWithdrawClaim\x12$.injective.peggy.v1.MsgWithdrawClaim\x1a,.injective.peggy.v1.MsgWithdrawClaimResponse\"*\x82\xd3\xe4\x93\x02$\"\"/injective/peggy/v1/withdraw_claim\x12\xa3\x01\n\x11ValsetUpdateClaim\x12).injective.peggy.v1.MsgValsetUpdatedClaim\x1a\x31.injective.peggy.v1.MsgValsetUpdatedClaimResponse\"0\x82\xd3\xe4\x93\x02*\"(/injective/peggy/v1/valset_updated_claim\x12\xa4\x01\n\x12\x45RC20DeployedClaim\x12).injective.peggy.v1.MsgERC20DeployedClaim\x1a\x31.injective.peggy.v1.MsgERC20DeployedClaimResponse\"0\x82\xd3\xe4\x93\x02*\"(/injective/peggy/v1/erc20_deployed_claim\x12\xba\x01\n\x18SetOrchestratorAddresses\x12/.injective.peggy.v1.MsgSetOrchestratorAddresses\x1a\x37.injective.peggy.v1.MsgSetOrchestratorAddressesResponse\"4\x82\xd3\xe4\x93\x02.\",/injective/peggy/v1/set_orchestrator_address\x12\x99\x01\n\x0f\x43\x61ncelSendToEth\x12&.injective.peggy.v1.MsgCancelSendToEth\x1a..injective.peggy.v1.MsgCancelSendToEthResponse\".\x82\xd3\xe4\x93\x02(\"&/injective/peggy/v1/cancel_send_to_eth\x12\xc5\x01\n\x1aSubmitBadSignatureEvidence\x12\x31.injective.peggy.v1.MsgSubmitBadSignatureEvidence\x1a\x39.injective.peggy.v1.MsgSubmitBadSignatureEvidenceResponse\"9\x82\xd3\xe4\x93\x02\x33\"1/injective/peggy/v1/submit_bad_signature_evidence\x12`\n\x0cUpdateParams\x12#.injective.peggy.v1.MsgUpdateParams\x1a+.injective.peggy.v1.MsgUpdateParamsResponse\x12\x8a\x01\n\x1a\x42lacklistEthereumAddresses\x12\x31.injective.peggy.v1.MsgBlacklistEthereumAddresses\x1a\x39.injective.peggy.v1.MsgBlacklistEthereumAddressesResponse\x12\x81\x01\n\x17RevokeEthereumBlacklist\x12..injective.peggy.v1.MsgRevokeEthereumBlacklist\x1a\x36.injective.peggy.v1.MsgRevokeEthereumBlacklistResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xda\x01\n\x16\x63om.injective.peggy.v1B\tMsgsProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types\xa2\x02\x03IPX\xaa\x02\x12Injective.Peggy.V1\xca\x02\x12Injective\\Peggy\\V1\xe2\x02\x1eInjective\\Peggy\\V1\\GPBMetadata\xea\x02\x14Injective::Peggy::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.peggy.v1.msgs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.injective.peggy.v1B\tMsgsProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types\242\002\003IPX\252\002\022Injective.Peggy.V1\312\002\022Injective\\Peggy\\V1\342\002\036Injective\\Peggy\\V1\\GPBMetadata\352\002\024Injective::Peggy::V1'
  _globals['_MSGSETORCHESTRATORADDRESSES']._loaded_options = None
  _globals['_MSGSETORCHESTRATORADDRESSES']._serialized_options = b'\202\347\260*\006sender\212\347\260*!peggy/MsgSetOrchestratorAddresses'
  _globals['_MSGVALSETCONFIRM']._loaded_options = None
  _globals['_MSGVALSETCONFIRM']._serialized_options = b'\202\347\260*\014orchestrator\212\347\260*\026peggy/MsgValsetConfirm'
  _globals['_MSGSENDTOETH'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGSENDTOETH'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSENDTOETH'].fields_by_name['bridge_fee']._loaded_options = None
  _globals['_MSGSENDTOETH'].fields_by_name['bridge_fee']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSENDTOETH']._loaded_options = None
  _globals['_MSGSENDTOETH']._serialized_options = b'\202\347\260*\006sender\212\347\260*\022peggy/MsgSendToEth'
  _globals['_MSGREQUESTBATCH']._loaded_options = None
  _globals['_MSGREQUESTBATCH']._serialized_options = b'\202\347\260*\014orchestrator\212\347\260*\025peggy/MsgRequestBatch'
  _globals['_MSGCONFIRMBATCH']._loaded_options = None
  _globals['_MSGCONFIRMBATCH']._serialized_options = b'\202\347\260*\014orchestrator\212\347\260*\025peggy/MsgConfirmBatch'
  _globals['_MSGDEPOSITCLAIM'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGDEPOSITCLAIM'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_MSGDEPOSITCLAIM']._loaded_options = None
  _globals['_MSGDEPOSITCLAIM']._serialized_options = b'\202\347\260*\014orchestrator\212\347\260*\025peggy/MsgDepositClaim'
  _globals['_MSGWITHDRAWCLAIM']._loaded_options = None
  _globals['_MSGWITHDRAWCLAIM']._serialized_options = b'\202\347\260*\014orchestrator\212\347\260*\026peggy/MsgWithdrawClaim'
  _globals['_MSGERC20DEPLOYEDCLAIM']._loaded_options = None
  _globals['_MSGERC20DEPLOYEDCLAIM']._serialized_options = b'\202\347\260*\014orchestrator\212\347\260*\033peggy/MsgERC20DeployedClaim'
  _globals['_MSGCANCELSENDTOETH']._loaded_options = None
  _globals['_MSGCANCELSENDTOETH']._serialized_options = b'\202\347\260*\006sender\212\347\260*\030peggy/MsgCancelSendToEth'
  _globals['_MSGSUBMITBADSIGNATUREEVIDENCE']._loaded_options = None
  _globals['_MSGSUBMITBADSIGNATUREEVIDENCE']._serialized_options = b'\202\347\260*\006sender\212\347\260*#peggy/MsgSubmitBadSignatureEvidence'
  _globals['_MSGVALSETUPDATEDCLAIM'].fields_by_name['reward_amount']._loaded_options = None
  _globals['_MSGVALSETUPDATEDCLAIM'].fields_by_name['reward_amount']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_MSGVALSETUPDATEDCLAIM']._loaded_options = None
  _globals['_MSGVALSETUPDATEDCLAIM']._serialized_options = b'\202\347\260*\014orchestrator\212\347\260*\033peggy/MsgValsetUpdatedClaim'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\025peggy/MsgUpdateParams'
  _globals['_MSGBLACKLISTETHEREUMADDRESSES']._loaded_options = None
  _globals['_MSGBLACKLISTETHEREUMADDRESSES']._serialized_options = b'\202\347\260*\006signer\212\347\260*#peggy/MsgBlacklistEthereumAddresses'
  _globals['_MSGREVOKEETHEREUMBLACKLIST']._loaded_options = None
  _globals['_MSGREVOKEETHEREUMBLACKLIST']._serialized_options = b'\202\347\260*\006signer\212\347\260* peggy/MsgRevokeEthereumBlacklist'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSG'].methods_by_name['ValsetConfirm']._loaded_options = None
  _globals['_MSG'].methods_by_name['ValsetConfirm']._serialized_options = b'\202\323\344\223\002$\"\"/injective/peggy/v1/valset_confirm'
  _globals['_MSG'].methods_by_name['SendToEth']._loaded_options = None
  _globals['_MSG'].methods_by_name['SendToEth']._serialized_options = b'\202\323\344\223\002!\"\037/injective/peggy/v1/send_to_eth'
  _globals['_MSG'].methods_by_name['RequestBatch']._loaded_options = None
  _globals['_MSG'].methods_by_name['RequestBatch']._serialized_options = b'\202\323\344\223\002#\"!/injective/peggy/v1/request_batch'
  _globals['_MSG'].methods_by_name['ConfirmBatch']._loaded_options = None
  _globals['_MSG'].methods_by_name['ConfirmBatch']._serialized_options = b'\202\323\344\223\002#\"!/injective/peggy/v1/confirm_batch'
  _globals['_MSG'].methods_by_name['DepositClaim']._loaded_options = None
  _globals['_MSG'].methods_by_name['DepositClaim']._serialized_options = b'\202\323\344\223\002#\"!/injective/peggy/v1/deposit_claim'
  _globals['_MSG'].methods_by_name['WithdrawClaim']._loaded_options = None
  _globals['_MSG'].methods_by_name['WithdrawClaim']._serialized_options = b'\202\323\344\223\002$\"\"/injective/peggy/v1/withdraw_claim'
  _globals['_MSG'].methods_by_name['ValsetUpdateClaim']._loaded_options = None
  _globals['_MSG'].methods_by_name['ValsetUpdateClaim']._serialized_options = b'\202\323\344\223\002*\"(/injective/peggy/v1/valset_updated_claim'
  _globals['_MSG'].methods_by_name['ERC20DeployedClaim']._loaded_options = None
  _globals['_MSG'].methods_by_name['ERC20DeployedClaim']._serialized_options = b'\202\323\344\223\002*\"(/injective/peggy/v1/erc20_deployed_claim'
  _globals['_MSG'].methods_by_name['SetOrchestratorAddresses']._loaded_options = None
  _globals['_MSG'].methods_by_name['SetOrchestratorAddresses']._serialized_options = b'\202\323\344\223\002.\",/injective/peggy/v1/set_orchestrator_address'
  _globals['_MSG'].methods_by_name['CancelSendToEth']._loaded_options = None
  _globals['_MSG'].methods_by_name['CancelSendToEth']._serialized_options = b'\202\323\344\223\002(\"&/injective/peggy/v1/cancel_send_to_eth'
  _globals['_MSG'].methods_by_name['SubmitBadSignatureEvidence']._loaded_options = None
  _globals['_MSG'].methods_by_name['SubmitBadSignatureEvidence']._serialized_options = b'\202\323\344\223\0023\"1/injective/peggy/v1/submit_bad_signature_evidence'
  _globals['_MSGSETORCHESTRATORADDRESSES']._serialized_start=301
  _globals['_MSGSETORCHESTRATORADDRESSES']._serialized_end=474
  _globals['_MSGSETORCHESTRATORADDRESSESRESPONSE']._serialized_start=476
  _globals['_MSGSETORCHESTRATORADDRESSESRESPONSE']._serialized_end=513
  _globals['_MSGVALSETCONFIRM']._serialized_start=516
  _globals['_MSGVALSETCONFIRM']._serialized_end=701
  _globals['_MSGVALSETCONFIRMRESPONSE']._serialized_start=703
  _globals['_MSGVALSETCONFIRMRESPONSE']._serialized_end=729
  _globals['_MSGSENDTOETH']._serialized_start=732
  _globals['_MSGSENDTOETH']._serialized_end=954
  _globals['_MSGSENDTOETHRESPONSE']._serialized_start=956
  _globals['_MSGSENDTOETHRESPONSE']._serialized_end=978
  _globals['_MSGREQUESTBATCH']._serialized_start=980
  _globals['_MSGREQUESTBATCH']._serialized_end=1100
  _globals['_MSGREQUESTBATCHRESPONSE']._serialized_start=1102
  _globals['_MSGREQUESTBATCHRESPONSE']._serialized_end=1127
  _globals['_MSGCONFIRMBATCH']._serialized_start=1130
  _globals['_MSGCONFIRMBATCH']._serialized_end=1350
  _globals['_MSGCONFIRMBATCHRESPONSE']._serialized_start=1352
  _globals['_MSGCONFIRMBATCHRESPONSE']._serialized_end=1377
  _globals['_MSGDEPOSITCLAIM']._serialized_start=1380
  _globals['_MSGDEPOSITCLAIM']._serialized_end=1742
  _globals['_MSGDEPOSITCLAIMRESPONSE']._serialized_start=1744
  _globals['_MSGDEPOSITCLAIMRESPONSE']._serialized_end=1769
  _globals['_MSGWITHDRAWCLAIM']._serialized_start=1772
  _globals['_MSGWITHDRAWCLAIM']._serialized_end=2012
  _globals['_MSGWITHDRAWCLAIMRESPONSE']._serialized_start=2014
  _globals['_MSGWITHDRAWCLAIMRESPONSE']._serialized_end=2040
  _globals['_MSGERC20DEPLOYEDCLAIM']._serialized_start=2043
  _globals['_MSGERC20DEPLOYEDCLAIM']._serialized_end=2367
  _globals['_MSGERC20DEPLOYEDCLAIMRESPONSE']._serialized_start=2369
  _globals['_MSGERC20DEPLOYEDCLAIMRESPONSE']._serialized_end=2400
  _globals['_MSGCANCELSENDTOETH']._serialized_start=2402
  _globals['_MSGCANCELSENDTOETH']._serialized_end=2527
  _globals['_MSGCANCELSENDTOETHRESPONSE']._serialized_start=2529
  _globals['_MSGCANCELSENDTOETHRESPONSE']._serialized_end=2557
  _globals['_MSGSUBMITBADSIGNATUREEVIDENCE']._serialized_start=2560
  _globals['_MSGSUBMITBADSIGNATUREEVIDENCE']._serialized_end=2746
  _globals['_MSGSUBMITBADSIGNATUREEVIDENCERESPONSE']._serialized_start=2748
  _globals['_MSGSUBMITBADSIGNATUREEVIDENCERESPONSE']._serialized_end=2787
  _globals['_MSGVALSETUPDATEDCLAIM']._serialized_start=2790
  _globals['_MSGVALSETUPDATEDCLAIM']._serialized_end=3169
  _globals['_MSGVALSETUPDATEDCLAIMRESPONSE']._serialized_start=3171
  _globals['_MSGVALSETUPDATEDCLAIMRESPONSE']._serialized_end=3202
  _globals['_MSGUPDATEPARAMS']._serialized_start=3205
  _globals['_MSGUPDATEPARAMS']._serialized_end=3378
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=3380
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=3405
  _globals['_MSGBLACKLISTETHEREUMADDRESSES']._serialized_start=3408
  _globals['_MSGBLACKLISTETHEREUMADDRESSES']._serialized_end=3565
  _globals['_MSGBLACKLISTETHEREUMADDRESSESRESPONSE']._serialized_start=3567
  _globals['_MSGBLACKLISTETHEREUMADDRESSESRESPONSE']._serialized_end=3606
  _globals['_MSGREVOKEETHEREUMBLACKLIST']._serialized_start=3609
  _globals['_MSGREVOKEETHEREUMBLACKLIST']._serialized_end=3760
  _globals['_MSGREVOKEETHEREUMBLACKLISTRESPONSE']._serialized_start=3762
  _globals['_MSGREVOKEETHEREUMBLACKLISTRESPONSE']._serialized_end=3798
  _globals['_MSG']._serialized_start=3801
  _globals['_MSG']._serialized_end=5911
# @@protoc_insertion_point(module_scope)
