# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/blocksync/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.types.v1 import block_pb2 as cometbft_dot_types_dot_v1_dot_block__pb2
from pyinjective.proto.cometbft.types.v1 import types_pb2 as cometbft_dot_types_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cometbft/blocksync/v1/types.proto\x12\x15\x63ometbft.blocksync.v1\x1a\x1d\x63ometbft/types/v1/block.proto\x1a\x1d\x63ometbft/types/v1/types.proto\"&\n\x0c\x42lockRequest\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\")\n\x0fNoBlockResponse\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\"\x0f\n\rStatusRequest\"<\n\x0eStatusResponse\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12\x12\n\x04\x62\x61se\x18\x02 \x01(\x03R\x04\x62\x61se\"\x81\x01\n\rBlockResponse\x12.\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x18.cometbft.types.v1.BlockR\x05\x62lock\x12@\n\next_commit\x18\x02 \x01(\x0b\x32!.cometbft.types.v1.ExtendedCommitR\textCommit\"\xa2\x03\n\x07Message\x12J\n\rblock_request\x18\x01 \x01(\x0b\x32#.cometbft.blocksync.v1.BlockRequestH\x00R\x0c\x62lockRequest\x12T\n\x11no_block_response\x18\x02 \x01(\x0b\x32&.cometbft.blocksync.v1.NoBlockResponseH\x00R\x0fnoBlockResponse\x12M\n\x0e\x62lock_response\x18\x03 \x01(\x0b\x32$.cometbft.blocksync.v1.BlockResponseH\x00R\rblockResponse\x12M\n\x0estatus_request\x18\x04 \x01(\x0b\x32$.cometbft.blocksync.v1.StatusRequestH\x00R\rstatusRequest\x12P\n\x0fstatus_response\x18\x05 \x01(\x0b\x32%.cometbft.blocksync.v1.StatusResponseH\x00R\x0estatusResponseB\x05\n\x03sumB\xd5\x01\n\x19\x63om.cometbft.blocksync.v1B\nTypesProtoP\x01Z6github.com/cometbft/cometbft/api/cometbft/blocksync/v1\xa2\x02\x03\x43\x42X\xaa\x02\x15\x43ometbft.Blocksync.V1\xca\x02\x15\x43ometbft\\Blocksync\\V1\xe2\x02!Cometbft\\Blocksync\\V1\\GPBMetadata\xea\x02\x17\x43ometbft::Blocksync::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.blocksync.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.cometbft.blocksync.v1B\nTypesProtoP\001Z6github.com/cometbft/cometbft/api/cometbft/blocksync/v1\242\002\003CBX\252\002\025Cometbft.Blocksync.V1\312\002\025Cometbft\\Blocksync\\V1\342\002!Cometbft\\Blocksync\\V1\\GPBMetadata\352\002\027Cometbft::Blocksync::V1'
  _globals['_BLOCKREQUEST']._serialized_start=122
  _globals['_BLOCKREQUEST']._serialized_end=160
  _globals['_NOBLOCKRESPONSE']._serialized_start=162
  _globals['_NOBLOCKRESPONSE']._serialized_end=203
  _globals['_STATUSREQUEST']._serialized_start=205
  _globals['_STATUSREQUEST']._serialized_end=220
  _globals['_STATUSRESPONSE']._serialized_start=222
  _globals['_STATUSRESPONSE']._serialized_end=282
  _globals['_BLOCKRESPONSE']._serialized_start=285
  _globals['_BLOCKRESPONSE']._serialized_end=414
  _globals['_MESSAGE']._serialized_start=417
  _globals['_MESSAGE']._serialized_end=835
# @@protoc_insertion_point(module_scope)
