# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/evm/v1/access_tuple.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#injective/evm/v1/access_tuple.proto\x12\x10injective.evm.v1\x1a\x14gogoproto/gogo.proto\"a\n\x0b\x41\x63\x63\x65ssTuple\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x32\n\x0cstorage_keys\x18\x02 \x03(\tB\x0f\xea\xde\x1f\x0bstorageKeysR\x0bstorageKeys:\x04\x88\xa0\x1f\x00\x42\xd5\x01\n\x14\x63om.injective.evm.v1B\x10\x41\x63\x63\x65ssTupleProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\xa2\x02\x03IEX\xaa\x02\x10Injective.Evm.V1\xca\x02\x10Injective\\Evm\\V1\xe2\x02\x1cInjective\\Evm\\V1\\GPBMetadata\xea\x02\x12Injective::Evm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.evm.v1.access_tuple_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.injective.evm.v1B\020AccessTupleProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\242\002\003IEX\252\002\020Injective.Evm.V1\312\002\020Injective\\Evm\\V1\342\002\034Injective\\Evm\\V1\\GPBMetadata\352\002\022Injective::Evm::V1'
  _globals['_ACCESSTUPLE'].fields_by_name['storage_keys']._loaded_options = None
  _globals['_ACCESSTUPLE'].fields_by_name['storage_keys']._serialized_options = b'\352\336\037\013storageKeys'
  _globals['_ACCESSTUPLE']._loaded_options = None
  _globals['_ACCESSTUPLE']._serialized_options = b'\210\240\037\000'
  _globals['_ACCESSTUPLE']._serialized_start=79
  _globals['_ACCESSTUPLE']._serialized_end=176
# @@protoc_insertion_point(module_scope)
