# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/types/v1beta1/tx_ext.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$injective/types/v1beta1/tx_ext.proto\x12\x17injective.types.v1beta1\x1a\x14gogoproto/gogo.proto\"\x88\x01\n\x16\x45xtensionOptionsWeb3Tx\x12*\n\x10typedDataChainID\x18\x01 \x01(\x04R\x10typedDataChainID\x12\x1a\n\x08\x66\x65\x65Payer\x18\x02 \x01(\tR\x08\x66\x65\x65Payer\x12 \n\x0b\x66\x65\x65PayerSig\x18\x03 \x01(\x0cR\x0b\x66\x65\x65PayerSig:\x04\x88\xa0\x1f\x00\x42\xe6\x01\n\x1b\x63om.injective.types.v1beta1B\nTxExtProtoP\x01Z=github.com/InjectiveLabs/injective-core/injective-chain/types\xa2\x02\x03ITX\xaa\x02\x17Injective.Types.V1beta1\xca\x02\x17Injective\\Types\\V1beta1\xe2\x02#Injective\\Types\\V1beta1\\GPBMetadata\xea\x02\x19Injective::Types::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.types.v1beta1.tx_ext_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.injective.types.v1beta1B\nTxExtProtoP\001Z=github.com/InjectiveLabs/injective-core/injective-chain/types\242\002\003ITX\252\002\027Injective.Types.V1beta1\312\002\027Injective\\Types\\V1beta1\342\002#Injective\\Types\\V1beta1\\GPBMetadata\352\002\031Injective::Types::V1beta1'
  _globals['_EXTENSIONOPTIONSWEB3TX']._loaded_options = None
  _globals['_EXTENSIONOPTIONSWEB3TX']._serialized_options = b'\210\240\037\000'
  _globals['_EXTENSIONOPTIONSWEB3TX']._serialized_start=88
  _globals['_EXTENSIONOPTIONSWEB3TX']._serialized_end=224
# @@protoc_insertion_point(module_scope)
