# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/txfees/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"osmosis/txfees/v1beta1/query.proto\x12\x16osmosis.txfees.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\"\x18\n\x16QueryEipBaseFeeRequest\"l\n\x17QueryEipBaseFeeResponse\x12Q\n\x08\x62\x61se_fee\x18\x01 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f\x0fyaml:\"base_fee\"R\x07\x62\x61seFee2\xac\x01\n\x05Query\x12\xa2\x01\n\rGetEipBaseFee\x12..osmosis.txfees.v1beta1.QueryEipBaseFeeRequest\x1a/.osmosis.txfees.v1beta1.QueryEipBaseFeeResponse\"0\x82\xd3\xe4\x93\x02*\x12(/osmosis/txfees/v1beta1/cur_eip_base_feeB\xf8\x01\n\x1a\x63om.osmosis.txfees.v1beta1B\nQueryProtoP\x01ZTgithub.com/InjectiveLabs/injective-core/injective-chain/modules/txfees/osmosis/types\xa2\x02\x03OTX\xaa\x02\x16Osmosis.Txfees.V1beta1\xca\x02\x16Osmosis\\Txfees\\V1beta1\xe2\x02\"Osmosis\\Txfees\\V1beta1\\GPBMetadata\xea\x02\x18Osmosis::Txfees::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.txfees.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.osmosis.txfees.v1beta1B\nQueryProtoP\001ZTgithub.com/InjectiveLabs/injective-core/injective-chain/modules/txfees/osmosis/types\242\002\003OTX\252\002\026Osmosis.Txfees.V1beta1\312\002\026Osmosis\\Txfees\\V1beta1\342\002\"Osmosis\\Txfees\\V1beta1\\GPBMetadata\352\002\030Osmosis::Txfees::V1beta1'
  _globals['_QUERYEIPBASEFEERESPONSE'].fields_by_name['base_fee']._loaded_options = None
  _globals['_QUERYEIPBASEFEERESPONSE'].fields_by_name['base_fee']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037\017yaml:\"base_fee\"'
  _globals['_QUERY'].methods_by_name['GetEipBaseFee']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetEipBaseFee']._serialized_options = b'\202\323\344\223\002*\022(/osmosis/txfees/v1beta1/cur_eip_base_fee'
  _globals['_QUERYEIPBASEFEEREQUEST']._serialized_start=146
  _globals['_QUERYEIPBASEFEEREQUEST']._serialized_end=170
  _globals['_QUERYEIPBASEFEERESPONSE']._serialized_start=172
  _globals['_QUERYEIPBASEFEERESPONSE']._serialized_end=280
  _globals['_QUERY']._serialized_start=283
  _globals['_QUERY']._serialized_end=455
# @@protoc_insertion_point(module_scope)
