# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_exchange_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%exchange/injective_exchange_rpc.proto\x12\x16injective_exchange_rpc\"\"\n\x0cGetTxRequest\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\"\xd3\x01\n\rGetTxResponse\x12\x17\n\x07tx_hash\x18\x01 \x01(\tR\x06txHash\x12\x16\n\x06height\x18\x02 \x01(\x12R\x06height\x12\x14\n\x05index\x18\x03 \x01(\rR\x05index\x12\x1c\n\tcodespace\x18\x04 \x01(\tR\tcodespace\x12\x12\n\x04\x63ode\x18\x05 \x01(\rR\x04\x63ode\x12\x12\n\x04\x64\x61ta\x18\x06 \x01(\x0cR\x04\x64\x61ta\x12\x17\n\x07raw_log\x18\x07 \x01(\tR\x06rawLog\x12\x1c\n\ttimestamp\x18\x08 \x01(\tR\ttimestamp\"\x9d\x02\n\x10PrepareTxRequest\x12\x19\n\x08\x63hain_id\x18\x01 \x01(\x04R\x07\x63hainId\x12%\n\x0esigner_address\x18\x02 \x01(\tR\rsignerAddress\x12\x1a\n\x08sequence\x18\x03 \x01(\x04R\x08sequence\x12\x12\n\x04memo\x18\x04 \x01(\tR\x04memo\x12%\n\x0etimeout_height\x18\x05 \x01(\x04R\rtimeoutHeight\x12\x35\n\x03\x66\x65\x65\x18\x06 \x01(\x0b\x32#.injective_exchange_rpc.CosmosTxFeeR\x03\x66\x65\x65\x12\x12\n\x04msgs\x18\x07 \x03(\x0cR\x04msgs\x12%\n\x0e\x65ip712_wrapper\x18\x08 \x01(\tR\reip712Wrapper\"|\n\x0b\x43osmosTxFee\x12\x38\n\x05price\x18\x01 \x03(\x0b\x32\".injective_exchange_rpc.CosmosCoinR\x05price\x12\x10\n\x03gas\x18\x02 \x01(\x04R\x03gas\x12!\n\x0c\x64\x65legate_fee\x18\x03 \x01(\x08R\x0b\x64\x65legateFee\":\n\nCosmosCoin\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\"\xc3\x01\n\x11PrepareTxResponse\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\tR\x04\x64\x61ta\x12\x1a\n\x08sequence\x18\x02 \x01(\x04R\x08sequence\x12\x1b\n\tsign_mode\x18\x03 \x01(\tR\x08signMode\x12 \n\x0cpub_key_type\x18\x04 \x01(\tR\npubKeyType\x12\x1b\n\tfee_payer\x18\x05 \x01(\tR\x08\x66\x65\x65Payer\x12\"\n\rfee_payer_sig\x18\x06 \x01(\tR\x0b\x66\x65\x65PayerSig\"\xc8\x02\n\x14PrepareEip712Request\x12\x19\n\x08\x63hain_id\x18\x01 \x01(\x04R\x07\x63hainId\x12%\n\x0esigner_address\x18\x02 \x01(\tR\rsignerAddress\x12\x1a\n\x08sequence\x18\x03 \x01(\x04R\x08sequence\x12%\n\x0e\x61\x63\x63ount_number\x18\x04 \x01(\x04R\raccountNumber\x12\x12\n\x04memo\x18\x05 \x01(\tR\x04memo\x12%\n\x0etimeout_height\x18\x06 \x01(\x04R\rtimeoutHeight\x12\x35\n\x03\x66\x65\x65\x18\x07 \x01(\x0b\x32#.injective_exchange_rpc.CosmosTxFeeR\x03\x66\x65\x65\x12\x12\n\x04msgs\x18\x08 \x03(\x0cR\x04msgs\x12%\n\x0e\x65ip712_wrapper\x18\t \x01(\tR\reip712Wrapper\"+\n\x15PrepareEip712Response\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\tR\x04\x64\x61ta\"\x85\x02\n\x12\x42roadcastTxRequest\x12\x19\n\x08\x63hain_id\x18\x01 \x01(\x04R\x07\x63hainId\x12\x0e\n\x02tx\x18\x02 \x01(\x0cR\x02tx\x12\x12\n\x04msgs\x18\x03 \x03(\x0cR\x04msgs\x12=\n\x07pub_key\x18\x04 \x01(\x0b\x32$.injective_exchange_rpc.CosmosPubKeyR\x06pubKey\x12\x1c\n\tsignature\x18\x05 \x01(\tR\tsignature\x12\x1b\n\tfee_payer\x18\x06 \x01(\tR\x08\x66\x65\x65Payer\x12\"\n\rfee_payer_sig\x18\x07 \x01(\tR\x0b\x66\x65\x65PayerSig\x12\x12\n\x04mode\x18\x08 \x01(\tR\x04mode\"4\n\x0c\x43osmosPubKey\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\"\xd9\x01\n\x13\x42roadcastTxResponse\x12\x17\n\x07tx_hash\x18\x01 \x01(\tR\x06txHash\x12\x16\n\x06height\x18\x02 \x01(\x12R\x06height\x12\x14\n\x05index\x18\x03 \x01(\rR\x05index\x12\x1c\n\tcodespace\x18\x04 \x01(\tR\tcodespace\x12\x12\n\x04\x63ode\x18\x05 \x01(\rR\x04\x63ode\x12\x12\n\x04\x64\x61ta\x18\x06 \x01(\x0cR\x04\x64\x61ta\x12\x17\n\x07raw_log\x18\x07 \x01(\tR\x06rawLog\x12\x1c\n\ttimestamp\x18\x08 \x01(\tR\ttimestamp\"\xe0\x01\n\x16PrepareCosmosTxRequest\x12\x19\n\x08\x63hain_id\x18\x01 \x01(\x04R\x07\x63hainId\x12%\n\x0esender_address\x18\x02 \x01(\tR\rsenderAddress\x12\x12\n\x04memo\x18\x03 \x01(\tR\x04memo\x12%\n\x0etimeout_height\x18\x04 \x01(\x04R\rtimeoutHeight\x12\x35\n\x03\x66\x65\x65\x18\x05 \x01(\x0b\x32#.injective_exchange_rpc.CosmosTxFeeR\x03\x66\x65\x65\x12\x12\n\x04msgs\x18\x06 \x03(\x0cR\x04msgs\"\xfa\x01\n\x17PrepareCosmosTxResponse\x12\x0e\n\x02tx\x18\x01 \x01(\x0cR\x02tx\x12\x1b\n\tsign_mode\x18\x02 \x01(\tR\x08signMode\x12 \n\x0cpub_key_type\x18\x03 \x01(\tR\npubKeyType\x12\x1b\n\tfee_payer\x18\x04 \x01(\tR\x08\x66\x65\x65Payer\x12\"\n\rfee_payer_sig\x18\x05 \x01(\tR\x0b\x66\x65\x65PayerSig\x12O\n\x11\x66\x65\x65_payer_pub_key\x18\x06 \x01(\x0b\x32$.injective_exchange_rpc.CosmosPubKeyR\x0e\x66\x65\x65PayerPubKey\"\xae\x01\n\x18\x42roadcastCosmosTxRequest\x12\x0e\n\x02tx\x18\x01 \x01(\x0cR\x02tx\x12=\n\x07pub_key\x18\x02 \x01(\x0b\x32$.injective_exchange_rpc.CosmosPubKeyR\x06pubKey\x12\x1c\n\tsignature\x18\x03 \x01(\tR\tsignature\x12%\n\x0esender_address\x18\x04 \x01(\tR\rsenderAddress\"\xdf\x01\n\x19\x42roadcastCosmosTxResponse\x12\x17\n\x07tx_hash\x18\x01 \x01(\tR\x06txHash\x12\x16\n\x06height\x18\x02 \x01(\x12R\x06height\x12\x14\n\x05index\x18\x03 \x01(\rR\x05index\x12\x1c\n\tcodespace\x18\x04 \x01(\tR\tcodespace\x12\x12\n\x04\x63ode\x18\x05 \x01(\rR\x04\x63ode\x12\x12\n\x04\x64\x61ta\x18\x06 \x01(\x0cR\x04\x64\x61ta\x12\x17\n\x07raw_log\x18\x07 \x01(\tR\x06rawLog\x12\x1c\n\ttimestamp\x18\x08 \x01(\tR\ttimestamp\"\x14\n\x12GetFeePayerRequest\"\x83\x01\n\x13GetFeePayerResponse\x12\x1b\n\tfee_payer\x18\x01 \x01(\tR\x08\x66\x65\x65Payer\x12O\n\x11\x66\x65\x65_payer_pub_key\x18\x02 \x01(\x0b\x32$.injective_exchange_rpc.CosmosPubKeyR\x0e\x66\x65\x65PayerPubKey2\xfa\x05\n\x14InjectiveExchangeRPC\x12T\n\x05GetTx\x12$.injective_exchange_rpc.GetTxRequest\x1a%.injective_exchange_rpc.GetTxResponse\x12`\n\tPrepareTx\x12(.injective_exchange_rpc.PrepareTxRequest\x1a).injective_exchange_rpc.PrepareTxResponse\x12l\n\rPrepareEip712\x12,.injective_exchange_rpc.PrepareEip712Request\x1a-.injective_exchange_rpc.PrepareEip712Response\x12\x66\n\x0b\x42roadcastTx\x12*.injective_exchange_rpc.BroadcastTxRequest\x1a+.injective_exchange_rpc.BroadcastTxResponse\x12r\n\x0fPrepareCosmosTx\x12..injective_exchange_rpc.PrepareCosmosTxRequest\x1a/.injective_exchange_rpc.PrepareCosmosTxResponse\x12x\n\x11\x42roadcastCosmosTx\x12\x30.injective_exchange_rpc.BroadcastCosmosTxRequest\x1a\x31.injective_exchange_rpc.BroadcastCosmosTxResponse\x12\x66\n\x0bGetFeePayer\x12*.injective_exchange_rpc.GetFeePayerRequest\x1a+.injective_exchange_rpc.GetFeePayerResponseB\xc2\x01\n\x1a\x63om.injective_exchange_rpcB\x19InjectiveExchangeRpcProtoP\x01Z\x19/injective_exchange_rpcpb\xa2\x02\x03IXX\xaa\x02\x14InjectiveExchangeRpc\xca\x02\x14InjectiveExchangeRpc\xe2\x02 InjectiveExchangeRpc\\GPBMetadata\xea\x02\x14InjectiveExchangeRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_exchange_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.injective_exchange_rpcB\031InjectiveExchangeRpcProtoP\001Z\031/injective_exchange_rpcpb\242\002\003IXX\252\002\024InjectiveExchangeRpc\312\002\024InjectiveExchangeRpc\342\002 InjectiveExchangeRpc\\GPBMetadata\352\002\024InjectiveExchangeRpc'
  _globals['_GETTXREQUEST']._serialized_start=65
  _globals['_GETTXREQUEST']._serialized_end=99
  _globals['_GETTXRESPONSE']._serialized_start=102
  _globals['_GETTXRESPONSE']._serialized_end=313
  _globals['_PREPARETXREQUEST']._serialized_start=316
  _globals['_PREPARETXREQUEST']._serialized_end=601
  _globals['_COSMOSTXFEE']._serialized_start=603
  _globals['_COSMOSTXFEE']._serialized_end=727
  _globals['_COSMOSCOIN']._serialized_start=729
  _globals['_COSMOSCOIN']._serialized_end=787
  _globals['_PREPARETXRESPONSE']._serialized_start=790
  _globals['_PREPARETXRESPONSE']._serialized_end=985
  _globals['_PREPAREEIP712REQUEST']._serialized_start=988
  _globals['_PREPAREEIP712REQUEST']._serialized_end=1316
  _globals['_PREPAREEIP712RESPONSE']._serialized_start=1318
  _globals['_PREPAREEIP712RESPONSE']._serialized_end=1361
  _globals['_BROADCASTTXREQUEST']._serialized_start=1364
  _globals['_BROADCASTTXREQUEST']._serialized_end=1625
  _globals['_COSMOSPUBKEY']._serialized_start=1627
  _globals['_COSMOSPUBKEY']._serialized_end=1679
  _globals['_BROADCASTTXRESPONSE']._serialized_start=1682
  _globals['_BROADCASTTXRESPONSE']._serialized_end=1899
  _globals['_PREPARECOSMOSTXREQUEST']._serialized_start=1902
  _globals['_PREPARECOSMOSTXREQUEST']._serialized_end=2126
  _globals['_PREPARECOSMOSTXRESPONSE']._serialized_start=2129
  _globals['_PREPARECOSMOSTXRESPONSE']._serialized_end=2379
  _globals['_BROADCASTCOSMOSTXREQUEST']._serialized_start=2382
  _globals['_BROADCASTCOSMOSTXREQUEST']._serialized_end=2556
  _globals['_BROADCASTCOSMOSTXRESPONSE']._serialized_start=2559
  _globals['_BROADCASTCOSMOSTXRESPONSE']._serialized_end=2782
  _globals['_GETFEEPAYERREQUEST']._serialized_start=2784
  _globals['_GETFEEPAYERREQUEST']._serialized_end=2804
  _globals['_GETFEEPAYERRESPONSE']._serialized_start=2807
  _globals['_GETFEEPAYERRESPONSE']._serialized_end=2938
  _globals['_INJECTIVEEXCHANGERPC']._serialized_start=2941
  _globals['_INJECTIVEEXCHANGERPC']._serialized_end=3703
# @@protoc_insertion_point(module_scope)
