# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/version/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63ometbft/version/v1/types.proto\x12\x13\x63ometbft.version.v1\x1a\x14gogoproto/gogo.proto\"=\n\x03\x41pp\x12\x1a\n\x08protocol\x18\x01 \x01(\x04R\x08protocol\x12\x1a\n\x08software\x18\x02 \x01(\tR\x08software\"9\n\tConsensus\x12\x14\n\x05\x62lock\x18\x01 \x01(\x04R\x05\x62lock\x12\x10\n\x03\x61pp\x18\x02 \x01(\x04R\x03\x61pp:\x04\xe8\xa0\x1f\x01\x42\xc9\x01\n\x17\x63om.cometbft.version.v1B\nTypesProtoP\x01Z4github.com/cometbft/cometbft/api/cometbft/version/v1\xa2\x02\x03\x43VX\xaa\x02\x13\x43ometbft.Version.V1\xca\x02\x13\x43ometbft\\Version\\V1\xe2\x02\x1f\x43ometbft\\Version\\V1\\GPBMetadata\xea\x02\x15\x43ometbft::Version::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.version.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.cometbft.version.v1B\nTypesProtoP\001Z4github.com/cometbft/cometbft/api/cometbft/version/v1\242\002\003CVX\252\002\023Cometbft.Version.V1\312\002\023Cometbft\\Version\\V1\342\002\037Cometbft\\Version\\V1\\GPBMetadata\352\002\025Cometbft::Version::V1'
  _globals['_CONSENSUS']._loaded_options = None
  _globals['_CONSENSUS']._serialized_options = b'\350\240\037\001'
  _globals['_APP']._serialized_start=78
  _globals['_APP']._serialized_end=139
  _globals['_CONSENSUS']._serialized_start=141
  _globals['_CONSENSUS']._serialized_end=198
# @@protoc_insertion_point(module_scope)
