# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/tokenfactory/v1beta1/authorityMetadata.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6injective/tokenfactory/v1beta1/authorityMetadata.proto\x12\x1einjective.tokenfactory.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x93\x01\n\x16\x44\x65nomAuthorityMetadata\x12&\n\x05\x61\x64min\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"admin\"R\x05\x61\x64min\x12K\n\x12\x61\x64min_burn_allowed\x18\x02 \x01(\x08\x42\x1d\xf2\xde\x1f\x19yaml:\"admin_burn_allowed\"R\x10\x61\x64minBurnAllowed:\x04\xe8\xa0\x1f\x01\x42\xaa\x02\n\"com.injective.tokenfactory.v1beta1B\x16\x41uthorityMetadataProtoP\x01ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types\xa2\x02\x03ITX\xaa\x02\x1eInjective.Tokenfactory.V1beta1\xca\x02\x1eInjective\\Tokenfactory\\V1beta1\xe2\x02*Injective\\Tokenfactory\\V1beta1\\GPBMetadata\xea\x02 Injective::Tokenfactory::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.tokenfactory.v1beta1.authorityMetadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.injective.tokenfactory.v1beta1B\026AuthorityMetadataProtoP\001ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types\242\002\003ITX\252\002\036Injective.Tokenfactory.V1beta1\312\002\036Injective\\Tokenfactory\\V1beta1\342\002*Injective\\Tokenfactory\\V1beta1\\GPBMetadata\352\002 Injective::Tokenfactory::V1beta1'
  _globals['_DENOMAUTHORITYMETADATA'].fields_by_name['admin']._loaded_options = None
  _globals['_DENOMAUTHORITYMETADATA'].fields_by_name['admin']._serialized_options = b'\362\336\037\014yaml:\"admin\"'
  _globals['_DENOMAUTHORITYMETADATA'].fields_by_name['admin_burn_allowed']._loaded_options = None
  _globals['_DENOMAUTHORITYMETADATA'].fields_by_name['admin_burn_allowed']._serialized_options = b'\362\336\037\031yaml:\"admin_burn_allowed\"'
  _globals['_DENOMAUTHORITYMETADATA']._loaded_options = None
  _globals['_DENOMAUTHORITYMETADATA']._serialized_options = b'\350\240\037\001'
  _globals['_DENOMAUTHORITYMETADATA']._serialized_start=145
  _globals['_DENOMAUTHORITYMETADATA']._serialized_end=292
# @@protoc_insertion_point(module_scope)
