# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/oracle.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%injective/oracle/v1beta1/oracle.proto\x12\x18injective.oracle.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x11\x61mino/amino.proto\"E\n\x06Params\x12#\n\rpyth_contract\x18\x01 \x01(\tR\x0cpythContract:\x16\xe8\xa0\x1f\x01\x8a\xe7\xb0*\roracle/Params\"k\n\nOracleInfo\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x45\n\x0boracle_type\x18\x02 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleTypeR\noracleType\"\xd6\x01\n\x13\x43hainlinkPriceState\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\tR\x06\x66\x65\x65\x64Id\x12;\n\x06\x61nswer\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06\x61nswer\x12\x1c\n\ttimestamp\x18\x03 \x01(\x04R\ttimestamp\x12K\n\x0bprice_state\x18\x04 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00R\npriceState\"\xea\x01\n\x0e\x42\x61ndPriceState\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x31\n\x04rate\x18\x02 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x04rate\x12!\n\x0cresolve_time\x18\x03 \x01(\x04R\x0bresolveTime\x12\x1d\n\nrequest_ID\x18\x04 \x01(\x04R\trequestID\x12K\n\x0bprice_state\x18\x05 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00R\npriceState\"\x9d\x01\n\x0ePriceFeedState\x12\x12\n\x04\x62\x61se\x18\x01 \x01(\tR\x04\x62\x61se\x12\x14\n\x05quote\x18\x02 \x01(\tR\x05quote\x12\x45\n\x0bprice_state\x18\x03 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateR\npriceState\x12\x1a\n\x08relayers\x18\x04 \x03(\tR\x08relayers\"F\n\x0cProviderInfo\x12\x1a\n\x08provider\x18\x01 \x01(\tR\x08provider\x12\x1a\n\x08relayers\x18\x02 \x03(\tR\x08relayers\"\xbe\x01\n\rProviderState\x12K\n\rprovider_info\x18\x01 \x01(\x0b\x32&.injective.oracle.v1beta1.ProviderInfoR\x0cproviderInfo\x12`\n\x15provider_price_states\x18\x02 \x03(\x0b\x32,.injective.oracle.v1beta1.ProviderPriceStateR\x13providerPriceStates\"h\n\x12ProviderPriceState\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12:\n\x05state\x18\x02 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateR\x05state\"9\n\rPriceFeedInfo\x12\x12\n\x04\x62\x61se\x18\x01 \x01(\tR\x04\x62\x61se\x12\x14\n\x05quote\x18\x02 \x01(\tR\x05quote\"K\n\x0ePriceFeedPrice\x12\x39\n\x05price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\"\xbb\x01\n\x12\x43oinbasePriceState\x12\x12\n\x04kind\x18\x01 \x01(\tR\x04kind\x12\x1c\n\ttimestamp\x18\x02 \x01(\x04R\ttimestamp\x12\x10\n\x03key\x18\x03 \x01(\tR\x03key\x12\x14\n\x05value\x18\x04 \x01(\x04R\x05value\x12K\n\x0bprice_state\x18\x05 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00R\npriceState\"\xcf\x01\n\x0fStorkPriceState\x12\x1c\n\ttimestamp\x18\x01 \x01(\x04R\ttimestamp\x12\x16\n\x06symbol\x18\x02 \x01(\tR\x06symbol\x12\x39\n\x05value\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05value\x12K\n\x0bprice_state\x18\x05 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00R\npriceState\"\xb5\x01\n\nPriceState\x12\x39\n\x05price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12N\n\x10\x63umulative_price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0f\x63umulativePrice\x12\x1c\n\ttimestamp\x18\x03 \x01(\x03R\ttimestamp\"\xd6\x02\n\x0ePythPriceState\x12\x19\n\x08price_id\x18\x01 \x01(\tR\x07priceId\x12@\n\tema_price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08\x65maPrice\x12>\n\x08\x65ma_conf\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x07\x65maConf\x12\x37\n\x04\x63onf\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x04\x63onf\x12!\n\x0cpublish_time\x18\x05 \x01(\x04R\x0bpublishTime\x12K\n\x0bprice_state\x18\x06 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00R\npriceState\"\x86\x03\n\x11\x42\x61ndOracleRequest\x12\x1d\n\nrequest_id\x18\x01 \x01(\x04R\trequestId\x12(\n\x10oracle_script_id\x18\x02 \x01(\x03R\x0eoracleScriptId\x12\x18\n\x07symbols\x18\x03 \x03(\tR\x07symbols\x12\x1b\n\task_count\x18\x04 \x01(\x04R\x08\x61skCount\x12\x1b\n\tmin_count\x18\x05 \x01(\x04R\x08minCount\x12h\n\tfee_limit\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.CoinsR\x08\x66\x65\x65Limit\x12\x1f\n\x0bprepare_gas\x18\x07 \x01(\x04R\nprepareGas\x12\x1f\n\x0b\x65xecute_gas\x18\x08 \x01(\x04R\nexecuteGas\x12(\n\x10min_source_count\x18\t \x01(\x04R\x0eminSourceCount\"\x86\x02\n\rBandIBCParams\x12(\n\x10\x62\x61nd_ibc_enabled\x18\x01 \x01(\x08R\x0e\x62\x61ndIbcEnabled\x12\x30\n\x14ibc_request_interval\x18\x02 \x01(\x03R\x12ibcRequestInterval\x12,\n\x12ibc_source_channel\x18\x03 \x01(\tR\x10ibcSourceChannel\x12\x1f\n\x0bibc_version\x18\x04 \x01(\tR\nibcVersion\x12\x1e\n\x0bibc_port_id\x18\x05 \x01(\tR\tibcPortId\x12*\n\x11legacy_oracle_ids\x18\x06 \x03(\x03R\x0flegacyOracleIds\"\x8f\x01\n\x14SymbolPriceTimestamp\x12<\n\x06oracle\x18\x01 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleTypeR\x06oracle\x12\x1b\n\tsymbol_id\x18\x02 \x01(\tR\x08symbolId\x12\x1c\n\ttimestamp\x18\x03 \x01(\x03R\ttimestamp\"y\n\x13LastPriceTimestamps\x12\x62\n\x15last_price_timestamps\x18\x01 \x03(\x0b\x32..injective.oracle.v1beta1.SymbolPriceTimestampR\x13lastPriceTimestamps\"\xc2\x01\n\x0cPriceRecords\x12<\n\x06oracle\x18\x01 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleTypeR\x06oracle\x12\x1b\n\tsymbol_id\x18\x02 \x01(\tR\x08symbolId\x12W\n\x14latest_price_records\x18\x03 \x03(\x0b\x32%.injective.oracle.v1beta1.PriceRecordR\x12latestPriceRecords\"f\n\x0bPriceRecord\x12\x1c\n\ttimestamp\x18\x01 \x01(\x03R\ttimestamp\x12\x39\n\x05price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\"\xf3\x03\n\x12MetadataStatistics\x12\x1f\n\x0bgroup_count\x18\x01 \x01(\rR\ngroupCount\x12.\n\x13records_sample_size\x18\x02 \x01(\rR\x11recordsSampleSize\x12\x37\n\x04mean\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x04mean\x12\x37\n\x04twap\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x04twap\x12\'\n\x0f\x66irst_timestamp\x18\x05 \x01(\x03R\x0e\x66irstTimestamp\x12%\n\x0elast_timestamp\x18\x06 \x01(\x03R\rlastTimestamp\x12@\n\tmin_price\x18\x07 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08minPrice\x12@\n\tmax_price\x18\x08 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08maxPrice\x12\x46\n\x0cmedian_price\x18\t \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0bmedianPrice\"\xe1\x01\n\x10PriceAttestation\x12\x19\n\x08price_id\x18\x01 \x01(\tR\x07priceId\x12\x14\n\x05price\x18\x02 \x01(\x03R\x05price\x12\x12\n\x04\x63onf\x18\x03 \x01(\x04R\x04\x63onf\x12\x12\n\x04\x65xpo\x18\x04 \x01(\x05R\x04\x65xpo\x12\x1b\n\tema_price\x18\x05 \x01(\x03R\x08\x65maPrice\x12\x19\n\x08\x65ma_conf\x18\x06 \x01(\x04R\x07\x65maConf\x12\x19\n\x08\x65ma_expo\x18\x07 \x01(\x05R\x07\x65maExpo\x12!\n\x0cpublish_time\x18\x08 \x01(\x03R\x0bpublishTime\"}\n\tAssetPair\x12\x19\n\x08\x61sset_id\x18\x01 \x01(\tR\x07\x61ssetId\x12U\n\rsigned_prices\x18\x02 \x03(\x0b\x32\x30.injective.oracle.v1beta1.SignedPriceOfAssetPairR\x0csignedPrices\"\xb4\x01\n\x16SignedPriceOfAssetPair\x12#\n\rpublisher_key\x18\x01 \x01(\tR\x0cpublisherKey\x12\x1c\n\ttimestamp\x18\x02 \x01(\x04R\ttimestamp\x12\x39\n\x05price\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12\x1c\n\tsignature\x18\x04 \x01(\x0cR\tsignature*\xaa\x01\n\nOracleType\x12\x0f\n\x0bUnspecified\x10\x00\x12\x08\n\x04\x42\x61nd\x10\x01\x12\r\n\tPriceFeed\x10\x02\x12\x0c\n\x08\x43oinbase\x10\x03\x12\r\n\tChainlink\x10\x04\x12\t\n\x05Razor\x10\x05\x12\x07\n\x03\x44ia\x10\x06\x12\x08\n\x04\x41PI3\x10\x07\x12\x07\n\x03Uma\x10\x08\x12\x08\n\x04Pyth\x10\t\x12\x0b\n\x07\x42\x61ndIBC\x10\n\x12\x0c\n\x08Provider\x10\x0b\x12\t\n\x05Stork\x10\x0c\x42\xff\x01\n\x1c\x63om.injective.oracle.v1beta1B\x0bOracleProtoP\x01ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\xa2\x02\x03IOX\xaa\x02\x18Injective.Oracle.V1beta1\xca\x02\x18Injective\\Oracle\\V1beta1\xe2\x02$Injective\\Oracle\\V1beta1\\GPBMetadata\xea\x02\x1aInjective::Oracle::V1beta1\xc0\xe3\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.oracle.v1beta1.oracle_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.injective.oracle.v1beta1B\013OracleProtoP\001ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\242\002\003IOX\252\002\030Injective.Oracle.V1beta1\312\002\030Injective\\Oracle\\V1beta1\342\002$Injective\\Oracle\\V1beta1\\GPBMetadata\352\002\032Injective::Oracle::V1beta1\300\343\036\001'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\350\240\037\001\212\347\260*\roracle/Params'
  _globals['_CHAINLINKPRICESTATE'].fields_by_name['answer']._loaded_options = None
  _globals['_CHAINLINKPRICESTATE'].fields_by_name['answer']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_CHAINLINKPRICESTATE'].fields_by_name['price_state']._loaded_options = None
  _globals['_CHAINLINKPRICESTATE'].fields_by_name['price_state']._serialized_options = b'\310\336\037\000'
  _globals['_BANDPRICESTATE'].fields_by_name['rate']._loaded_options = None
  _globals['_BANDPRICESTATE'].fields_by_name['rate']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_BANDPRICESTATE'].fields_by_name['price_state']._loaded_options = None
  _globals['_BANDPRICESTATE'].fields_by_name['price_state']._serialized_options = b'\310\336\037\000'
  _globals['_PRICEFEEDPRICE'].fields_by_name['price']._loaded_options = None
  _globals['_PRICEFEEDPRICE'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_COINBASEPRICESTATE'].fields_by_name['price_state']._loaded_options = None
  _globals['_COINBASEPRICESTATE'].fields_by_name['price_state']._serialized_options = b'\310\336\037\000'
  _globals['_STORKPRICESTATE'].fields_by_name['value']._loaded_options = None
  _globals['_STORKPRICESTATE'].fields_by_name['value']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_STORKPRICESTATE'].fields_by_name['price_state']._loaded_options = None
  _globals['_STORKPRICESTATE'].fields_by_name['price_state']._serialized_options = b'\310\336\037\000'
  _globals['_PRICESTATE'].fields_by_name['price']._loaded_options = None
  _globals['_PRICESTATE'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PRICESTATE'].fields_by_name['cumulative_price']._loaded_options = None
  _globals['_PRICESTATE'].fields_by_name['cumulative_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PYTHPRICESTATE'].fields_by_name['ema_price']._loaded_options = None
  _globals['_PYTHPRICESTATE'].fields_by_name['ema_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PYTHPRICESTATE'].fields_by_name['ema_conf']._loaded_options = None
  _globals['_PYTHPRICESTATE'].fields_by_name['ema_conf']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PYTHPRICESTATE'].fields_by_name['conf']._loaded_options = None
  _globals['_PYTHPRICESTATE'].fields_by_name['conf']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PYTHPRICESTATE'].fields_by_name['price_state']._loaded_options = None
  _globals['_PYTHPRICESTATE'].fields_by_name['price_state']._serialized_options = b'\310\336\037\000'
  _globals['_BANDORACLEREQUEST'].fields_by_name['fee_limit']._loaded_options = None
  _globals['_BANDORACLEREQUEST'].fields_by_name['fee_limit']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_PRICERECORD'].fields_by_name['price']._loaded_options = None
  _globals['_PRICERECORD'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_METADATASTATISTICS'].fields_by_name['mean']._loaded_options = None
  _globals['_METADATASTATISTICS'].fields_by_name['mean']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_METADATASTATISTICS'].fields_by_name['twap']._loaded_options = None
  _globals['_METADATASTATISTICS'].fields_by_name['twap']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_METADATASTATISTICS'].fields_by_name['min_price']._loaded_options = None
  _globals['_METADATASTATISTICS'].fields_by_name['min_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_METADATASTATISTICS'].fields_by_name['max_price']._loaded_options = None
  _globals['_METADATASTATISTICS'].fields_by_name['max_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_METADATASTATISTICS'].fields_by_name['median_price']._loaded_options = None
  _globals['_METADATASTATISTICS'].fields_by_name['median_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SIGNEDPRICEOFASSETPAIR'].fields_by_name['price']._loaded_options = None
  _globals['_SIGNEDPRICEOFASSETPAIR'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_ORACLETYPE']._serialized_start=4639
  _globals['_ORACLETYPE']._serialized_end=4809
  _globals['_PARAMS']._serialized_start=140
  _globals['_PARAMS']._serialized_end=209
  _globals['_ORACLEINFO']._serialized_start=211
  _globals['_ORACLEINFO']._serialized_end=318
  _globals['_CHAINLINKPRICESTATE']._serialized_start=321
  _globals['_CHAINLINKPRICESTATE']._serialized_end=535
  _globals['_BANDPRICESTATE']._serialized_start=538
  _globals['_BANDPRICESTATE']._serialized_end=772
  _globals['_PRICEFEEDSTATE']._serialized_start=775
  _globals['_PRICEFEEDSTATE']._serialized_end=932
  _globals['_PROVIDERINFO']._serialized_start=934
  _globals['_PROVIDERINFO']._serialized_end=1004
  _globals['_PROVIDERSTATE']._serialized_start=1007
  _globals['_PROVIDERSTATE']._serialized_end=1197
  _globals['_PROVIDERPRICESTATE']._serialized_start=1199
  _globals['_PROVIDERPRICESTATE']._serialized_end=1303
  _globals['_PRICEFEEDINFO']._serialized_start=1305
  _globals['_PRICEFEEDINFO']._serialized_end=1362
  _globals['_PRICEFEEDPRICE']._serialized_start=1364
  _globals['_PRICEFEEDPRICE']._serialized_end=1439
  _globals['_COINBASEPRICESTATE']._serialized_start=1442
  _globals['_COINBASEPRICESTATE']._serialized_end=1629
  _globals['_STORKPRICESTATE']._serialized_start=1632
  _globals['_STORKPRICESTATE']._serialized_end=1839
  _globals['_PRICESTATE']._serialized_start=1842
  _globals['_PRICESTATE']._serialized_end=2023
  _globals['_PYTHPRICESTATE']._serialized_start=2026
  _globals['_PYTHPRICESTATE']._serialized_end=2368
  _globals['_BANDORACLEREQUEST']._serialized_start=2371
  _globals['_BANDORACLEREQUEST']._serialized_end=2761
  _globals['_BANDIBCPARAMS']._serialized_start=2764
  _globals['_BANDIBCPARAMS']._serialized_end=3026
  _globals['_SYMBOLPRICETIMESTAMP']._serialized_start=3029
  _globals['_SYMBOLPRICETIMESTAMP']._serialized_end=3172
  _globals['_LASTPRICETIMESTAMPS']._serialized_start=3174
  _globals['_LASTPRICETIMESTAMPS']._serialized_end=3295
  _globals['_PRICERECORDS']._serialized_start=3298
  _globals['_PRICERECORDS']._serialized_end=3492
  _globals['_PRICERECORD']._serialized_start=3494
  _globals['_PRICERECORD']._serialized_end=3596
  _globals['_METADATASTATISTICS']._serialized_start=3599
  _globals['_METADATASTATISTICS']._serialized_end=4098
  _globals['_PRICEATTESTATION']._serialized_start=4101
  _globals['_PRICEATTESTATION']._serialized_end=4326
  _globals['_ASSETPAIR']._serialized_start=4328
  _globals['_ASSETPAIR']._serialized_end=4453
  _globals['_SIGNEDPRICEOFASSETPAIR']._serialized_start=4456
  _globals['_SIGNEDPRICEOFASSETPAIR']._serialized_end=4636
# @@protoc_insertion_point(module_scope)
