# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/libs/bits/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cometbft/libs/bits/v1/types.proto\x12\x15\x63ometbft.libs.bits.v1\"4\n\x08\x42itArray\x12\x12\n\x04\x62its\x18\x01 \x01(\x03R\x04\x62its\x12\x14\n\x05\x65lems\x18\x02 \x03(\x04R\x05\x65lemsB\xd6\x01\n\x19\x63om.cometbft.libs.bits.v1B\nTypesProtoP\x01Z6github.com/cometbft/cometbft/api/cometbft/libs/bits/v1\xa2\x02\x03\x43LB\xaa\x02\x15\x43ometbft.Libs.Bits.V1\xca\x02\x15\x43ometbft\\Libs\\Bits\\V1\xe2\x02!Cometbft\\Libs\\Bits\\V1\\GPBMetadata\xea\x02\x18\x43ometbft::Libs::Bits::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.libs.bits.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.cometbft.libs.bits.v1B\nTypesProtoP\001Z6github.com/cometbft/cometbft/api/cometbft/libs/bits/v1\242\002\003CLB\252\002\025Cometbft.Libs.Bits.V1\312\002\025Cometbft\\Libs\\Bits\\V1\342\002!Cometbft\\Libs\\Bits\\V1\\GPBMetadata\352\002\030Cometbft::Libs::Bits::V1'
  _globals['_BITARRAY']._serialized_start=60
  _globals['_BITARRAY']._serialized_end=112
# @@protoc_insertion_point(module_scope)
