# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/evm/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.injective.evm.v1 import params_pb2 as injective_dot_evm_dot_v1_dot_params__pb2
from pyinjective.proto.injective.evm.v1 import state_pb2 as injective_dot_evm_dot_v1_dot_state__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1einjective/evm/v1/genesis.proto\x12\x10injective.evm.v1\x1a\x1dinjective/evm/v1/params.proto\x1a\x1cinjective/evm/v1/state.proto\x1a\x14gogoproto/gogo.proto\"\x8a\x01\n\x0cGenesisState\x12\x42\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32 .injective.evm.v1.GenesisAccountB\x04\xc8\xde\x1f\x00R\x08\x61\x63\x63ounts\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32\x18.injective.evm.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"\x82\x01\n\x0eGenesisAccount\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x12\n\x04\x63ode\x18\x02 \x01(\tR\x04\x63ode\x12\x42\n\x07storage\x18\x03 \x03(\x0b\x32\x17.injective.evm.v1.StateB\x0f\xc8\xde\x1f\x00\xaa\xdf\x1f\x07StorageR\x07storageB\xd1\x01\n\x14\x63om.injective.evm.v1B\x0cGenesisProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\xa2\x02\x03IEX\xaa\x02\x10Injective.Evm.V1\xca\x02\x10Injective\\Evm\\V1\xe2\x02\x1cInjective\\Evm\\V1\\GPBMetadata\xea\x02\x12Injective::Evm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.evm.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.injective.evm.v1B\014GenesisProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\242\002\003IEX\252\002\020Injective.Evm.V1\312\002\020Injective\\Evm\\V1\342\002\034Injective\\Evm\\V1\\GPBMetadata\352\002\022Injective::Evm::V1'
  _globals['_GENESISSTATE'].fields_by_name['accounts']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['accounts']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISACCOUNT'].fields_by_name['storage']._loaded_options = None
  _globals['_GENESISACCOUNT'].fields_by_name['storage']._serialized_options = b'\310\336\037\000\252\337\037\007Storage'
  _globals['_GENESISSTATE']._serialized_start=136
  _globals['_GENESISSTATE']._serialized_end=274
  _globals['_GENESISACCOUNT']._serialized_start=277
  _globals['_GENESISACCOUNT']._serialized_end=407
# @@protoc_insertion_point(module_scope)
