# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/privval/v1beta2/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.crypto.v1 import keys_pb2 as cometbft_dot_crypto_dot_v1_dot_keys__pb2
from pyinjective.proto.cometbft.types.v1 import types_pb2 as cometbft_dot_types_dot_v1_dot_types__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cometbft/privval/v1beta2/types.proto\x12\x18\x63ometbft.privval.v1beta2\x1a\x1d\x63ometbft/crypto/v1/keys.proto\x1a\x1d\x63ometbft/types/v1/types.proto\x1a\x14gogoproto/gogo.proto\"I\n\x11RemoteSignerError\x12\x12\n\x04\x63ode\x18\x01 \x01(\x05R\x04\x63ode\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\"*\n\rPubKeyRequest\x12\x19\n\x08\x63hain_id\x18\x01 \x01(\tR\x07\x63hainId\"\x91\x01\n\x0ePubKeyResponse\x12<\n\x07pub_key\x18\x01 \x01(\x0b\x32\x1d.cometbft.crypto.v1.PublicKeyB\x04\xc8\xde\x1f\x00R\x06pubKey\x12\x41\n\x05\x65rror\x18\x02 \x01(\x0b\x32+.cometbft.privval.v1beta2.RemoteSignerErrorR\x05\x65rror\"Y\n\x0fSignVoteRequest\x12+\n\x04vote\x18\x01 \x01(\x0b\x32\x17.cometbft.types.v1.VoteR\x04vote\x12\x19\n\x08\x63hain_id\x18\x02 \x01(\tR\x07\x63hainId\"\x8a\x01\n\x12SignedVoteResponse\x12\x31\n\x04vote\x18\x01 \x01(\x0b\x32\x17.cometbft.types.v1.VoteB\x04\xc8\xde\x1f\x00R\x04vote\x12\x41\n\x05\x65rror\x18\x02 \x01(\x0b\x32+.cometbft.privval.v1beta2.RemoteSignerErrorR\x05\x65rror\"i\n\x13SignProposalRequest\x12\x37\n\x08proposal\x18\x01 \x01(\x0b\x32\x1b.cometbft.types.v1.ProposalR\x08proposal\x12\x19\n\x08\x63hain_id\x18\x02 \x01(\tR\x07\x63hainId\"\x9a\x01\n\x16SignedProposalResponse\x12=\n\x08proposal\x18\x01 \x01(\x0b\x32\x1b.cometbft.types.v1.ProposalB\x04\xc8\xde\x1f\x00R\x08proposal\x12\x41\n\x05\x65rror\x18\x02 \x01(\x0b\x32+.cometbft.privval.v1beta2.RemoteSignerErrorR\x05\x65rror\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\xe2\x05\n\x07Message\x12Q\n\x0fpub_key_request\x18\x01 \x01(\x0b\x32\'.cometbft.privval.v1beta2.PubKeyRequestH\x00R\rpubKeyRequest\x12T\n\x10pub_key_response\x18\x02 \x01(\x0b\x32(.cometbft.privval.v1beta2.PubKeyResponseH\x00R\x0epubKeyResponse\x12W\n\x11sign_vote_request\x18\x03 \x01(\x0b\x32).cometbft.privval.v1beta2.SignVoteRequestH\x00R\x0fsignVoteRequest\x12`\n\x14signed_vote_response\x18\x04 \x01(\x0b\x32,.cometbft.privval.v1beta2.SignedVoteResponseH\x00R\x12signedVoteResponse\x12\x63\n\x15sign_proposal_request\x18\x05 \x01(\x0b\x32-.cometbft.privval.v1beta2.SignProposalRequestH\x00R\x13signProposalRequest\x12l\n\x18signed_proposal_response\x18\x06 \x01(\x0b\x32\x30.cometbft.privval.v1beta2.SignedProposalResponseH\x00R\x16signedProposalResponse\x12J\n\x0cping_request\x18\x07 \x01(\x0b\x32%.cometbft.privval.v1beta2.PingRequestH\x00R\x0bpingRequest\x12M\n\rping_response\x18\x08 \x01(\x0b\x32&.cometbft.privval.v1beta2.PingResponseH\x00R\x0cpingResponseB\x05\n\x03sum*\xa8\x01\n\x06\x45rrors\x12\x12\n\x0e\x45RRORS_UNKNOWN\x10\x00\x12\x1e\n\x1a\x45RRORS_UNEXPECTED_RESPONSE\x10\x01\x12\x18\n\x14\x45RRORS_NO_CONNECTION\x10\x02\x12\x1d\n\x19\x45RRORS_CONNECTION_TIMEOUT\x10\x03\x12\x17\n\x13\x45RRORS_READ_TIMEOUT\x10\x04\x12\x18\n\x14\x45RRORS_WRITE_TIMEOUT\x10\x05\x42\xe7\x01\n\x1c\x63om.cometbft.privval.v1beta2B\nTypesProtoP\x01Z9github.com/cometbft/cometbft/api/cometbft/privval/v1beta2\xa2\x02\x03\x43PX\xaa\x02\x18\x43ometbft.Privval.V1beta2\xca\x02\x18\x43ometbft\\Privval\\V1beta2\xe2\x02$Cometbft\\Privval\\V1beta2\\GPBMetadata\xea\x02\x1a\x43ometbft::Privval::V1beta2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.privval.v1beta2.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.cometbft.privval.v1beta2B\nTypesProtoP\001Z9github.com/cometbft/cometbft/api/cometbft/privval/v1beta2\242\002\003CPX\252\002\030Cometbft.Privval.V1beta2\312\002\030Cometbft\\Privval\\V1beta2\342\002$Cometbft\\Privval\\V1beta2\\GPBMetadata\352\002\032Cometbft::Privval::V1beta2'
  _globals['_PUBKEYRESPONSE'].fields_by_name['pub_key']._loaded_options = None
  _globals['_PUBKEYRESPONSE'].fields_by_name['pub_key']._serialized_options = b'\310\336\037\000'
  _globals['_SIGNEDVOTERESPONSE'].fields_by_name['vote']._loaded_options = None
  _globals['_SIGNEDVOTERESPONSE'].fields_by_name['vote']._serialized_options = b'\310\336\037\000'
  _globals['_SIGNEDPROPOSALRESPONSE'].fields_by_name['proposal']._loaded_options = None
  _globals['_SIGNEDPROPOSALRESPONSE'].fields_by_name['proposal']._serialized_options = b'\310\336\037\000'
  _globals['_ERRORS']._serialized_start=1686
  _globals['_ERRORS']._serialized_end=1854
  _globals['_REMOTESIGNERERROR']._serialized_start=150
  _globals['_REMOTESIGNERERROR']._serialized_end=223
  _globals['_PUBKEYREQUEST']._serialized_start=225
  _globals['_PUBKEYREQUEST']._serialized_end=267
  _globals['_PUBKEYRESPONSE']._serialized_start=270
  _globals['_PUBKEYRESPONSE']._serialized_end=415
  _globals['_SIGNVOTEREQUEST']._serialized_start=417
  _globals['_SIGNVOTEREQUEST']._serialized_end=506
  _globals['_SIGNEDVOTERESPONSE']._serialized_start=509
  _globals['_SIGNEDVOTERESPONSE']._serialized_end=647
  _globals['_SIGNPROPOSALREQUEST']._serialized_start=649
  _globals['_SIGNPROPOSALREQUEST']._serialized_end=754
  _globals['_SIGNEDPROPOSALRESPONSE']._serialized_start=757
  _globals['_SIGNEDPROPOSALRESPONSE']._serialized_end=911
  _globals['_PINGREQUEST']._serialized_start=913
  _globals['_PINGREQUEST']._serialized_end=926
  _globals['_PINGRESPONSE']._serialized_start=928
  _globals['_PINGRESPONSE']._serialized_end=942
  _globals['_MESSAGE']._serialized_start=945
  _globals['_MESSAGE']._serialized_end=1683
# @@protoc_insertion_point(module_scope)
