# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/p2p/v1/conn.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cometbft.crypto.v1 import keys_pb2 as cometbft_dot_crypto_dot_v1_dot_keys__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63ometbft/p2p/v1/conn.proto\x12\x0f\x63ometbft.p2p.v1\x1a\x14gogoproto/gogo.proto\x1a\x1d\x63ometbft/crypto/v1/keys.proto\"\x0c\n\nPacketPing\"\x0c\n\nPacketPong\"h\n\tPacketMsg\x12,\n\nchannel_id\x18\x01 \x01(\x05\x42\r\xe2\xde\x1f\tChannelIDR\tchannelId\x12\x19\n\x03\x65of\x18\x02 \x01(\x08\x42\x07\xe2\xde\x1f\x03\x45OFR\x03\x65of\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\"\xcc\x01\n\x06Packet\x12>\n\x0bpacket_ping\x18\x01 \x01(\x0b\x32\x1b.cometbft.p2p.v1.PacketPingH\x00R\npacketPing\x12>\n\x0bpacket_pong\x18\x02 \x01(\x0b\x32\x1b.cometbft.p2p.v1.PacketPongH\x00R\npacketPong\x12;\n\npacket_msg\x18\x03 \x01(\x0b\x32\x1a.cometbft.p2p.v1.PacketMsgH\x00R\tpacketMsgB\x05\n\x03sum\"`\n\x0e\x41uthSigMessage\x12<\n\x07pub_key\x18\x01 \x01(\x0b\x32\x1d.cometbft.crypto.v1.PublicKeyB\x04\xc8\xde\x1f\x00R\x06pubKey\x12\x10\n\x03sig\x18\x02 \x01(\x0cR\x03sigB\xb0\x01\n\x13\x63om.cometbft.p2p.v1B\tConnProtoP\x01Z0github.com/cometbft/cometbft/api/cometbft/p2p/v1\xa2\x02\x03\x43PX\xaa\x02\x0f\x43ometbft.P2p.V1\xca\x02\x0f\x43ometbft\\P2p\\V1\xe2\x02\x1b\x43ometbft\\P2p\\V1\\GPBMetadata\xea\x02\x11\x43ometbft::P2p::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.p2p.v1.conn_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.cometbft.p2p.v1B\tConnProtoP\001Z0github.com/cometbft/cometbft/api/cometbft/p2p/v1\242\002\003CPX\252\002\017Cometbft.P2p.V1\312\002\017Cometbft\\P2p\\V1\342\002\033Cometbft\\P2p\\V1\\GPBMetadata\352\002\021Cometbft::P2p::V1'
  _globals['_PACKETMSG'].fields_by_name['channel_id']._loaded_options = None
  _globals['_PACKETMSG'].fields_by_name['channel_id']._serialized_options = b'\342\336\037\tChannelID'
  _globals['_PACKETMSG'].fields_by_name['eof']._loaded_options = None
  _globals['_PACKETMSG'].fields_by_name['eof']._serialized_options = b'\342\336\037\003EOF'
  _globals['_AUTHSIGMESSAGE'].fields_by_name['pub_key']._loaded_options = None
  _globals['_AUTHSIGMESSAGE'].fields_by_name['pub_key']._serialized_options = b'\310\336\037\000'
  _globals['_PACKETPING']._serialized_start=100
  _globals['_PACKETPING']._serialized_end=112
  _globals['_PACKETPONG']._serialized_start=114
  _globals['_PACKETPONG']._serialized_end=126
  _globals['_PACKETMSG']._serialized_start=128
  _globals['_PACKETMSG']._serialized_end=232
  _globals['_PACKET']._serialized_start=235
  _globals['_PACKET']._serialized_end=439
  _globals['_AUTHSIGMESSAGE']._serialized_start=441
  _globals['_AUTHSIGMESSAGE']._serialized_end=537
# @@protoc_insertion_point(module_scope)
