# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/fee/v1/fee.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ibc/applications/fee/v1/fee.proto\x12\x17ibc.applications.fee.v1\x1a\x11\x61mino/amino.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a!ibc/core/channel/v1/channel.proto\x1a\x17\x63osmos/msg/v1/msg.proto\"\xf4\x02\n\x03\x46\x65\x65\x12w\n\x08recv_fee\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBA\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coinsR\x07recvFee\x12u\n\x07\x61\x63k_fee\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBA\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coinsR\x06\x61\x63kFee\x12}\n\x0btimeout_fee\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBA\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coinsR\ntimeoutFee\"\x99\x01\n\tPacketFee\x12\x34\n\x03\x66\x65\x65\x18\x01 \x01(\x0b\x32\x1c.ibc.applications.fee.v1.FeeB\x04\xc8\xde\x1f\x00R\x03\x66\x65\x65\x12%\n\x0erefund_address\x18\x02 \x01(\tR\rrefundAddress\x12\x1a\n\x08relayers\x18\x03 \x03(\tR\x08relayers:\x13\x82\xe7\xb0*\x0erefund_address\"W\n\nPacketFees\x12I\n\x0bpacket_fees\x18\x01 \x03(\x0b\x32\".ibc.applications.fee.v1.PacketFeeB\x04\xc8\xde\x1f\x00R\npacketFees\"\xa3\x01\n\x14IdentifiedPacketFees\x12@\n\tpacket_id\x18\x01 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x04\xc8\xde\x1f\x00R\x08packetId\x12I\n\x0bpacket_fees\x18\x02 \x03(\x0b\x32\".ibc.applications.fee.v1.PacketFeeB\x04\xc8\xde\x1f\x00R\npacketFeesB\xdd\x01\n\x1b\x63om.ibc.applications.fee.v1B\x08\x46\x65\x65ProtoP\x01Z5github.com/cosmos/ibc-go/v8/modules/apps/29-fee/types\xa2\x02\x03IAF\xaa\x02\x17Ibc.Applications.Fee.V1\xca\x02\x17Ibc\\Applications\\Fee\\V1\xe2\x02#Ibc\\Applications\\Fee\\V1\\GPBMetadata\xea\x02\x1aIbc::Applications::Fee::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.fee.v1.fee_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.ibc.applications.fee.v1B\010FeeProtoP\001Z5github.com/cosmos/ibc-go/v8/modules/apps/29-fee/types\242\002\003IAF\252\002\027Ibc.Applications.Fee.V1\312\002\027Ibc\\Applications\\Fee\\V1\342\002#Ibc\\Applications\\Fee\\V1\\GPBMetadata\352\002\032Ibc::Applications::Fee::V1'
  _globals['_FEE'].fields_by_name['recv_fee']._loaded_options = None
  _globals['_FEE'].fields_by_name['recv_fee']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins'
  _globals['_FEE'].fields_by_name['ack_fee']._loaded_options = None
  _globals['_FEE'].fields_by_name['ack_fee']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins'
  _globals['_FEE'].fields_by_name['timeout_fee']._loaded_options = None
  _globals['_FEE'].fields_by_name['timeout_fee']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins'
  _globals['_PACKETFEE'].fields_by_name['fee']._loaded_options = None
  _globals['_PACKETFEE'].fields_by_name['fee']._serialized_options = b'\310\336\037\000'
  _globals['_PACKETFEE']._loaded_options = None
  _globals['_PACKETFEE']._serialized_options = b'\202\347\260*\016refund_address'
  _globals['_PACKETFEES'].fields_by_name['packet_fees']._loaded_options = None
  _globals['_PACKETFEES'].fields_by_name['packet_fees']._serialized_options = b'\310\336\037\000'
  _globals['_IDENTIFIEDPACKETFEES'].fields_by_name['packet_id']._loaded_options = None
  _globals['_IDENTIFIEDPACKETFEES'].fields_by_name['packet_id']._serialized_options = b'\310\336\037\000'
  _globals['_IDENTIFIEDPACKETFEES'].fields_by_name['packet_fees']._loaded_options = None
  _globals['_IDENTIFIEDPACKETFEES'].fields_by_name['packet_fees']._serialized_options = b'\310\336\037\000'
  _globals['_FEE']._serialized_start=196
  _globals['_FEE']._serialized_end=568
  _globals['_PACKETFEE']._serialized_start=571
  _globals['_PACKETFEE']._serialized_end=724
  _globals['_PACKETFEES']._serialized_start=726
  _globals['_PACKETFEES']._serialized_end=813
  _globals['_IDENTIFIEDPACKETFEES']._serialized_start=816
  _globals['_IDENTIFIEDPACKETFEES']._serialized_end=979
# @@protoc_insertion_point(module_scope)
