# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/privval/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.types.v1 import types_pb2 as cometbft_dot_types_dot_v1_dot_types__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63ometbft/privval/v1/types.proto\x12\x13\x63ometbft.privval.v1\x1a\x1d\x63ometbft/types/v1/types.proto\x1a\x14gogoproto/gogo.proto\"I\n\x11RemoteSignerError\x12\x12\n\x04\x63ode\x18\x01 \x01(\x05R\x04\x63ode\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\"*\n\rPubKeyRequest\x12\x19\n\x08\x63hain_id\x18\x01 \x01(\tR\x07\x63hainId\"\x9a\x01\n\x0ePubKeyResponse\x12<\n\x05\x65rror\x18\x02 \x01(\x0b\x32&.cometbft.privval.v1.RemoteSignerErrorR\x05\x65rror\x12\"\n\rpub_key_bytes\x18\x03 \x01(\x0cR\x0bpubKeyBytes\x12 \n\x0cpub_key_type\x18\x04 \x01(\tR\npubKeyTypeJ\x04\x08\x01\x10\x02\"\x8f\x01\n\x0fSignVoteRequest\x12+\n\x04vote\x18\x01 \x01(\x0b\x32\x17.cometbft.types.v1.VoteR\x04vote\x12\x19\n\x08\x63hain_id\x18\x02 \x01(\tR\x07\x63hainId\x12\x34\n\x16skip_extension_signing\x18\x03 \x01(\x08R\x14skipExtensionSigning\"\x85\x01\n\x12SignedVoteResponse\x12\x31\n\x04vote\x18\x01 \x01(\x0b\x32\x17.cometbft.types.v1.VoteB\x04\xc8\xde\x1f\x00R\x04vote\x12<\n\x05\x65rror\x18\x02 \x01(\x0b\x32&.cometbft.privval.v1.RemoteSignerErrorR\x05\x65rror\"i\n\x13SignProposalRequest\x12\x37\n\x08proposal\x18\x01 \x01(\x0b\x32\x1b.cometbft.types.v1.ProposalR\x08proposal\x12\x19\n\x08\x63hain_id\x18\x02 \x01(\tR\x07\x63hainId\"\x95\x01\n\x16SignedProposalResponse\x12=\n\x08proposal\x18\x01 \x01(\x0b\x32\x1b.cometbft.types.v1.ProposalB\x04\xc8\xde\x1f\x00R\x08proposal\x12<\n\x05\x65rror\x18\x02 \x01(\x0b\x32&.cometbft.privval.v1.RemoteSignerErrorR\x05\x65rror\"(\n\x10SignBytesRequest\x12\x14\n\x05value\x18\x01 \x01(\x0cR\x05value\"o\n\x11SignBytesResponse\x12\x1c\n\tsignature\x18\x01 \x01(\x0cR\tsignature\x12<\n\x05\x65rror\x18\x02 \x01(\x0b\x32&.cometbft.privval.v1.RemoteSignerErrorR\x05\x65rror\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\xeb\x06\n\x07Message\x12L\n\x0fpub_key_request\x18\x01 \x01(\x0b\x32\".cometbft.privval.v1.PubKeyRequestH\x00R\rpubKeyRequest\x12O\n\x10pub_key_response\x18\x02 \x01(\x0b\x32#.cometbft.privval.v1.PubKeyResponseH\x00R\x0epubKeyResponse\x12R\n\x11sign_vote_request\x18\x03 \x01(\x0b\x32$.cometbft.privval.v1.SignVoteRequestH\x00R\x0fsignVoteRequest\x12[\n\x14signed_vote_response\x18\x04 \x01(\x0b\x32\'.cometbft.privval.v1.SignedVoteResponseH\x00R\x12signedVoteResponse\x12^\n\x15sign_proposal_request\x18\x05 \x01(\x0b\x32(.cometbft.privval.v1.SignProposalRequestH\x00R\x13signProposalRequest\x12g\n\x18signed_proposal_response\x18\x06 \x01(\x0b\x32+.cometbft.privval.v1.SignedProposalResponseH\x00R\x16signedProposalResponse\x12\x45\n\x0cping_request\x18\x07 \x01(\x0b\x32 .cometbft.privval.v1.PingRequestH\x00R\x0bpingRequest\x12H\n\rping_response\x18\x08 \x01(\x0b\x32!.cometbft.privval.v1.PingResponseH\x00R\x0cpingResponse\x12U\n\x12sign_bytes_request\x18\t \x01(\x0b\x32%.cometbft.privval.v1.SignBytesRequestH\x00R\x10signBytesRequest\x12X\n\x13sign_bytes_response\x18\n \x01(\x0b\x32&.cometbft.privval.v1.SignBytesResponseH\x00R\x11signBytesResponseB\x05\n\x03sumB\xc9\x01\n\x17\x63om.cometbft.privval.v1B\nTypesProtoP\x01Z4github.com/cometbft/cometbft/api/cometbft/privval/v1\xa2\x02\x03\x43PX\xaa\x02\x13\x43ometbft.Privval.V1\xca\x02\x13\x43ometbft\\Privval\\V1\xe2\x02\x1f\x43ometbft\\Privval\\V1\\GPBMetadata\xea\x02\x15\x43ometbft::Privval::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.privval.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.cometbft.privval.v1B\nTypesProtoP\001Z4github.com/cometbft/cometbft/api/cometbft/privval/v1\242\002\003CPX\252\002\023Cometbft.Privval.V1\312\002\023Cometbft\\Privval\\V1\342\002\037Cometbft\\Privval\\V1\\GPBMetadata\352\002\025Cometbft::Privval::V1'
  _globals['_SIGNEDVOTERESPONSE'].fields_by_name['vote']._loaded_options = None
  _globals['_SIGNEDVOTERESPONSE'].fields_by_name['vote']._serialized_options = b'\310\336\037\000'
  _globals['_SIGNEDPROPOSALRESPONSE'].fields_by_name['proposal']._loaded_options = None
  _globals['_SIGNEDPROPOSALRESPONSE'].fields_by_name['proposal']._serialized_options = b'\310\336\037\000'
  _globals['_REMOTESIGNERERROR']._serialized_start=109
  _globals['_REMOTESIGNERERROR']._serialized_end=182
  _globals['_PUBKEYREQUEST']._serialized_start=184
  _globals['_PUBKEYREQUEST']._serialized_end=226
  _globals['_PUBKEYRESPONSE']._serialized_start=229
  _globals['_PUBKEYRESPONSE']._serialized_end=383
  _globals['_SIGNVOTEREQUEST']._serialized_start=386
  _globals['_SIGNVOTEREQUEST']._serialized_end=529
  _globals['_SIGNEDVOTERESPONSE']._serialized_start=532
  _globals['_SIGNEDVOTERESPONSE']._serialized_end=665
  _globals['_SIGNPROPOSALREQUEST']._serialized_start=667
  _globals['_SIGNPROPOSALREQUEST']._serialized_end=772
  _globals['_SIGNEDPROPOSALRESPONSE']._serialized_start=775
  _globals['_SIGNEDPROPOSALRESPONSE']._serialized_end=924
  _globals['_SIGNBYTESREQUEST']._serialized_start=926
  _globals['_SIGNBYTESREQUEST']._serialized_end=966
  _globals['_SIGNBYTESRESPONSE']._serialized_start=968
  _globals['_SIGNBYTESRESPONSE']._serialized_end=1079
  _globals['_PINGREQUEST']._serialized_start=1081
  _globals['_PINGREQUEST']._serialized_end=1094
  _globals['_PINGRESPONSE']._serialized_start=1096
  _globals['_PINGRESPONSE']._serialized_end=1110
  _globals['_MESSAGE']._serialized_start=1113
  _globals['_MESSAGE']._serialized_end=1988
# @@protoc_insertion_point(module_scope)
