# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_meta_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!exchange/injective_meta_rpc.proto\x12\x12injective_meta_rpc\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\x10\n\x0eVersionRequest\"\xab\x01\n\x0fVersionResponse\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x44\n\x05\x62uild\x18\x02 \x03(\x0b\x32..injective_meta_rpc.VersionResponse.BuildEntryR\x05\x62uild\x1a\x38\n\nBuildEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"+\n\x0bInfoRequest\x12\x1c\n\ttimestamp\x18\x01 \x01(\x12R\ttimestamp\"\xfc\x01\n\x0cInfoResponse\x12\x1c\n\ttimestamp\x18\x01 \x01(\x12R\ttimestamp\x12\x1f\n\x0bserver_time\x18\x02 \x01(\x12R\nserverTime\x12\x18\n\x07version\x18\x03 \x01(\tR\x07version\x12\x41\n\x05\x62uild\x18\x04 \x03(\x0b\x32+.injective_meta_rpc.InfoResponse.BuildEntryR\x05\x62uild\x12\x16\n\x06region\x18\x05 \x01(\tR\x06region\x1a\x38\n\nBuildEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x18\n\x16StreamKeepaliveRequest\"p\n\x17StreamKeepaliveResponse\x12\x14\n\x05\x65vent\x18\x01 \x01(\tR\x05\x65vent\x12!\n\x0cnew_endpoint\x18\x02 \x01(\tR\x0bnewEndpoint\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\".\n\x14TokenMetadataRequest\x12\x16\n\x06\x64\x65noms\x18\x01 \x03(\tR\x06\x64\x65noms\"Y\n\x15TokenMetadataResponse\x12@\n\x06tokens\x18\x01 \x03(\x0b\x32(.injective_meta_rpc.TokenMetadataElementR\x06tokens\"\xd6\x01\n\x14TokenMetadataElement\x12)\n\x10\x65thereum_address\x18\x01 \x01(\tR\x0f\x65thereumAddress\x12!\n\x0c\x63oingecko_id\x18\x02 \x01(\tR\x0b\x63oingeckoId\x12\x14\n\x05\x64\x65nom\x18\x03 \x01(\tR\x05\x64\x65nom\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12\x16\n\x06symbol\x18\x05 \x01(\tR\x06symbol\x12\x1a\n\x08\x64\x65\x63imals\x18\x06 \x01(\x11R\x08\x64\x65\x63imals\x12\x12\n\x04logo\x18\x07 \x01(\tR\x04logo2\xd0\x03\n\x10InjectiveMetaRPC\x12I\n\x04Ping\x12\x1f.injective_meta_rpc.PingRequest\x1a .injective_meta_rpc.PingResponse\x12R\n\x07Version\x12\".injective_meta_rpc.VersionRequest\x1a#.injective_meta_rpc.VersionResponse\x12I\n\x04Info\x12\x1f.injective_meta_rpc.InfoRequest\x1a .injective_meta_rpc.InfoResponse\x12l\n\x0fStreamKeepalive\x12*.injective_meta_rpc.StreamKeepaliveRequest\x1a+.injective_meta_rpc.StreamKeepaliveResponse0\x01\x12\x64\n\rTokenMetadata\x12(.injective_meta_rpc.TokenMetadataRequest\x1a).injective_meta_rpc.TokenMetadataResponseB\xa6\x01\n\x16\x63om.injective_meta_rpcB\x15InjectiveMetaRpcProtoP\x01Z\x15/injective_meta_rpcpb\xa2\x02\x03IXX\xaa\x02\x10InjectiveMetaRpc\xca\x02\x10InjectiveMetaRpc\xe2\x02\x1cInjectiveMetaRpc\\GPBMetadata\xea\x02\x10InjectiveMetaRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_meta_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.injective_meta_rpcB\025InjectiveMetaRpcProtoP\001Z\025/injective_meta_rpcpb\242\002\003IXX\252\002\020InjectiveMetaRpc\312\002\020InjectiveMetaRpc\342\002\034InjectiveMetaRpc\\GPBMetadata\352\002\020InjectiveMetaRpc'
  _globals['_VERSIONRESPONSE_BUILDENTRY']._loaded_options = None
  _globals['_VERSIONRESPONSE_BUILDENTRY']._serialized_options = b'8\001'
  _globals['_INFORESPONSE_BUILDENTRY']._loaded_options = None
  _globals['_INFORESPONSE_BUILDENTRY']._serialized_options = b'8\001'
  _globals['_PINGREQUEST']._serialized_start=57
  _globals['_PINGREQUEST']._serialized_end=70
  _globals['_PINGRESPONSE']._serialized_start=72
  _globals['_PINGRESPONSE']._serialized_end=86
  _globals['_VERSIONREQUEST']._serialized_start=88
  _globals['_VERSIONREQUEST']._serialized_end=104
  _globals['_VERSIONRESPONSE']._serialized_start=107
  _globals['_VERSIONRESPONSE']._serialized_end=278
  _globals['_VERSIONRESPONSE_BUILDENTRY']._serialized_start=222
  _globals['_VERSIONRESPONSE_BUILDENTRY']._serialized_end=278
  _globals['_INFOREQUEST']._serialized_start=280
  _globals['_INFOREQUEST']._serialized_end=323
  _globals['_INFORESPONSE']._serialized_start=326
  _globals['_INFORESPONSE']._serialized_end=578
  _globals['_INFORESPONSE_BUILDENTRY']._serialized_start=222
  _globals['_INFORESPONSE_BUILDENTRY']._serialized_end=278
  _globals['_STREAMKEEPALIVEREQUEST']._serialized_start=580
  _globals['_STREAMKEEPALIVEREQUEST']._serialized_end=604
  _globals['_STREAMKEEPALIVERESPONSE']._serialized_start=606
  _globals['_STREAMKEEPALIVERESPONSE']._serialized_end=718
  _globals['_TOKENMETADATAREQUEST']._serialized_start=720
  _globals['_TOKENMETADATAREQUEST']._serialized_end=766
  _globals['_TOKENMETADATARESPONSE']._serialized_start=768
  _globals['_TOKENMETADATARESPONSE']._serialized_end=857
  _globals['_TOKENMETADATAELEMENT']._serialized_start=860
  _globals['_TOKENMETADATAELEMENT']._serialized_end=1074
  _globals['_INJECTIVEMETARPC']._serialized_start=1077
  _globals['_INJECTIVEMETARPC']._serialized_end=1541
# @@protoc_insertion_point(module_scope)
