# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/store/v1beta1/listening.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.abci.v1 import types_pb2 as cometbft_dot_abci_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/store/v1beta1/listening.proto\x12\x14\x63osmos.store.v1beta1\x1a\x1c\x63ometbft/abci/v1/types.proto\"j\n\x0bStoreKVPair\x12\x1b\n\tstore_key\x18\x01 \x01(\tR\x08storeKey\x12\x16\n\x06\x64\x65lete\x18\x02 \x01(\x08R\x06\x64\x65lete\x12\x10\n\x03key\x18\x03 \x01(\x0cR\x03key\x12\x14\n\x05value\x18\x04 \x01(\x0cR\x05value\"\xb7\x02\n\rBlockMetadata\x12I\n\x0fresponse_commit\x18\x06 \x01(\x0b\x32 .cometbft.abci.v1.CommitResponseR\x0eresponseCommit\x12\\\n\x16request_finalize_block\x18\x07 \x01(\x0b\x32&.cometbft.abci.v1.FinalizeBlockRequestR\x14requestFinalizeBlock\x12_\n\x17response_finalize_block\x18\x08 \x01(\x0b\x32\'.cometbft.abci.v1.FinalizeBlockResponseR\x15responseFinalizeBlockJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06\x42\xb6\x01\n\x18\x63om.cosmos.store.v1beta1B\x0eListeningProtoP\x01Z\x18\x63osmossdk.io/store/types\xa2\x02\x03\x43SX\xaa\x02\x14\x43osmos.Store.V1beta1\xca\x02\x14\x43osmos\\Store\\V1beta1\xe2\x02 Cosmos\\Store\\V1beta1\\GPBMetadata\xea\x02\x16\x43osmos::Store::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.store.v1beta1.listening_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.cosmos.store.v1beta1B\016ListeningProtoP\001Z\030cosmossdk.io/store/types\242\002\003CSX\252\002\024Cosmos.Store.V1beta1\312\002\024Cosmos\\Store\\V1beta1\342\002 Cosmos\\Store\\V1beta1\\GPBMetadata\352\002\026Cosmos::Store::V1beta1'
  _globals['_STOREKVPAIR']._serialized_start=92
  _globals['_STOREKVPAIR']._serialized_end=198
  _globals['_BLOCKMETADATA']._serialized_start=201
  _globals['_BLOCKMETADATA']._serialized_end=512
# @@protoc_insertion_point(module_scope)
