# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/erc20/v1beta1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.injective.erc20.v1beta1 import params_pb2 as injective_dot_erc20_dot_v1beta1_dot_params__pb2
from pyinjective.proto.injective.erc20.v1beta1 import erc20_pb2 as injective_dot_erc20_dot_v1beta1_dot_erc20__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n injective/erc20/v1beta1/tx.proto\x12\x17injective.erc20.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a$injective/erc20/v1beta1/params.proto\x1a#injective/erc20/v1beta1/erc20.proto\x1a\x11\x61mino/amino.proto\"\xb2\x01\n\x0fMsgUpdateParams\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12=\n\x06params\x18\x02 \x01(\x0b\x32\x1f.injective.erc20.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:(\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x15\x65rc20/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"\xb2\x01\n\x12MsgCreateTokenPair\x12)\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"R\x06sender\x12G\n\ntoken_pair\x18\x02 \x01(\x0b\x32\".injective.erc20.v1beta1.TokenPairB\x04\xc8\xde\x1f\x00R\ttokenPair:(\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x18\x65rc20/MsgCreateTokenPair\"e\n\x1aMsgCreateTokenPairResponse\x12G\n\ntoken_pair\x18\x01 \x01(\x0b\x32\".injective.erc20.v1beta1.TokenPairB\x04\xc8\xde\x1f\x00R\ttokenPair\"\x88\x01\n\x12MsgDeleteTokenPair\x12)\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"R\x06sender\x12\x1d\n\nbank_denom\x18\x02 \x01(\tR\tbankDenom:(\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x18\x65rc20/MsgDeleteTokenPair\"\x1c\n\x1aMsgDeleteTokenPairResponse2\xe2\x02\n\x03Msg\x12j\n\x0cUpdateParams\x12(.injective.erc20.v1beta1.MsgUpdateParams\x1a\x30.injective.erc20.v1beta1.MsgUpdateParamsResponse\x12s\n\x0f\x43reateTokenPair\x12+.injective.erc20.v1beta1.MsgCreateTokenPair\x1a\x33.injective.erc20.v1beta1.MsgCreateTokenPairResponse\x12s\n\x0f\x44\x65leteTokenPair\x12+.injective.erc20.v1beta1.MsgDeleteTokenPair\x1a\x33.injective.erc20.v1beta1.MsgDeleteTokenPairResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xf1\x01\n\x1b\x63om.injective.erc20.v1beta1B\x07TxProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/erc20/types\xa2\x02\x03IEX\xaa\x02\x17Injective.Erc20.V1beta1\xca\x02\x17Injective\\Erc20\\V1beta1\xe2\x02#Injective\\Erc20\\V1beta1\\GPBMetadata\xea\x02\x19Injective::Erc20::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.erc20.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.injective.erc20.v1beta1B\007TxProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/erc20/types\242\002\003IEX\252\002\027Injective.Erc20.V1beta1\312\002\027Injective\\Erc20\\V1beta1\342\002#Injective\\Erc20\\V1beta1\\GPBMetadata\352\002\031Injective::Erc20::V1beta1'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\025erc20/MsgUpdateParams'
  _globals['_MSGCREATETOKENPAIR'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGCREATETOKENPAIR'].fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _globals['_MSGCREATETOKENPAIR'].fields_by_name['token_pair']._loaded_options = None
  _globals['_MSGCREATETOKENPAIR'].fields_by_name['token_pair']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATETOKENPAIR']._loaded_options = None
  _globals['_MSGCREATETOKENPAIR']._serialized_options = b'\202\347\260*\006sender\212\347\260*\030erc20/MsgCreateTokenPair'
  _globals['_MSGCREATETOKENPAIRRESPONSE'].fields_by_name['token_pair']._loaded_options = None
  _globals['_MSGCREATETOKENPAIRRESPONSE'].fields_by_name['token_pair']._serialized_options = b'\310\336\037\000'
  _globals['_MSGDELETETOKENPAIR'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGDELETETOKENPAIR'].fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _globals['_MSGDELETETOKENPAIR']._loaded_options = None
  _globals['_MSGDELETETOKENPAIR']._serialized_options = b'\202\347\260*\006sender\212\347\260*\030erc20/MsgDeleteTokenPair'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._serialized_start=294
  _globals['_MSGUPDATEPARAMS']._serialized_end=472
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=474
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=499
  _globals['_MSGCREATETOKENPAIR']._serialized_start=502
  _globals['_MSGCREATETOKENPAIR']._serialized_end=680
  _globals['_MSGCREATETOKENPAIRRESPONSE']._serialized_start=682
  _globals['_MSGCREATETOKENPAIRRESPONSE']._serialized_end=783
  _globals['_MSGDELETETOKENPAIR']._serialized_start=786
  _globals['_MSGDELETETOKENPAIR']._serialized_end=922
  _globals['_MSGDELETETOKENPAIRRESPONSE']._serialized_start=924
  _globals['_MSGDELETETOKENPAIRRESPONSE']._serialized_end=952
  _globals['_MSG']._serialized_start=955
  _globals['_MSG']._serialized_end=1309
# @@protoc_insertion_point(module_scope)
