# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/msg/v1/msg.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63osmos/msg/v1/msg.proto\x12\rcosmos.msg.v1\x1a google/protobuf/descriptor.proto:<\n\x07service\x12\x1f.google.protobuf.ServiceOptions\x18\xf0\x8c\xa6\x05 \x01(\x08R\x07service::\n\x06signer\x12\x1f.google.protobuf.MessageOptions\x18\xf0\x8c\xa6\x05 \x03(\tR\x06signerB\xa2\x01\n\x11\x63om.cosmos.msg.v1B\x08MsgProtoP\x01Z-github.com/cosmos/cosmos-sdk/types/msgservice\xa2\x02\x03\x43MX\xaa\x02\rCosmos.Msg.V1\xca\x02\rCosmos\\Msg\\V1\xe2\x02\x19\x43osmos\\Msg\\V1\\GPBMetadata\xea\x02\x0f\x43osmos::Msg::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.msg.v1.msg_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021com.cosmos.msg.v1B\010MsgProtoP\001Z-github.com/cosmos/cosmos-sdk/types/msgservice\242\002\003CMX\252\002\rCosmos.Msg.V1\312\002\rCosmos\\Msg\\V1\342\002\031Cosmos\\Msg\\V1\\GPBMetadata\352\002\017Cosmos::Msg::V1'
# @@protoc_insertion_point(module_scope)
