# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/geo/type/viewport.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import latlng_pb2 as google_dot_type_dot_latlng__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egoogle/geo/type/viewport.proto\x12\x0fgoogle.geo.type\x1a\x18google/type/latlng.proto\"Z\n\x08Viewport\x12%\n\x03low\x18\x01 \x01(\x0b\x32\x13.google.type.LatLngR\x03low\x12\'\n\x04high\x18\x02 \x01(\x0b\x32\x13.google.type.LatLngR\x04highB\xc4\x01\n\x13\x63om.google.geo.typeB\rViewportProtoP\x01Z@google.golang.org/genproto/googleapis/geo/type/viewport;viewport\xa2\x02\x03GGT\xaa\x02\x0fGoogle.Geo.Type\xca\x02\x0fGoogle\\Geo\\Type\xe2\x02\x1bGoogle\\Geo\\Type\\GPBMetadata\xea\x02\x11Google::Geo::Typeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.geo.type.viewport_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.google.geo.typeB\rViewportProtoP\001Z@google.golang.org/genproto/googleapis/geo/type/viewport;viewport\242\002\003GGT\252\002\017Google.Geo.Type\312\002\017Google\\Geo\\Type\342\002\033Google\\Geo\\Type\\GPBMetadata\352\002\021Google::Geo::Type'
  _globals['_VIEWPORT']._serialized_start=77
  _globals['_VIEWPORT']._serialized_end=167
# @@protoc_insertion_point(module_scope)
