# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/tx/config/v1/config.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/tx/config/v1/config.proto\x12\x13\x63osmos.tx.config.v1\x1a cosmos/app/v1alpha1/module.proto\"\x90\x01\n\x06\x43onfig\x12*\n\x11skip_ante_handler\x18\x01 \x01(\x08R\x0fskipAnteHandler\x12*\n\x11skip_post_handler\x18\x02 \x01(\x08R\x0fskipPostHandler:.\xba\xc0\x96\xda\x01(\n&github.com/cosmos/cosmos-sdk/x/auth/txB\x95\x01\n\x17\x63om.cosmos.tx.config.v1B\x0b\x43onfigProtoP\x01\xa2\x02\x03\x43TC\xaa\x02\x13\x43osmos.Tx.Config.V1\xca\x02\x13\x43osmos\\Tx\\Config\\V1\xe2\x02\x1f\x43osmos\\Tx\\Config\\V1\\GPBMetadata\xea\x02\x16\x43osmos::Tx::Config::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.tx.config.v1.config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.cosmos.tx.config.v1B\013ConfigProtoP\001\242\002\003CTC\252\002\023Cosmos.Tx.Config.V1\312\002\023Cosmos\\Tx\\Config\\V1\342\002\037Cosmos\\Tx\\Config\\V1\\GPBMetadata\352\002\026Cosmos::Tx::Config::V1'
  _globals['_CONFIG']._loaded_options = None
  _globals['_CONFIG']._serialized_options = b'\272\300\226\332\001(\n&github.com/cosmos/cosmos-sdk/x/auth/tx'
  _globals['_CONFIG']._serialized_start=92
  _globals['_CONFIG']._serialized_end=236
# @@protoc_insertion_point(module_scope)
