# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/query/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63osmos/query/v1/query.proto\x12\x0f\x63osmos.query.v1\x1a google/protobuf/descriptor.proto:M\n\x11module_query_safe\x12\x1e.google.protobuf.MethodOptions\x18\xf1\x8c\xa6\x05 \x01(\x08R\x0fmoduleQuerySafeB\xa9\x01\n\x13\x63om.cosmos.query.v1B\nQueryProtoP\x01Z(github.com/cosmos/cosmos-sdk/types/query\xa2\x02\x03\x43QX\xaa\x02\x0f\x43osmos.Query.V1\xca\x02\x0f\x43osmos\\Query\\V1\xe2\x02\x1b\x43osmos\\Query\\V1\\GPBMetadata\xea\x02\x11\x43osmos::Query::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.query.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.cosmos.query.v1B\nQueryProtoP\001Z(github.com/cosmos/cosmos-sdk/types/query\242\002\003CQX\252\002\017Cosmos.Query.V1\312\002\017Cosmos\\Query\\V1\342\002\033Cosmos\\Query\\V1\\GPBMetadata\352\002\021Cosmos::Query::V1'
# @@protoc_insertion_point(module_scope)
