# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/vesting/module/v1/module.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/vesting/module/v1/module.proto\x12\x18\x63osmos.vesting.module.v1\x1a cosmos/app/v1alpha1/module.proto\"=\n\x06Module:3\xba\xc0\x96\xda\x01-\n+github.com/cosmos/cosmos-sdk/x/auth/vestingB\xae\x01\n\x1c\x63om.cosmos.vesting.module.v1B\x0bModuleProtoP\x01\xa2\x02\x03\x43VM\xaa\x02\x18\x43osmos.Vesting.Module.V1\xca\x02\x18\x43osmos\\Vesting\\Module\\V1\xe2\x02$Cosmos\\Vesting\\Module\\V1\\GPBMetadata\xea\x02\x1b\x43osmos::Vesting::Module::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.vesting.module.v1.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.cosmos.vesting.module.v1B\013ModuleProtoP\001\242\002\003CVM\252\002\030Cosmos.Vesting.Module.V1\312\002\030Cosmos\\Vesting\\Module\\V1\342\002$Cosmos\\Vesting\\Module\\V1\\GPBMetadata\352\002\033Cosmos::Vesting::Module::V1'
  _globals['_MODULE']._loaded_options = None
  _globals['_MODULE']._serialized_options = b'\272\300\226\332\001-\n+github.com/cosmos/cosmos-sdk/x/auth/vesting'
  _globals['_MODULE']._serialized_start=101
  _globals['_MODULE']._serialized_end=162
# @@protoc_insertion_point(module_scope)
