# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/services/version/v1/version_service.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.services.version.v1 import version_pb2 as cometbft_dot_services_dot_version_dot_v1_dot_version__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2cometbft/services/version/v1/version_service.proto\x12\x1c\x63ometbft.services.version.v1\x1a*cometbft/services/version/v1/version.proto2\x81\x01\n\x0eVersionService\x12o\n\nGetVersion\x12/.cometbft.services.version.v1.GetVersionRequest\x1a\x30.cometbft.services.version.v1.GetVersionResponseB\x89\x02\n com.cometbft.services.version.v1B\x13VersionServiceProtoP\x01Z=github.com/cometbft/cometbft/api/cometbft/services/version/v1\xa2\x02\x03\x43SV\xaa\x02\x1c\x43ometbft.Services.Version.V1\xca\x02\x1c\x43ometbft\\Services\\Version\\V1\xe2\x02(Cometbft\\Services\\Version\\V1\\GPBMetadata\xea\x02\x1f\x43ometbft::Services::Version::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.services.version.v1.version_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.cometbft.services.version.v1B\023VersionServiceProtoP\001Z=github.com/cometbft/cometbft/api/cometbft/services/version/v1\242\002\003CSV\252\002\034Cometbft.Services.Version.V1\312\002\034Cometbft\\Services\\Version\\V1\342\002(Cometbft\\Services\\Version\\V1\\GPBMetadata\352\002\037Cometbft::Services::Version::V1'
  _globals['_VERSIONSERVICE']._serialized_start=129
  _globals['_VERSIONSERVICE']._serialized_end=258
# @@protoc_insertion_point(module_scope)
