# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: capability/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from capability.v1 import capability_pb2 as capability_dot_v1_dot_capability__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63\x61pability/v1/genesis.proto\x12\rcapability.v1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63\x61pability/v1/capability.proto\x1a\x11\x61mino/amino.proto\"t\n\rGenesisOwners\x12\x14\n\x05index\x18\x01 \x01(\x04R\x05index\x12M\n\x0cindex_owners\x18\x02 \x01(\x0b\x32\x1f.capability.v1.CapabilityOwnersB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0bindexOwners\"e\n\x0cGenesisState\x12\x14\n\x05index\x18\x01 \x01(\x04R\x05index\x12?\n\x06owners\x18\x02 \x03(\x0b\x32\x1c.capability.v1.GenesisOwnersB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06ownersB\xa9\x01\n\x11\x63om.capability.v1B\x0cGenesisProtoP\x01Z1github.com/cosmos/ibc-go/modules/capability/types\xa2\x02\x03\x43XX\xaa\x02\rCapability.V1\xca\x02\rCapability\\V1\xe2\x02\x19\x43\x61pability\\V1\\GPBMetadata\xea\x02\x0e\x43\x61pability::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'capability.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021com.capability.v1B\014GenesisProtoP\001Z1github.com/cosmos/ibc-go/modules/capability/types\242\002\003CXX\252\002\rCapability.V1\312\002\rCapability\\V1\342\002\031Capability\\V1\\GPBMetadata\352\002\016Capability::V1'
  _globals['_GENESISOWNERS'].fields_by_name['index_owners']._loaded_options = None
  _globals['_GENESISOWNERS'].fields_by_name['index_owners']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['owners']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['owners']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISOWNERS']._serialized_start=119
  _globals['_GENESISOWNERS']._serialized_end=235
  _globals['_GENESISSTATE']._serialized_start=237
  _globals['_GENESISSTATE']._serialized_end=338
# @@protoc_insertion_point(module_scope)
