# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/consensus/module/v1/module.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'cosmos/consensus/module/v1/module.proto\x12\x1a\x63osmos.consensus.module.v1\x1a cosmos/app/v1alpha1/module.proto\"X\n\x06Module\x12\x1c\n\tauthority\x18\x01 \x01(\tR\tauthority:0\xba\xc0\x96\xda\x01*\n(github.com/cosmos/cosmos-sdk/x/consensusB\xb8\x01\n\x1e\x63om.cosmos.consensus.module.v1B\x0bModuleProtoP\x01\xa2\x02\x03\x43\x43M\xaa\x02\x1a\x43osmos.Consensus.Module.V1\xca\x02\x1a\x43osmos\\Consensus\\Module\\V1\xe2\x02&Cosmos\\Consensus\\Module\\V1\\GPBMetadata\xea\x02\x1d\x43osmos::Consensus::Module::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.consensus.module.v1.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036com.cosmos.consensus.module.v1B\013ModuleProtoP\001\242\002\003CCM\252\002\032Cosmos.Consensus.Module.V1\312\002\032Cosmos\\Consensus\\Module\\V1\342\002&Cosmos\\Consensus\\Module\\V1\\GPBMetadata\352\002\035Cosmos::Consensus::Module::V1'
  _globals['_MODULE']._loaded_options = None
  _globals['_MODULE']._serialized_options = b'\272\300\226\332\001*\n(github.com/cosmos/cosmos-sdk/x/consensus'
  _globals['_MODULE']._serialized_start=105
  _globals['_MODULE']._serialized_end=193
# @@protoc_insertion_point(module_scope)
