# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/types/v1/evidence.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.types.v1 import types_pb2 as cometbft_dot_types_dot_v1_dot_types__pb2
from pyinjective.proto.cometbft.types.v1 import validator_pb2 as cometbft_dot_types_dot_v1_dot_validator__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cometbft/types/v1/evidence.proto\x12\x11\x63ometbft.types.v1\x1a\x1d\x63ometbft/types/v1/types.proto\x1a!cometbft/types/v1/validator.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe6\x01\n\x08\x45vidence\x12\x62\n\x17\x64uplicate_vote_evidence\x18\x01 \x01(\x0b\x32(.cometbft.types.v1.DuplicateVoteEvidenceH\x00R\x15\x64uplicateVoteEvidence\x12o\n\x1clight_client_attack_evidence\x18\x02 \x01(\x0b\x32,.cometbft.types.v1.LightClientAttackEvidenceH\x00R\x19lightClientAttackEvidenceB\x05\n\x03sum\"\x92\x02\n\x15\x44uplicateVoteEvidence\x12.\n\x06vote_a\x18\x01 \x01(\x0b\x32\x17.cometbft.types.v1.VoteR\x05voteA\x12.\n\x06vote_b\x18\x02 \x01(\x0b\x32\x17.cometbft.types.v1.VoteR\x05voteB\x12,\n\x12total_voting_power\x18\x03 \x01(\x03R\x10totalVotingPower\x12\'\n\x0fvalidator_power\x18\x04 \x01(\x03R\x0evalidatorPower\x12\x42\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\ttimestamp\"\xcf\x02\n\x19LightClientAttackEvidence\x12J\n\x11\x63onflicting_block\x18\x01 \x01(\x0b\x32\x1d.cometbft.types.v1.LightBlockR\x10\x63onflictingBlock\x12#\n\rcommon_height\x18\x02 \x01(\x03R\x0c\x63ommonHeight\x12O\n\x14\x62yzantine_validators\x18\x03 \x03(\x0b\x32\x1c.cometbft.types.v1.ValidatorR\x13\x62yzantineValidators\x12,\n\x12total_voting_power\x18\x04 \x01(\x03R\x10totalVotingPower\x12\x42\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\ttimestamp\"M\n\x0c\x45videnceList\x12=\n\x08\x65vidence\x18\x01 \x03(\x0b\x32\x1b.cometbft.types.v1.EvidenceB\x04\xc8\xde\x1f\x00R\x08\x65videnceB\xc0\x01\n\x15\x63om.cometbft.types.v1B\rEvidenceProtoP\x01Z2github.com/cometbft/cometbft/api/cometbft/types/v1\xa2\x02\x03\x43TX\xaa\x02\x11\x43ometbft.Types.V1\xca\x02\x11\x43ometbft\\Types\\V1\xe2\x02\x1d\x43ometbft\\Types\\V1\\GPBMetadata\xea\x02\x13\x43ometbft::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.types.v1.evidence_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.cometbft.types.v1B\rEvidenceProtoP\001Z2github.com/cometbft/cometbft/api/cometbft/types/v1\242\002\003CTX\252\002\021Cometbft.Types.V1\312\002\021Cometbft\\Types\\V1\342\002\035Cometbft\\Types\\V1\\GPBMetadata\352\002\023Cometbft::Types::V1'
  _globals['_DUPLICATEVOTEEVIDENCE'].fields_by_name['timestamp']._loaded_options = None
  _globals['_DUPLICATEVOTEEVIDENCE'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_LIGHTCLIENTATTACKEVIDENCE'].fields_by_name['timestamp']._loaded_options = None
  _globals['_LIGHTCLIENTATTACKEVIDENCE'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_EVIDENCELIST'].fields_by_name['evidence']._loaded_options = None
  _globals['_EVIDENCELIST'].fields_by_name['evidence']._serialized_options = b'\310\336\037\000'
  _globals['_EVIDENCE']._serialized_start=177
  _globals['_EVIDENCE']._serialized_end=407
  _globals['_DUPLICATEVOTEEVIDENCE']._serialized_start=410
  _globals['_DUPLICATEVOTEEVIDENCE']._serialized_end=684
  _globals['_LIGHTCLIENTATTACKEVIDENCE']._serialized_start=687
  _globals['_LIGHTCLIENTATTACKEVIDENCE']._serialized_end=1022
  _globals['_EVIDENCELIST']._serialized_start=1024
  _globals['_EVIDENCELIST']._serialized_end=1101
# @@protoc_insertion_point(module_scope)
