# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/bytestream/bytestream.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"google/bytestream/bytestream.proto\x12\x11google.bytestream\"r\n\x0bReadRequest\x12#\n\rresource_name\x18\x01 \x01(\tR\x0cresourceName\x12\x1f\n\x0bread_offset\x18\x02 \x01(\x03R\nreadOffset\x12\x1d\n\nread_limit\x18\x03 \x01(\x03R\treadLimit\"\"\n\x0cReadResponse\x12\x12\n\x04\x64\x61ta\x18\n \x01(\x0cR\x04\x64\x61ta\"\x8d\x01\n\x0cWriteRequest\x12#\n\rresource_name\x18\x01 \x01(\tR\x0cresourceName\x12!\n\x0cwrite_offset\x18\x02 \x01(\x03R\x0bwriteOffset\x12!\n\x0c\x66inish_write\x18\x03 \x01(\x08R\x0b\x66inishWrite\x12\x12\n\x04\x64\x61ta\x18\n \x01(\x0cR\x04\x64\x61ta\"6\n\rWriteResponse\x12%\n\x0e\x63ommitted_size\x18\x01 \x01(\x03R\rcommittedSize\">\n\x17QueryWriteStatusRequest\x12#\n\rresource_name\x18\x01 \x01(\tR\x0cresourceName\"]\n\x18QueryWriteStatusResponse\x12%\n\x0e\x63ommitted_size\x18\x01 \x01(\x03R\rcommittedSize\x12\x1a\n\x08\x63omplete\x18\x02 \x01(\x08R\x08\x63omplete2\x92\x02\n\nByteStream\x12I\n\x04Read\x12\x1e.google.bytestream.ReadRequest\x1a\x1f.google.bytestream.ReadResponse0\x01\x12L\n\x05Write\x12\x1f.google.bytestream.WriteRequest\x1a .google.bytestream.WriteResponse(\x01\x12k\n\x10QueryWriteStatus\x12*.google.bytestream.QueryWriteStatusRequest\x1a+.google.bytestream.QueryWriteStatusResponseB\xca\x01\n\x15\x63om.google.bytestreamB\x0f\x42ytestreamProtoP\x01Z;google.golang.org/genproto/googleapis/bytestream;bytestream\xa2\x02\x03GBX\xaa\x02\x11Google.Bytestream\xca\x02\x11Google\\Bytestream\xe2\x02\x1dGoogle\\Bytestream\\GPBMetadata\xea\x02\x12Google::Bytestreamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.bytestream.bytestream_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.google.bytestreamB\017BytestreamProtoP\001Z;google.golang.org/genproto/googleapis/bytestream;bytestream\242\002\003GBX\252\002\021Google.Bytestream\312\002\021Google\\Bytestream\342\002\035Google\\Bytestream\\GPBMetadata\352\002\022Google::Bytestream'
  _globals['_READREQUEST']._serialized_start=57
  _globals['_READREQUEST']._serialized_end=171
  _globals['_READRESPONSE']._serialized_start=173
  _globals['_READRESPONSE']._serialized_end=207
  _globals['_WRITEREQUEST']._serialized_start=210
  _globals['_WRITEREQUEST']._serialized_end=351
  _globals['_WRITERESPONSE']._serialized_start=353
  _globals['_WRITERESPONSE']._serialized_end=407
  _globals['_QUERYWRITESTATUSREQUEST']._serialized_start=409
  _globals['_QUERYWRITESTATUSREQUEST']._serialized_end=471
  _globals['_QUERYWRITESTATUSRESPONSE']._serialized_start=473
  _globals['_QUERYWRITESTATUSRESPONSE']._serialized_end=566
  _globals['_BYTESTREAM']._serialized_start=569
  _globals['_BYTESTREAM']._serialized_end=843
# @@protoc_insertion_point(module_scope)
