# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/consensus/v1/wal.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.consensus.v1 import types_pb2 as cometbft_dot_consensus_dot_v1_dot_types__pb2
from pyinjective.proto.cometbft.types.v1 import events_pb2 as cometbft_dot_types_dot_v1_dot_events__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63ometbft/consensus/v1/wal.proto\x12\x15\x63ometbft.consensus.v1\x1a!cometbft/consensus/v1/types.proto\x1a\x1e\x63ometbft/types/v1/events.proto\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xaf\x01\n\x07MsgInfo\x12\x36\n\x03msg\x18\x01 \x01(\x0b\x32\x1e.cometbft.consensus.v1.MessageB\x04\xc8\xde\x1f\x00R\x03msg\x12#\n\x07peer_id\x18\x02 \x01(\tB\n\xe2\xde\x1f\x06PeerIDR\x06peerId\x12G\n\x0creceive_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x01\x90\xdf\x1f\x01R\x0breceiveTime\"\x90\x01\n\x0bTimeoutInfo\x12?\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01R\x08\x64uration\x12\x16\n\x06height\x18\x02 \x01(\x03R\x06height\x12\x14\n\x05round\x18\x03 \x01(\x05R\x05round\x12\x12\n\x04step\x18\x04 \x01(\rR\x04step\"#\n\tEndHeight\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\"\xbb\x02\n\nWALMessage\x12]\n\x16\x65vent_data_round_state\x18\x01 \x01(\x0b\x32&.cometbft.types.v1.EventDataRoundStateH\x00R\x13\x65ventDataRoundState\x12;\n\x08msg_info\x18\x02 \x01(\x0b\x32\x1e.cometbft.consensus.v1.MsgInfoH\x00R\x07msgInfo\x12G\n\x0ctimeout_info\x18\x03 \x01(\x0b\x32\".cometbft.consensus.v1.TimeoutInfoH\x00R\x0btimeoutInfo\x12\x41\n\nend_height\x18\x04 \x01(\x0b\x32 .cometbft.consensus.v1.EndHeightH\x00R\tendHeightB\x05\n\x03sum\"\x80\x01\n\x0fTimedWALMessage\x12\x38\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x33\n\x03msg\x18\x02 \x01(\x0b\x32!.cometbft.consensus.v1.WALMessageR\x03msgB\xd3\x01\n\x19\x63om.cometbft.consensus.v1B\x08WalProtoP\x01Z6github.com/cometbft/cometbft/api/cometbft/consensus/v1\xa2\x02\x03\x43\x43X\xaa\x02\x15\x43ometbft.Consensus.V1\xca\x02\x15\x43ometbft\\Consensus\\V1\xe2\x02!Cometbft\\Consensus\\V1\\GPBMetadata\xea\x02\x17\x43ometbft::Consensus::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.consensus.v1.wal_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.cometbft.consensus.v1B\010WalProtoP\001Z6github.com/cometbft/cometbft/api/cometbft/consensus/v1\242\002\003CCX\252\002\025Cometbft.Consensus.V1\312\002\025Cometbft\\Consensus\\V1\342\002!Cometbft\\Consensus\\V1\\GPBMetadata\352\002\027Cometbft::Consensus::V1'
  _globals['_MSGINFO'].fields_by_name['msg']._loaded_options = None
  _globals['_MSGINFO'].fields_by_name['msg']._serialized_options = b'\310\336\037\000'
  _globals['_MSGINFO'].fields_by_name['peer_id']._loaded_options = None
  _globals['_MSGINFO'].fields_by_name['peer_id']._serialized_options = b'\342\336\037\006PeerID'
  _globals['_MSGINFO'].fields_by_name['receive_time']._loaded_options = None
  _globals['_MSGINFO'].fields_by_name['receive_time']._serialized_options = b'\310\336\037\001\220\337\037\001'
  _globals['_TIMEOUTINFO'].fields_by_name['duration']._loaded_options = None
  _globals['_TIMEOUTINFO'].fields_by_name['duration']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_TIMEDWALMESSAGE'].fields_by_name['time']._loaded_options = None
  _globals['_TIMEDWALMESSAGE'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_MSGINFO']._serialized_start=213
  _globals['_MSGINFO']._serialized_end=388
  _globals['_TIMEOUTINFO']._serialized_start=391
  _globals['_TIMEOUTINFO']._serialized_end=535
  _globals['_ENDHEIGHT']._serialized_start=537
  _globals['_ENDHEIGHT']._serialized_end=572
  _globals['_WALMESSAGE']._serialized_start=575
  _globals['_WALMESSAGE']._serialized_end=890
  _globals['_TIMEDWALMESSAGE']._serialized_start=893
  _globals['_TIMEDWALMESSAGE']._serialized_end=1021
# @@protoc_insertion_point(module_scope)
