# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/permissions/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.injective.permissions.v1beta1 import params_pb2 as injective_dot_permissions_dot_v1beta1_dot_params__pb2
from pyinjective.proto.injective.permissions.v1beta1 import genesis_pb2 as injective_dot_permissions_dot_v1beta1_dot_genesis__pb2
from pyinjective.proto.injective.permissions.v1beta1 import permissions_pb2 as injective_dot_permissions_dot_v1beta1_dot_permissions__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)injective/permissions/v1beta1/query.proto\x12\x1dinjective.permissions.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a*injective/permissions/v1beta1/params.proto\x1a+injective/permissions/v1beta1/genesis.proto\x1a/injective/permissions/v1beta1/permissions.proto\"\x14\n\x12QueryParamsRequest\"Z\n\x13QueryParamsResponse\x12\x43\n\x06params\x18\x01 \x01(\x0b\x32%.injective.permissions.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"\x1d\n\x1bQueryNamespaceDenomsRequest\"6\n\x1cQueryNamespaceDenomsResponse\x12\x16\n\x06\x64\x65noms\x18\x01 \x03(\tR\x06\x64\x65noms\"\x18\n\x16QueryNamespacesRequest\"c\n\x17QueryNamespacesResponse\x12H\n\nnamespaces\x18\x01 \x03(\x0b\x32(.injective.permissions.v1beta1.NamespaceR\nnamespaces\"-\n\x15QueryNamespaceRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\"`\n\x16QueryNamespaceResponse\x12\x46\n\tnamespace\x18\x01 \x01(\x0b\x32(.injective.permissions.v1beta1.NamespaceR\tnamespace\"D\n\x18QueryActorsByRoleRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x12\n\x04role\x18\x02 \x01(\tR\x04role\"3\n\x19QueryActorsByRoleResponse\x12\x16\n\x06\x61\x63tors\x18\x01 \x03(\tR\x06\x61\x63tors\"F\n\x18QueryRolesByActorRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x14\n\x05\x61\x63tor\x18\x02 \x01(\tR\x05\x61\x63tor\"1\n\x19QueryRolesByActorResponse\x12\x14\n\x05roles\x18\x01 \x03(\tR\x05roles\"0\n\x18QueryRoleManagersRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\"l\n\x19QueryRoleManagersResponse\x12O\n\rrole_managers\x18\x01 \x03(\x0b\x32*.injective.permissions.v1beta1.RoleManagerR\x0croleManagers\"I\n\x17QueryRoleManagerRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x18\n\x07manager\x18\x02 \x01(\tR\x07manager\"i\n\x18QueryRoleManagerResponse\x12M\n\x0crole_manager\x18\x01 \x01(\x0b\x32*.injective.permissions.v1beta1.RoleManagerR\x0broleManager\"2\n\x1aQueryPolicyStatusesRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\"s\n\x1bQueryPolicyStatusesResponse\x12T\n\x0fpolicy_statuses\x18\x01 \x03(\x0b\x32+.injective.permissions.v1beta1.PolicyStatusR\x0epolicyStatuses\"=\n%QueryPolicyManagerCapabilitiesRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\"\xa0\x01\n&QueryPolicyManagerCapabilitiesResponse\x12v\n\x1bpolicy_manager_capabilities\x18\x01 \x03(\x0b\x32\x36.injective.permissions.v1beta1.PolicyManagerCapabilityR\x19policyManagerCapabilities\",\n\x14QueryVouchersRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\"b\n\x15QueryVouchersResponse\x12I\n\x08vouchers\x18\x01 \x03(\x0b\x32-.injective.permissions.v1beta1.AddressVoucherR\x08vouchers\"E\n\x13QueryVoucherRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\"\x91\x01\n\x14QueryVoucherResponse\x12y\n\x07voucher\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xc8\xde\x1f\x00\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\xea\xde\x1f\x11voucher,omitemptyR\x07voucher\"\x19\n\x17QueryModuleStateRequest\"]\n\x18QueryModuleStateResponse\x12\x41\n\x05state\x18\x01 \x01(\x0b\x32+.injective.permissions.v1beta1.GenesisStateR\x05state2\xdd\x13\n\x05Query\x12\x9e\x01\n\x06Params\x12\x31.injective.permissions.v1beta1.QueryParamsRequest\x1a\x32.injective.permissions.v1beta1.QueryParamsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/injective/permissions/v1beta1/params\x12\xc3\x01\n\x0fNamespaceDenoms\x12:.injective.permissions.v1beta1.QueryNamespaceDenomsRequest\x1a;.injective.permissions.v1beta1.QueryNamespaceDenomsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/permissions/v1beta1/namespace_denoms\x12\xae\x01\n\nNamespaces\x12\x35.injective.permissions.v1beta1.QueryNamespacesRequest\x1a\x36.injective.permissions.v1beta1.QueryNamespacesResponse\"1\x82\xd3\xe4\x93\x02+\x12)/injective/permissions/v1beta1/namespaces\x12\xb2\x01\n\tNamespace\x12\x34.injective.permissions.v1beta1.QueryNamespaceRequest\x1a\x35.injective.permissions.v1beta1.QueryNamespaceResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/injective/permissions/v1beta1/namespace/{denom}\x12\xc8\x01\n\x0cRolesByActor\x12\x37.injective.permissions.v1beta1.QueryRolesByActorRequest\x1a\x38.injective.permissions.v1beta1.QueryRolesByActorResponse\"E\x82\xd3\xe4\x93\x02?\x12=/injective/permissions/v1beta1/roles_by_actor/{denom}/{actor}\x12\xc7\x01\n\x0c\x41\x63torsByRole\x12\x37.injective.permissions.v1beta1.QueryActorsByRoleRequest\x1a\x38.injective.permissions.v1beta1.QueryActorsByRoleResponse\"D\x82\xd3\xe4\x93\x02>\x12</injective/permissions/v1beta1/actors_by_role/{denom}/{role}\x12\xbf\x01\n\x0cRoleManagers\x12\x37.injective.permissions.v1beta1.QueryRoleManagersRequest\x1a\x38.injective.permissions.v1beta1.QueryRoleManagersResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/injective/permissions/v1beta1/role_managers/{denom}\x12\xc5\x01\n\x0bRoleManager\x12\x36.injective.permissions.v1beta1.QueryRoleManagerRequest\x1a\x37.injective.permissions.v1beta1.QueryRoleManagerResponse\"E\x82\xd3\xe4\x93\x02?\x12=/injective/permissions/v1beta1/role_manager/{denom}/{manager}\x12\xc7\x01\n\x0ePolicyStatuses\x12\x39.injective.permissions.v1beta1.QueryPolicyStatusesRequest\x1a:.injective.permissions.v1beta1.QueryPolicyStatusesResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/injective/permissions/v1beta1/policy_statuses/{denom}\x12\xf4\x01\n\x19PolicyManagerCapabilities\x12\x44.injective.permissions.v1beta1.QueryPolicyManagerCapabilitiesRequest\x1a\x45.injective.permissions.v1beta1.QueryPolicyManagerCapabilitiesResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/injective/permissions/v1beta1/policy_manager_capabilities/{denom}\x12\xae\x01\n\x08Vouchers\x12\x33.injective.permissions.v1beta1.QueryVouchersRequest\x1a\x34.injective.permissions.v1beta1.QueryVouchersResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/permissions/v1beta1/vouchers/{denom}\x12\xb4\x01\n\x07Voucher\x12\x32.injective.permissions.v1beta1.QueryVoucherRequest\x1a\x33.injective.permissions.v1beta1.QueryVoucherResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/injective/permissions/v1beta1/voucher/{denom}/{address}\x12\xbe\x01\n\x16PermissionsModuleState\x12\x36.injective.permissions.v1beta1.QueryModuleStateRequest\x1a\x37.injective.permissions.v1beta1.QueryModuleStateResponse\"3\x82\xd3\xe4\x93\x02-\x12+/injective/permissions/v1beta1/module_stateB\x98\x02\n!com.injective.permissions.v1beta1B\nQueryProtoP\x01ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/permissions/types\xa2\x02\x03IPX\xaa\x02\x1dInjective.Permissions.V1beta1\xca\x02\x1dInjective\\Permissions\\V1beta1\xe2\x02)Injective\\Permissions\\V1beta1\\GPBMetadata\xea\x02\x1fInjective::Permissions::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.permissions.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.injective.permissions.v1beta1B\nQueryProtoP\001ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/permissions/types\242\002\003IPX\252\002\035Injective.Permissions.V1beta1\312\002\035Injective\\Permissions\\V1beta1\342\002)Injective\\Permissions\\V1beta1\\GPBMetadata\352\002\037Injective::Permissions::V1beta1'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVOUCHERRESPONSE'].fields_by_name['voucher']._loaded_options = None
  _globals['_QUERYVOUCHERRESPONSE'].fields_by_name['voucher']._serialized_options = b'\310\336\037\000\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin\352\336\037\021voucher,omitempty'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\'\022%/injective/permissions/v1beta1/params'
  _globals['_QUERY'].methods_by_name['NamespaceDenoms']._loaded_options = None
  _globals['_QUERY'].methods_by_name['NamespaceDenoms']._serialized_options = b'\202\323\344\223\0021\022//injective/permissions/v1beta1/namespace_denoms'
  _globals['_QUERY'].methods_by_name['Namespaces']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Namespaces']._serialized_options = b'\202\323\344\223\002+\022)/injective/permissions/v1beta1/namespaces'
  _globals['_QUERY'].methods_by_name['Namespace']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Namespace']._serialized_options = b'\202\323\344\223\0022\0220/injective/permissions/v1beta1/namespace/{denom}'
  _globals['_QUERY'].methods_by_name['RolesByActor']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RolesByActor']._serialized_options = b'\202\323\344\223\002?\022=/injective/permissions/v1beta1/roles_by_actor/{denom}/{actor}'
  _globals['_QUERY'].methods_by_name['ActorsByRole']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ActorsByRole']._serialized_options = b'\202\323\344\223\002>\022</injective/permissions/v1beta1/actors_by_role/{denom}/{role}'
  _globals['_QUERY'].methods_by_name['RoleManagers']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RoleManagers']._serialized_options = b'\202\323\344\223\0026\0224/injective/permissions/v1beta1/role_managers/{denom}'
  _globals['_QUERY'].methods_by_name['RoleManager']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RoleManager']._serialized_options = b'\202\323\344\223\002?\022=/injective/permissions/v1beta1/role_manager/{denom}/{manager}'
  _globals['_QUERY'].methods_by_name['PolicyStatuses']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PolicyStatuses']._serialized_options = b'\202\323\344\223\0028\0226/injective/permissions/v1beta1/policy_statuses/{denom}'
  _globals['_QUERY'].methods_by_name['PolicyManagerCapabilities']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PolicyManagerCapabilities']._serialized_options = b'\202\323\344\223\002D\022B/injective/permissions/v1beta1/policy_manager_capabilities/{denom}'
  _globals['_QUERY'].methods_by_name['Vouchers']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Vouchers']._serialized_options = b'\202\323\344\223\0021\022//injective/permissions/v1beta1/vouchers/{denom}'
  _globals['_QUERY'].methods_by_name['Voucher']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Voucher']._serialized_options = b'\202\323\344\223\002:\0228/injective/permissions/v1beta1/voucher/{denom}/{address}'
  _globals['_QUERY'].methods_by_name['PermissionsModuleState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PermissionsModuleState']._serialized_options = b'\202\323\344\223\002-\022+/injective/permissions/v1beta1/module_state'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=342
  _globals['_QUERYPARAMSREQUEST']._serialized_end=362
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=364
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=454
  _globals['_QUERYNAMESPACEDENOMSREQUEST']._serialized_start=456
  _globals['_QUERYNAMESPACEDENOMSREQUEST']._serialized_end=485
  _globals['_QUERYNAMESPACEDENOMSRESPONSE']._serialized_start=487
  _globals['_QUERYNAMESPACEDENOMSRESPONSE']._serialized_end=541
  _globals['_QUERYNAMESPACESREQUEST']._serialized_start=543
  _globals['_QUERYNAMESPACESREQUEST']._serialized_end=567
  _globals['_QUERYNAMESPACESRESPONSE']._serialized_start=569
  _globals['_QUERYNAMESPACESRESPONSE']._serialized_end=668
  _globals['_QUERYNAMESPACEREQUEST']._serialized_start=670
  _globals['_QUERYNAMESPACEREQUEST']._serialized_end=715
  _globals['_QUERYNAMESPACERESPONSE']._serialized_start=717
  _globals['_QUERYNAMESPACERESPONSE']._serialized_end=813
  _globals['_QUERYACTORSBYROLEREQUEST']._serialized_start=815
  _globals['_QUERYACTORSBYROLEREQUEST']._serialized_end=883
  _globals['_QUERYACTORSBYROLERESPONSE']._serialized_start=885
  _globals['_QUERYACTORSBYROLERESPONSE']._serialized_end=936
  _globals['_QUERYROLESBYACTORREQUEST']._serialized_start=938
  _globals['_QUERYROLESBYACTORREQUEST']._serialized_end=1008
  _globals['_QUERYROLESBYACTORRESPONSE']._serialized_start=1010
  _globals['_QUERYROLESBYACTORRESPONSE']._serialized_end=1059
  _globals['_QUERYROLEMANAGERSREQUEST']._serialized_start=1061
  _globals['_QUERYROLEMANAGERSREQUEST']._serialized_end=1109
  _globals['_QUERYROLEMANAGERSRESPONSE']._serialized_start=1111
  _globals['_QUERYROLEMANAGERSRESPONSE']._serialized_end=1219
  _globals['_QUERYROLEMANAGERREQUEST']._serialized_start=1221
  _globals['_QUERYROLEMANAGERREQUEST']._serialized_end=1294
  _globals['_QUERYROLEMANAGERRESPONSE']._serialized_start=1296
  _globals['_QUERYROLEMANAGERRESPONSE']._serialized_end=1401
  _globals['_QUERYPOLICYSTATUSESREQUEST']._serialized_start=1403
  _globals['_QUERYPOLICYSTATUSESREQUEST']._serialized_end=1453
  _globals['_QUERYPOLICYSTATUSESRESPONSE']._serialized_start=1455
  _globals['_QUERYPOLICYSTATUSESRESPONSE']._serialized_end=1570
  _globals['_QUERYPOLICYMANAGERCAPABILITIESREQUEST']._serialized_start=1572
  _globals['_QUERYPOLICYMANAGERCAPABILITIESREQUEST']._serialized_end=1633
  _globals['_QUERYPOLICYMANAGERCAPABILITIESRESPONSE']._serialized_start=1636
  _globals['_QUERYPOLICYMANAGERCAPABILITIESRESPONSE']._serialized_end=1796
  _globals['_QUERYVOUCHERSREQUEST']._serialized_start=1798
  _globals['_QUERYVOUCHERSREQUEST']._serialized_end=1842
  _globals['_QUERYVOUCHERSRESPONSE']._serialized_start=1844
  _globals['_QUERYVOUCHERSRESPONSE']._serialized_end=1942
  _globals['_QUERYVOUCHERREQUEST']._serialized_start=1944
  _globals['_QUERYVOUCHERREQUEST']._serialized_end=2013
  _globals['_QUERYVOUCHERRESPONSE']._serialized_start=2016
  _globals['_QUERYVOUCHERRESPONSE']._serialized_end=2161
  _globals['_QUERYMODULESTATEREQUEST']._serialized_start=2163
  _globals['_QUERYMODULESTATEREQUEST']._serialized_end=2188
  _globals['_QUERYMODULESTATERESPONSE']._serialized_start=2190
  _globals['_QUERYMODULESTATERESPONSE']._serialized_end=2283
  _globals['_QUERY']._serialized_start=2286
  _globals['_QUERY']._serialized_end=4811
# @@protoc_insertion_point(module_scope)
