# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/types/v1beta2/params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cometbft.types.v1beta1 import params_pb2 as cometbft_dot_types_dot_v1beta1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cometbft/types/v1beta2/params.proto\x12\x16\x63ometbft.types.v1beta2\x1a\x14gogoproto/gogo.proto\x1a#cometbft/types/v1beta1/params.proto\"\x98\x02\n\x0f\x43onsensusParams\x12\x39\n\x05\x62lock\x18\x01 \x01(\x0b\x32#.cometbft.types.v1beta2.BlockParamsR\x05\x62lock\x12\x42\n\x08\x65vidence\x18\x02 \x01(\x0b\x32&.cometbft.types.v1beta1.EvidenceParamsR\x08\x65vidence\x12\x45\n\tvalidator\x18\x03 \x01(\x0b\x32\'.cometbft.types.v1beta1.ValidatorParamsR\tvalidator\x12?\n\x07version\x18\x04 \x01(\x0b\x32%.cometbft.types.v1beta1.VersionParamsR\x07version\"I\n\x0b\x42lockParams\x12\x1b\n\tmax_bytes\x18\x01 \x01(\x03R\x08maxBytes\x12\x17\n\x07max_gas\x18\x02 \x01(\x03R\x06maxGasJ\x04\x08\x03\x10\x04\x42\xe0\x01\n\x1a\x63om.cometbft.types.v1beta2B\x0bParamsProtoP\x01Z7github.com/cometbft/cometbft/api/cometbft/types/v1beta2\xa2\x02\x03\x43TX\xaa\x02\x16\x43ometbft.Types.V1beta2\xca\x02\x16\x43ometbft\\Types\\V1beta2\xe2\x02\"Cometbft\\Types\\V1beta2\\GPBMetadata\xea\x02\x18\x43ometbft::Types::V1beta2\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.types.v1beta2.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.cometbft.types.v1beta2B\013ParamsProtoP\001Z7github.com/cometbft/cometbft/api/cometbft/types/v1beta2\242\002\003CTX\252\002\026Cometbft.Types.V1beta2\312\002\026Cometbft\\Types\\V1beta2\342\002\"Cometbft\\Types\\V1beta2\\GPBMetadata\352\002\030Cometbft::Types::V1beta2\250\342\036\001'
  _globals['_CONSENSUSPARAMS']._serialized_start=123
  _globals['_CONSENSUSPARAMS']._serialized_end=403
  _globals['_BLOCKPARAMS']._serialized_start=405
  _globals['_BLOCKPARAMS']._serialized_end=478
# @@protoc_insertion_point(module_scope)
