# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%injective/oracle/v1beta1/events.proto\x12\x18injective.oracle.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a%injective/oracle/v1beta1/oracle.proto\"\x8c\x01\n\x16SetChainlinkPriceEvent\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\tR\x06\x66\x65\x65\x64Id\x12;\n\x06\x61nswer\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06\x61nswer\x12\x1c\n\ttimestamp\x18\x03 \x01(\x04R\ttimestamp\"\xc2\x01\n\x11SetBandPriceEvent\x12\x18\n\x07relayer\x18\x01 \x01(\tR\x07relayer\x12\x16\n\x06symbol\x18\x02 \x01(\tR\x06symbol\x12\x39\n\x05price\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12!\n\x0cresolve_time\x18\x04 \x01(\x04R\x0bresolveTime\x12\x1d\n\nrequest_id\x18\x05 \x01(\x04R\trequestId\"\xe6\x01\n\x14SetBandIBCPriceEvent\x12\x18\n\x07relayer\x18\x01 \x01(\tR\x07relayer\x12\x18\n\x07symbols\x18\x02 \x03(\tR\x07symbols\x12;\n\x06prices\x18\x03 \x03(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06prices\x12!\n\x0cresolve_time\x18\x04 \x01(\x04R\x0bresolveTime\x12\x1d\n\nrequest_id\x18\x05 \x01(\x04R\trequestId\x12\x1b\n\tclient_id\x18\x06 \x01(\x03R\x08\x63lientId\"T\n\x16\x45ventBandIBCAckSuccess\x12\x1d\n\nack_result\x18\x01 \x01(\tR\tackResult\x12\x1b\n\tclient_id\x18\x02 \x01(\x03R\x08\x63lientId\"P\n\x14\x45ventBandIBCAckError\x12\x1b\n\tack_error\x18\x01 \x01(\tR\x08\x61\x63kError\x12\x1b\n\tclient_id\x18\x02 \x01(\x03R\x08\x63lientId\":\n\x1b\x45ventBandIBCResponseTimeout\x12\x1b\n\tclient_id\x18\x01 \x01(\x03R\x08\x63lientId\"\x97\x01\n\x16SetPriceFeedPriceEvent\x12\x18\n\x07relayer\x18\x01 \x01(\tR\x07relayer\x12\x12\n\x04\x62\x61se\x18\x02 \x01(\tR\x04\x62\x61se\x12\x14\n\x05quote\x18\x03 \x01(\tR\x05quote\x12\x39\n\x05price\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\"\xa0\x01\n\x15SetProviderPriceEvent\x12\x1a\n\x08provider\x18\x01 \x01(\tR\x08provider\x12\x18\n\x07relayer\x18\x02 \x01(\tR\x07relayer\x12\x16\n\x06symbol\x18\x03 \x01(\tR\x06symbol\x12\x39\n\x05price\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\"\x88\x01\n\x15SetCoinbasePriceEvent\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x39\n\x05price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12\x1c\n\ttimestamp\x18\x03 \x01(\x04R\ttimestamp\"X\n\x13\x45ventSetStorkPrices\x12\x41\n\x06prices\x18\x01 \x03(\x0b\x32).injective.oracle.v1beta1.StorkPriceStateR\x06prices\"V\n\x12\x45ventSetPythPrices\x12@\n\x06prices\x18\x01 \x03(\x0b\x32(.injective.oracle.v1beta1.PythPriceStateR\x06pricesB\xfb\x01\n\x1c\x63om.injective.oracle.v1beta1B\x0b\x45ventsProtoP\x01ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\xa2\x02\x03IOX\xaa\x02\x18Injective.Oracle.V1beta1\xca\x02\x18Injective\\Oracle\\V1beta1\xe2\x02$Injective\\Oracle\\V1beta1\\GPBMetadata\xea\x02\x1aInjective::Oracle::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.oracle.v1beta1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.injective.oracle.v1beta1B\013EventsProtoP\001ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\242\002\003IOX\252\002\030Injective.Oracle.V1beta1\312\002\030Injective\\Oracle\\V1beta1\342\002$Injective\\Oracle\\V1beta1\\GPBMetadata\352\002\032Injective::Oracle::V1beta1'
  _globals['_SETCHAINLINKPRICEEVENT'].fields_by_name['answer']._loaded_options = None
  _globals['_SETCHAINLINKPRICEEVENT'].fields_by_name['answer']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SETBANDPRICEEVENT'].fields_by_name['price']._loaded_options = None
  _globals['_SETBANDPRICEEVENT'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SETBANDIBCPRICEEVENT'].fields_by_name['prices']._loaded_options = None
  _globals['_SETBANDIBCPRICEEVENT'].fields_by_name['prices']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SETPRICEFEEDPRICEEVENT'].fields_by_name['price']._loaded_options = None
  _globals['_SETPRICEFEEDPRICEEVENT'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SETPROVIDERPRICEEVENT'].fields_by_name['price']._loaded_options = None
  _globals['_SETPROVIDERPRICEEVENT'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SETCOINBASEPRICEEVENT'].fields_by_name['price']._loaded_options = None
  _globals['_SETCOINBASEPRICEEVENT'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SETCHAINLINKPRICEEVENT']._serialized_start=161
  _globals['_SETCHAINLINKPRICEEVENT']._serialized_end=301
  _globals['_SETBANDPRICEEVENT']._serialized_start=304
  _globals['_SETBANDPRICEEVENT']._serialized_end=498
  _globals['_SETBANDIBCPRICEEVENT']._serialized_start=501
  _globals['_SETBANDIBCPRICEEVENT']._serialized_end=731
  _globals['_EVENTBANDIBCACKSUCCESS']._serialized_start=733
  _globals['_EVENTBANDIBCACKSUCCESS']._serialized_end=817
  _globals['_EVENTBANDIBCACKERROR']._serialized_start=819
  _globals['_EVENTBANDIBCACKERROR']._serialized_end=899
  _globals['_EVENTBANDIBCRESPONSETIMEOUT']._serialized_start=901
  _globals['_EVENTBANDIBCRESPONSETIMEOUT']._serialized_end=959
  _globals['_SETPRICEFEEDPRICEEVENT']._serialized_start=962
  _globals['_SETPRICEFEEDPRICEEVENT']._serialized_end=1113
  _globals['_SETPROVIDERPRICEEVENT']._serialized_start=1116
  _globals['_SETPROVIDERPRICEEVENT']._serialized_end=1276
  _globals['_SETCOINBASEPRICEEVENT']._serialized_start=1279
  _globals['_SETCOINBASEPRICEEVENT']._serialized_end=1415
  _globals['_EVENTSETSTORKPRICES']._serialized_start=1417
  _globals['_EVENTSETSTORKPRICES']._serialized_end=1505
  _globals['_EVENTSETPYTHPRICES']._serialized_start=1507
  _globals['_EVENTSETPYTHPRICES']._serialized_end=1593
# @@protoc_insertion_point(module_scope)
