# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&injective/oracle/v1beta1/genesis.proto\x12\x18injective.oracle.v1beta1\x1a%injective/oracle/v1beta1/oracle.proto\x1a\x14gogoproto/gogo.proto\"\xe4\n\n\x0cGenesisState\x12>\n\x06params\x18\x01 \x01(\x0b\x32 .injective.oracle.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\x12#\n\rband_relayers\x18\x02 \x03(\tR\x0c\x62\x61ndRelayers\x12T\n\x11\x62\x61nd_price_states\x18\x03 \x03(\x0b\x32(.injective.oracle.v1beta1.BandPriceStateR\x0f\x62\x61ndPriceStates\x12_\n\x17price_feed_price_states\x18\x04 \x03(\x0b\x32(.injective.oracle.v1beta1.PriceFeedStateR\x14priceFeedPriceStates\x12`\n\x15\x63oinbase_price_states\x18\x05 \x03(\x0b\x32,.injective.oracle.v1beta1.CoinbasePriceStateR\x13\x63oinbasePriceStates\x12[\n\x15\x62\x61nd_ibc_price_states\x18\x06 \x03(\x0b\x32(.injective.oracle.v1beta1.BandPriceStateR\x12\x62\x61ndIbcPriceStates\x12\x64\n\x18\x62\x61nd_ibc_oracle_requests\x18\x07 \x03(\x0b\x32+.injective.oracle.v1beta1.BandOracleRequestR\x15\x62\x61ndIbcOracleRequests\x12U\n\x0f\x62\x61nd_ibc_params\x18\x08 \x01(\x0b\x32\'.injective.oracle.v1beta1.BandIBCParamsB\x04\xc8\xde\x1f\x00R\rbandIbcParams\x12\x38\n\x19\x62\x61nd_ibc_latest_client_id\x18\t \x01(\x04R\x15\x62\x61ndIbcLatestClientId\x12S\n\x10\x63\x61lldata_records\x18\n \x03(\x0b\x32(.injective.oracle.v1beta1.CalldataRecordR\x0f\x63\x61lldataRecords\x12:\n\x1a\x62\x61nd_ibc_latest_request_id\x18\x0b \x01(\x04R\x16\x62\x61ndIbcLatestRequestId\x12\x63\n\x16\x63hainlink_price_states\x18\x0c \x03(\x0b\x32-.injective.oracle.v1beta1.ChainlinkPriceStateR\x14\x63hainlinkPriceStates\x12`\n\x18historical_price_records\x18\r \x03(\x0b\x32&.injective.oracle.v1beta1.PriceRecordsR\x16historicalPriceRecords\x12P\n\x0fprovider_states\x18\x0e \x03(\x0b\x32\'.injective.oracle.v1beta1.ProviderStateR\x0eproviderStates\x12T\n\x11pyth_price_states\x18\x0f \x03(\x0b\x32(.injective.oracle.v1beta1.PythPriceStateR\x0fpythPriceStates\x12W\n\x12stork_price_states\x18\x10 \x03(\x0b\x32).injective.oracle.v1beta1.StorkPriceStateR\x10storkPriceStates\x12)\n\x10stork_publishers\x18\x11 \x03(\tR\x0fstorkPublishers\"I\n\x0e\x43\x61lldataRecord\x12\x1b\n\tclient_id\x18\x01 \x01(\x04R\x08\x63lientId\x12\x1a\n\x08\x63\x61lldata\x18\x02 \x01(\x0cR\x08\x63\x61lldataB\xfc\x01\n\x1c\x63om.injective.oracle.v1beta1B\x0cGenesisProtoP\x01ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\xa2\x02\x03IOX\xaa\x02\x18Injective.Oracle.V1beta1\xca\x02\x18Injective\\Oracle\\V1beta1\xe2\x02$Injective\\Oracle\\V1beta1\\GPBMetadata\xea\x02\x1aInjective::Oracle::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.oracle.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.injective.oracle.v1beta1B\014GenesisProtoP\001ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\242\002\003IOX\252\002\030Injective.Oracle.V1beta1\312\002\030Injective\\Oracle\\V1beta1\342\002$Injective\\Oracle\\V1beta1\\GPBMetadata\352\002\032Injective::Oracle::V1beta1'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['band_ibc_params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['band_ibc_params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=130
  _globals['_GENESISSTATE']._serialized_end=1510
  _globals['_CALLDATARECORD']._serialized_start=1512
  _globals['_CALLDATARECORD']._serialized_end=1585
# @@protoc_insertion_point(module_scope)
