# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/types/v1beta1/tx_response.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)injective/types/v1beta1/tx_response.proto\x12\x17injective.types.v1beta1\"F\n\x18TxResponseGenericMessage\x12\x16\n\x06header\x18\x01 \x01(\tR\x06header\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\"_\n\x0eTxResponseData\x12M\n\x08messages\x18\x01 \x03(\x0b\x32\x31.injective.types.v1beta1.TxResponseGenericMessageR\x08messagesB\xeb\x01\n\x1b\x63om.injective.types.v1beta1B\x0fTxResponseProtoP\x01Z=github.com/InjectiveLabs/injective-core/injective-chain/types\xa2\x02\x03ITX\xaa\x02\x17Injective.Types.V1beta1\xca\x02\x17Injective\\Types\\V1beta1\xe2\x02#Injective\\Types\\V1beta1\\GPBMetadata\xea\x02\x19Injective::Types::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.types.v1beta1.tx_response_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.injective.types.v1beta1B\017TxResponseProtoP\001Z=github.com/InjectiveLabs/injective-core/injective-chain/types\242\002\003ITX\252\002\027Injective.Types.V1beta1\312\002\027Injective\\Types\\V1beta1\342\002#Injective\\Types\\V1beta1\\GPBMetadata\352\002\031Injective::Types::V1beta1'
  _globals['_TXRESPONSEGENERICMESSAGE']._serialized_start=70
  _globals['_TXRESPONSEGENERICMESSAGE']._serialized_end=140
  _globals['_TXRESPONSEDATA']._serialized_start=142
  _globals['_TXRESPONSEDATA']._serialized_end=237
# @@protoc_insertion_point(module_scope)
