# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/channel/v1/upgrade.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ibc/core/channel/v1/upgrade.proto\x12\x13ibc.core.channel.v1\x1a\x14gogoproto/gogo.proto\x1a!ibc/core/channel/v1/channel.proto\"\xbd\x01\n\x07Upgrade\x12@\n\x06\x66ields\x18\x01 \x01(\x0b\x32\".ibc.core.channel.v1.UpgradeFieldsB\x04\xc8\xde\x1f\x00R\x06\x66ields\x12<\n\x07timeout\x18\x02 \x01(\x0b\x32\x1c.ibc.core.channel.v1.TimeoutB\x04\xc8\xde\x1f\x00R\x07timeout\x12,\n\x12next_sequence_send\x18\x03 \x01(\x04R\x10nextSequenceSend:\x04\x88\xa0\x1f\x00\"\x90\x01\n\rUpgradeFields\x12\x36\n\x08ordering\x18\x01 \x01(\x0e\x32\x1a.ibc.core.channel.v1.OrderR\x08ordering\x12\'\n\x0f\x63onnection_hops\x18\x02 \x03(\tR\x0e\x63onnectionHops\x12\x18\n\x07version\x18\x03 \x01(\tR\x07version:\x04\x88\xa0\x1f\x00\"J\n\x0c\x45rrorReceipt\x12\x1a\n\x08sequence\x18\x01 \x01(\x04R\x08sequence\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message:\x04\x88\xa0\x1f\x00\x42\xd1\x01\n\x17\x63om.ibc.core.channel.v1B\x0cUpgradeProtoP\x01Z9github.com/cosmos/ibc-go/v8/modules/core/04-channel/types\xa2\x02\x03ICC\xaa\x02\x13Ibc.Core.Channel.V1\xca\x02\x13Ibc\\Core\\Channel\\V1\xe2\x02\x1fIbc\\Core\\Channel\\V1\\GPBMetadata\xea\x02\x16Ibc::Core::Channel::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.channel.v1.upgrade_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.ibc.core.channel.v1B\014UpgradeProtoP\001Z9github.com/cosmos/ibc-go/v8/modules/core/04-channel/types\242\002\003ICC\252\002\023Ibc.Core.Channel.V1\312\002\023Ibc\\Core\\Channel\\V1\342\002\037Ibc\\Core\\Channel\\V1\\GPBMetadata\352\002\026Ibc::Core::Channel::V1'
  _globals['_UPGRADE'].fields_by_name['fields']._loaded_options = None
  _globals['_UPGRADE'].fields_by_name['fields']._serialized_options = b'\310\336\037\000'
  _globals['_UPGRADE'].fields_by_name['timeout']._loaded_options = None
  _globals['_UPGRADE'].fields_by_name['timeout']._serialized_options = b'\310\336\037\000'
  _globals['_UPGRADE']._loaded_options = None
  _globals['_UPGRADE']._serialized_options = b'\210\240\037\000'
  _globals['_UPGRADEFIELDS']._loaded_options = None
  _globals['_UPGRADEFIELDS']._serialized_options = b'\210\240\037\000'
  _globals['_ERRORRECEIPT']._loaded_options = None
  _globals['_ERRORRECEIPT']._serialized_options = b'\210\240\037\000'
  _globals['_UPGRADE']._serialized_start=116
  _globals['_UPGRADE']._serialized_end=305
  _globals['_UPGRADEFIELDS']._serialized_start=308
  _globals['_UPGRADEFIELDS']._serialized_end=452
  _globals['_ERRORRECEIPT']._serialized_start=454
  _globals['_ERRORRECEIPT']._serialized_end=528
# @@protoc_insertion_point(module_scope)
