# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/evm/v1/log.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ainjective/evm/v1/log.proto\x12\x10injective.evm.v1\x1a\x14gogoproto/gogo.proto\"\xca\x02\n\x03Log\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x16\n\x06topics\x18\x02 \x03(\tR\x06topics\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\x12\x32\n\x0c\x62lock_number\x18\x04 \x01(\x04\x42\x0f\xea\xde\x1f\x0b\x62lockNumberR\x0b\x62lockNumber\x12,\n\x07tx_hash\x18\x05 \x01(\tB\x13\xea\xde\x1f\x0ftransactionHashR\x06txHash\x12/\n\x08tx_index\x18\x06 \x01(\x04\x42\x14\xea\xde\x1f\x10transactionIndexR\x07txIndex\x12,\n\nblock_hash\x18\x07 \x01(\tB\r\xea\xde\x1f\tblockHashR\tblockHash\x12\"\n\x05index\x18\x08 \x01(\x04\x42\x0c\xea\xde\x1f\x08logIndexR\x05index\x12\x18\n\x07removed\x18\t \x01(\x08R\x07removedB\xcd\x01\n\x14\x63om.injective.evm.v1B\x08LogProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\xa2\x02\x03IEX\xaa\x02\x10Injective.Evm.V1\xca\x02\x10Injective\\Evm\\V1\xe2\x02\x1cInjective\\Evm\\V1\\GPBMetadata\xea\x02\x12Injective::Evm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.evm.v1.log_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.injective.evm.v1B\010LogProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\242\002\003IEX\252\002\020Injective.Evm.V1\312\002\020Injective\\Evm\\V1\342\002\034Injective\\Evm\\V1\\GPBMetadata\352\002\022Injective::Evm::V1'
  _globals['_LOG'].fields_by_name['block_number']._loaded_options = None
  _globals['_LOG'].fields_by_name['block_number']._serialized_options = b'\352\336\037\013blockNumber'
  _globals['_LOG'].fields_by_name['tx_hash']._loaded_options = None
  _globals['_LOG'].fields_by_name['tx_hash']._serialized_options = b'\352\336\037\017transactionHash'
  _globals['_LOG'].fields_by_name['tx_index']._loaded_options = None
  _globals['_LOG'].fields_by_name['tx_index']._serialized_options = b'\352\336\037\020transactionIndex'
  _globals['_LOG'].fields_by_name['block_hash']._loaded_options = None
  _globals['_LOG'].fields_by_name['block_hash']._serialized_options = b'\352\336\037\tblockHash'
  _globals['_LOG'].fields_by_name['index']._loaded_options = None
  _globals['_LOG'].fields_by_name['index']._serialized_options = b'\352\336\037\010logIndex'
  _globals['_LOG']._serialized_start=71
  _globals['_LOG']._serialized_end=401
# @@protoc_insertion_point(module_scope)
