# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/connection/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.ibc.core.connection.v1 import connection_pb2 as ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ibc/core/connection/v1/genesis.proto\x12\x16ibc.core.connection.v1\x1a\x14gogoproto/gogo.proto\x1a\'ibc/core/connection/v1/connection.proto\"\xc3\x02\n\x0cGenesisState\x12T\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32,.ibc.core.connection.v1.IdentifiedConnectionB\x04\xc8\xde\x1f\x00R\x0b\x63onnections\x12\x65\n\x17\x63lient_connection_paths\x18\x02 \x03(\x0b\x32\'.ibc.core.connection.v1.ConnectionPathsB\x04\xc8\xde\x1f\x00R\x15\x63lientConnectionPaths\x12\x38\n\x18next_connection_sequence\x18\x03 \x01(\x04R\x16nextConnectionSequence\x12<\n\x06params\x18\x04 \x01(\x0b\x32\x1e.ibc.core.connection.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06paramsB\xe3\x01\n\x1a\x63om.ibc.core.connection.v1B\x0cGenesisProtoP\x01Z<github.com/cosmos/ibc-go/v8/modules/core/03-connection/types\xa2\x02\x03ICC\xaa\x02\x16Ibc.Core.Connection.V1\xca\x02\x16Ibc\\Core\\Connection\\V1\xe2\x02\"Ibc\\Core\\Connection\\V1\\GPBMetadata\xea\x02\x19Ibc::Core::Connection::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.connection.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.ibc.core.connection.v1B\014GenesisProtoP\001Z<github.com/cosmos/ibc-go/v8/modules/core/03-connection/types\242\002\003ICC\252\002\026Ibc.Core.Connection.V1\312\002\026Ibc\\Core\\Connection\\V1\342\002\"Ibc\\Core\\Connection\\V1\\GPBMetadata\352\002\031Ibc::Core::Connection::V1'
  _globals['_GENESISSTATE'].fields_by_name['connections']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['connections']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['client_connection_paths']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['client_connection_paths']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=128
  _globals['_GENESISSTATE']._serialized_end=451
# @@protoc_insertion_point(module_scope)
