# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from pyinjective.proto.injective.oracle.v1beta1 import genesis_pb2 as injective_dot_oracle_dot_v1beta1_dot_genesis__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$injective/oracle/v1beta1/query.proto\x12\x18injective.oracle.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a&injective/oracle/v1beta1/genesis.proto\x1a\x14gogoproto/gogo.proto\"2\n\x15QueryPythPriceRequest\x12\x19\n\x08price_id\x18\x01 \x01(\tR\x07priceId\"c\n\x16QueryPythPriceResponse\x12I\n\x0bprice_state\x18\x01 \x01(\x0b\x32(.injective.oracle.v1beta1.PythPriceStateR\npriceState\"\x14\n\x12QueryParamsRequest\"U\n\x13QueryParamsResponse\x12>\n\x06params\x18\x01 \x01(\x0b\x32 .injective.oracle.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"\x1a\n\x18QueryBandRelayersRequest\"7\n\x19QueryBandRelayersResponse\x12\x1a\n\x08relayers\x18\x01 \x03(\tR\x08relayers\"\x1d\n\x1bQueryBandPriceStatesRequest\"k\n\x1cQueryBandPriceStatesResponse\x12K\n\x0cprice_states\x18\x01 \x03(\x0b\x32(.injective.oracle.v1beta1.BandPriceStateR\x0bpriceStates\" \n\x1eQueryBandIBCPriceStatesRequest\"n\n\x1fQueryBandIBCPriceStatesResponse\x12K\n\x0cprice_states\x18\x01 \x03(\x0b\x32(.injective.oracle.v1beta1.BandPriceStateR\x0bpriceStates\"\"\n QueryPriceFeedPriceStatesRequest\"p\n!QueryPriceFeedPriceStatesResponse\x12K\n\x0cprice_states\x18\x01 \x03(\x0b\x32(.injective.oracle.v1beta1.PriceFeedStateR\x0bpriceStates\"!\n\x1fQueryCoinbasePriceStatesRequest\"s\n QueryCoinbasePriceStatesResponse\x12O\n\x0cprice_states\x18\x01 \x03(\x0b\x32,.injective.oracle.v1beta1.CoinbasePriceStateR\x0bpriceStates\"\x1d\n\x1bQueryPythPriceStatesRequest\"k\n\x1cQueryPythPriceStatesResponse\x12K\n\x0cprice_states\x18\x01 \x03(\x0b\x32(.injective.oracle.v1beta1.PythPriceStateR\x0bpriceStates\"\x1e\n\x1cQueryStorkPriceStatesRequest\"m\n\x1dQueryStorkPriceStatesResponse\x12L\n\x0cprice_states\x18\x01 \x03(\x0b\x32).injective.oracle.v1beta1.StorkPriceStateR\x0bpriceStates\"\x1d\n\x1bQueryStorkPublishersRequest\">\n\x1cQueryStorkPublishersResponse\x12\x1e\n\npublishers\x18\x01 \x03(\tR\npublishers\"T\n\x1eQueryProviderPriceStateRequest\x12\x1a\n\x08provider\x18\x01 \x01(\tR\x08provider\x12\x16\n\x06symbol\x18\x02 \x01(\tR\x06symbol\"h\n\x1fQueryProviderPriceStateResponse\x12\x45\n\x0bprice_state\x18\x01 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateR\npriceState\"\x19\n\x17QueryModuleStateRequest\"X\n\x18QueryModuleStateResponse\x12<\n\x05state\x18\x01 \x01(\x0b\x32&.injective.oracle.v1beta1.GenesisStateR\x05state\"\x7f\n\"QueryHistoricalPriceRecordsRequest\x12<\n\x06oracle\x18\x01 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleTypeR\x06oracle\x12\x1b\n\tsymbol_id\x18\x02 \x01(\tR\x08symbolId\"r\n#QueryHistoricalPriceRecordsResponse\x12K\n\rprice_records\x18\x01 \x03(\x0b\x32&.injective.oracle.v1beta1.PriceRecordsR\x0cpriceRecords\"\x8a\x01\n\x14OracleHistoryOptions\x12\x17\n\x07max_age\x18\x01 \x01(\x04R\x06maxAge\x12.\n\x13include_raw_history\x18\x02 \x01(\x08R\x11includeRawHistory\x12)\n\x10include_metadata\x18\x03 \x01(\x08R\x0fincludeMetadata\"\x8c\x02\n\x1cQueryOracleVolatilityRequest\x12\x41\n\tbase_info\x18\x01 \x01(\x0b\x32$.injective.oracle.v1beta1.OracleInfoR\x08\x62\x61seInfo\x12\x43\n\nquote_info\x18\x02 \x01(\x0b\x32$.injective.oracle.v1beta1.OracleInfoR\tquoteInfo\x12\x64\n\x16oracle_history_options\x18\x03 \x01(\x0b\x32..injective.oracle.v1beta1.OracleHistoryOptionsR\x14oracleHistoryOptions\"\x81\x02\n\x1dQueryOracleVolatilityResponse\x12?\n\nvolatility\x18\x01 \x01(\tB\x1f\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\nvolatility\x12W\n\x10history_metadata\x18\x02 \x01(\x0b\x32,.injective.oracle.v1beta1.MetadataStatisticsR\x0fhistoryMetadata\x12\x46\n\x0braw_history\x18\x03 \x03(\x0b\x32%.injective.oracle.v1beta1.PriceRecordR\nrawHistory\"!\n\x1fQueryOracleProvidersInfoRequest\"h\n QueryOracleProvidersInfoResponse\x12\x44\n\tproviders\x18\x01 \x03(\x0b\x32&.injective.oracle.v1beta1.ProviderInfoR\tproviders\">\n QueryOracleProviderPricesRequest\x12\x1a\n\x08provider\x18\x01 \x01(\tR\x08provider\"r\n!QueryOracleProviderPricesResponse\x12M\n\rproviderState\x18\x01 \x03(\x0b\x32\'.injective.oracle.v1beta1.ProviderStateR\rproviderState\"\\\n\x0eScalingOptions\x12#\n\rbase_decimals\x18\x01 \x01(\rR\x0c\x62\x61seDecimals\x12%\n\x0equote_decimals\x18\x02 \x01(\rR\rquoteDecimals\"\xe3\x01\n\x17QueryOraclePriceRequest\x12\x45\n\x0boracle_type\x18\x01 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleTypeR\noracleType\x12\x12\n\x04\x62\x61se\x18\x02 \x01(\tR\x04\x62\x61se\x12\x14\n\x05quote\x18\x03 \x01(\tR\x05quote\x12W\n\x0fscaling_options\x18\x04 \x01(\x0b\x32(.injective.oracle.v1beta1.ScalingOptionsB\x04\xc8\xde\x1f\x01R\x0escalingOptions\"\xe2\x03\n\x0ePricePairState\x12\x42\n\npair_price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\tpairPrice\x12\x42\n\nbase_price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\tbasePrice\x12\x44\n\x0bquote_price\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\nquotePrice\x12W\n\x15\x62\x61se_cumulative_price\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x13\x62\x61seCumulativePrice\x12Y\n\x16quote_cumulative_price\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x14quoteCumulativePrice\x12%\n\x0e\x62\x61se_timestamp\x18\x06 \x01(\x03R\rbaseTimestamp\x12\'\n\x0fquote_timestamp\x18\x07 \x01(\x03R\x0equoteTimestamp\"n\n\x18QueryOraclePriceResponse\x12R\n\x10price_pair_state\x18\x01 \x01(\x0b\x32(.injective.oracle.v1beta1.PricePairStateR\x0epricePairState2\xcd\x18\n\x05Query\x12\x8f\x01\n\x06Params\x12,.injective.oracle.v1beta1.QueryParamsRequest\x1a-.injective.oracle.v1beta1.QueryParamsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /injective/oracle/v1beta1/params\x12\xa8\x01\n\x0c\x42\x61ndRelayers\x12\x32.injective.oracle.v1beta1.QueryBandRelayersRequest\x1a\x33.injective.oracle.v1beta1.QueryBandRelayersResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/injective/oracle/v1beta1/band_relayers\x12\xb5\x01\n\x0f\x42\x61ndPriceStates\x12\x35.injective.oracle.v1beta1.QueryBandPriceStatesRequest\x1a\x36.injective.oracle.v1beta1.QueryBandPriceStatesResponse\"3\x82\xd3\xe4\x93\x02-\x12+/injective/oracle/v1beta1/band_price_states\x12\xc2\x01\n\x12\x42\x61ndIBCPriceStates\x12\x38.injective.oracle.v1beta1.QueryBandIBCPriceStatesRequest\x1a\x39.injective.oracle.v1beta1.QueryBandIBCPriceStatesResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/oracle/v1beta1/band_ibc_price_states\x12\xc9\x01\n\x14PriceFeedPriceStates\x12:.injective.oracle.v1beta1.QueryPriceFeedPriceStatesRequest\x1a;.injective.oracle.v1beta1.QueryPriceFeedPriceStatesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/injective/oracle/v1beta1/pricefeed_price_states\x12\xc5\x01\n\x13\x43oinbasePriceStates\x12\x39.injective.oracle.v1beta1.QueryCoinbasePriceStatesRequest\x1a:.injective.oracle.v1beta1.QueryCoinbasePriceStatesResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/oracle/v1beta1/coinbase_price_states\x12\xb5\x01\n\x0fPythPriceStates\x12\x35.injective.oracle.v1beta1.QueryPythPriceStatesRequest\x1a\x36.injective.oracle.v1beta1.QueryPythPriceStatesResponse\"3\x82\xd3\xe4\x93\x02-\x12+/injective/oracle/v1beta1/pyth_price_states\x12\xb9\x01\n\x10StorkPriceStates\x12\x36.injective.oracle.v1beta1.QueryStorkPriceStatesRequest\x1a\x37.injective.oracle.v1beta1.QueryStorkPriceStatesResponse\"4\x82\xd3\xe4\x93\x02.\x12,/injective/oracle/v1beta1/stork_price_states\x12\xb4\x01\n\x0fStorkPublishers\x12\x35.injective.oracle.v1beta1.QueryStorkPublishersRequest\x1a\x36.injective.oracle.v1beta1.QueryStorkPublishersResponse\"2\x82\xd3\xe4\x93\x02,\x12*/injective/oracle/v1beta1/stork_publishers\x12\xd5\x01\n\x12ProviderPriceState\x12\x38.injective.oracle.v1beta1.QueryProviderPriceStateRequest\x1a\x39.injective.oracle.v1beta1.QueryProviderPriceStateResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/injective/oracle/v1beta1/provider_price_state/{provider}/{symbol}\x12\xaa\x01\n\x11OracleModuleState\x12\x31.injective.oracle.v1beta1.QueryModuleStateRequest\x1a\x32.injective.oracle.v1beta1.QueryModuleStateResponse\".\x82\xd3\xe4\x93\x02(\x12&/injective/oracle/v1beta1/module_state\x12\xd1\x01\n\x16HistoricalPriceRecords\x12<.injective.oracle.v1beta1.QueryHistoricalPriceRecordsRequest\x1a=.injective.oracle.v1beta1.QueryHistoricalPriceRecordsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/oracle/v1beta1/historical_price_records\x12\xb1\x01\n\x10OracleVolatility\x12\x36.injective.oracle.v1beta1.QueryOracleVolatilityRequest\x1a\x37.injective.oracle.v1beta1.QueryOracleVolatilityResponse\",\x82\xd3\xe4\x93\x02&\x12$/injective/oracle/v1beta1/volatility\x12\xb9\x01\n\x13OracleProvidersInfo\x12\x39.injective.oracle.v1beta1.QueryOracleProvidersInfoRequest\x1a:.injective.oracle.v1beta1.QueryOracleProvidersInfoResponse\"+\x82\xd3\xe4\x93\x02%\x12#/injective/oracle/v1beta1/providers\x12\xc2\x01\n\x14OracleProviderPrices\x12:.injective.oracle.v1beta1.QueryOracleProviderPricesRequest\x1a;.injective.oracle.v1beta1.QueryOracleProviderPricesResponse\"1\x82\xd3\xe4\x93\x02+\x12)/injective/oracle/v1beta1/provider_prices\x12\x9d\x01\n\x0bOraclePrice\x12\x31.injective.oracle.v1beta1.QueryOraclePriceRequest\x1a\x32.injective.oracle.v1beta1.QueryOraclePriceResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/injective/oracle/v1beta1/price\x12\x9c\x01\n\tPythPrice\x12/.injective.oracle.v1beta1.QueryPythPriceRequest\x1a\x30.injective.oracle.v1beta1.QueryPythPriceResponse\",\x82\xd3\xe4\x93\x02&\x12$/injective/oracle/v1beta1/pyth_priceB\xfa\x01\n\x1c\x63om.injective.oracle.v1beta1B\nQueryProtoP\x01ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\xa2\x02\x03IOX\xaa\x02\x18Injective.Oracle.V1beta1\xca\x02\x18Injective\\Oracle\\V1beta1\xe2\x02$Injective\\Oracle\\V1beta1\\GPBMetadata\xea\x02\x1aInjective::Oracle::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.oracle.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.injective.oracle.v1beta1B\nQueryProtoP\001ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\242\002\003IOX\252\002\030Injective.Oracle.V1beta1\312\002\030Injective\\Oracle\\V1beta1\342\002$Injective\\Oracle\\V1beta1\\GPBMetadata\352\002\032Injective::Oracle::V1beta1'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYORACLEVOLATILITYRESPONSE'].fields_by_name['volatility']._loaded_options = None
  _globals['_QUERYORACLEVOLATILITYRESPONSE'].fields_by_name['volatility']._serialized_options = b'\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYORACLEPRICEREQUEST'].fields_by_name['scaling_options']._loaded_options = None
  _globals['_QUERYORACLEPRICEREQUEST'].fields_by_name['scaling_options']._serialized_options = b'\310\336\037\001'
  _globals['_PRICEPAIRSTATE'].fields_by_name['pair_price']._loaded_options = None
  _globals['_PRICEPAIRSTATE'].fields_by_name['pair_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PRICEPAIRSTATE'].fields_by_name['base_price']._loaded_options = None
  _globals['_PRICEPAIRSTATE'].fields_by_name['base_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PRICEPAIRSTATE'].fields_by_name['quote_price']._loaded_options = None
  _globals['_PRICEPAIRSTATE'].fields_by_name['quote_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PRICEPAIRSTATE'].fields_by_name['base_cumulative_price']._loaded_options = None
  _globals['_PRICEPAIRSTATE'].fields_by_name['base_cumulative_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PRICEPAIRSTATE'].fields_by_name['quote_cumulative_price']._loaded_options = None
  _globals['_PRICEPAIRSTATE'].fields_by_name['quote_cumulative_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\"\022 /injective/oracle/v1beta1/params'
  _globals['_QUERY'].methods_by_name['BandRelayers']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BandRelayers']._serialized_options = b'\202\323\344\223\002)\022\'/injective/oracle/v1beta1/band_relayers'
  _globals['_QUERY'].methods_by_name['BandPriceStates']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BandPriceStates']._serialized_options = b'\202\323\344\223\002-\022+/injective/oracle/v1beta1/band_price_states'
  _globals['_QUERY'].methods_by_name['BandIBCPriceStates']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BandIBCPriceStates']._serialized_options = b'\202\323\344\223\0021\022//injective/oracle/v1beta1/band_ibc_price_states'
  _globals['_QUERY'].methods_by_name['PriceFeedPriceStates']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PriceFeedPriceStates']._serialized_options = b'\202\323\344\223\0022\0220/injective/oracle/v1beta1/pricefeed_price_states'
  _globals['_QUERY'].methods_by_name['CoinbasePriceStates']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CoinbasePriceStates']._serialized_options = b'\202\323\344\223\0021\022//injective/oracle/v1beta1/coinbase_price_states'
  _globals['_QUERY'].methods_by_name['PythPriceStates']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PythPriceStates']._serialized_options = b'\202\323\344\223\002-\022+/injective/oracle/v1beta1/pyth_price_states'
  _globals['_QUERY'].methods_by_name['StorkPriceStates']._loaded_options = None
  _globals['_QUERY'].methods_by_name['StorkPriceStates']._serialized_options = b'\202\323\344\223\002.\022,/injective/oracle/v1beta1/stork_price_states'
  _globals['_QUERY'].methods_by_name['StorkPublishers']._loaded_options = None
  _globals['_QUERY'].methods_by_name['StorkPublishers']._serialized_options = b'\202\323\344\223\002,\022*/injective/oracle/v1beta1/stork_publishers'
  _globals['_QUERY'].methods_by_name['ProviderPriceState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ProviderPriceState']._serialized_options = b'\202\323\344\223\002D\022B/injective/oracle/v1beta1/provider_price_state/{provider}/{symbol}'
  _globals['_QUERY'].methods_by_name['OracleModuleState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OracleModuleState']._serialized_options = b'\202\323\344\223\002(\022&/injective/oracle/v1beta1/module_state'
  _globals['_QUERY'].methods_by_name['HistoricalPriceRecords']._loaded_options = None
  _globals['_QUERY'].methods_by_name['HistoricalPriceRecords']._serialized_options = b'\202\323\344\223\0024\0222/injective/oracle/v1beta1/historical_price_records'
  _globals['_QUERY'].methods_by_name['OracleVolatility']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OracleVolatility']._serialized_options = b'\202\323\344\223\002&\022$/injective/oracle/v1beta1/volatility'
  _globals['_QUERY'].methods_by_name['OracleProvidersInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OracleProvidersInfo']._serialized_options = b'\202\323\344\223\002%\022#/injective/oracle/v1beta1/providers'
  _globals['_QUERY'].methods_by_name['OracleProviderPrices']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OracleProviderPrices']._serialized_options = b'\202\323\344\223\002+\022)/injective/oracle/v1beta1/provider_prices'
  _globals['_QUERY'].methods_by_name['OraclePrice']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OraclePrice']._serialized_options = b'\202\323\344\223\002!\022\037/injective/oracle/v1beta1/price'
  _globals['_QUERY'].methods_by_name['PythPrice']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PythPrice']._serialized_options = b'\202\323\344\223\002&\022$/injective/oracle/v1beta1/pyth_price'
  _globals['_QUERYPYTHPRICEREQUEST']._serialized_start=197
  _globals['_QUERYPYTHPRICEREQUEST']._serialized_end=247
  _globals['_QUERYPYTHPRICERESPONSE']._serialized_start=249
  _globals['_QUERYPYTHPRICERESPONSE']._serialized_end=348
  _globals['_QUERYPARAMSREQUEST']._serialized_start=350
  _globals['_QUERYPARAMSREQUEST']._serialized_end=370
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=372
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=457
  _globals['_QUERYBANDRELAYERSREQUEST']._serialized_start=459
  _globals['_QUERYBANDRELAYERSREQUEST']._serialized_end=485
  _globals['_QUERYBANDRELAYERSRESPONSE']._serialized_start=487
  _globals['_QUERYBANDRELAYERSRESPONSE']._serialized_end=542
  _globals['_QUERYBANDPRICESTATESREQUEST']._serialized_start=544
  _globals['_QUERYBANDPRICESTATESREQUEST']._serialized_end=573
  _globals['_QUERYBANDPRICESTATESRESPONSE']._serialized_start=575
  _globals['_QUERYBANDPRICESTATESRESPONSE']._serialized_end=682
  _globals['_QUERYBANDIBCPRICESTATESREQUEST']._serialized_start=684
  _globals['_QUERYBANDIBCPRICESTATESREQUEST']._serialized_end=716
  _globals['_QUERYBANDIBCPRICESTATESRESPONSE']._serialized_start=718
  _globals['_QUERYBANDIBCPRICESTATESRESPONSE']._serialized_end=828
  _globals['_QUERYPRICEFEEDPRICESTATESREQUEST']._serialized_start=830
  _globals['_QUERYPRICEFEEDPRICESTATESREQUEST']._serialized_end=864
  _globals['_QUERYPRICEFEEDPRICESTATESRESPONSE']._serialized_start=866
  _globals['_QUERYPRICEFEEDPRICESTATESRESPONSE']._serialized_end=978
  _globals['_QUERYCOINBASEPRICESTATESREQUEST']._serialized_start=980
  _globals['_QUERYCOINBASEPRICESTATESREQUEST']._serialized_end=1013
  _globals['_QUERYCOINBASEPRICESTATESRESPONSE']._serialized_start=1015
  _globals['_QUERYCOINBASEPRICESTATESRESPONSE']._serialized_end=1130
  _globals['_QUERYPYTHPRICESTATESREQUEST']._serialized_start=1132
  _globals['_QUERYPYTHPRICESTATESREQUEST']._serialized_end=1161
  _globals['_QUERYPYTHPRICESTATESRESPONSE']._serialized_start=1163
  _globals['_QUERYPYTHPRICESTATESRESPONSE']._serialized_end=1270
  _globals['_QUERYSTORKPRICESTATESREQUEST']._serialized_start=1272
  _globals['_QUERYSTORKPRICESTATESREQUEST']._serialized_end=1302
  _globals['_QUERYSTORKPRICESTATESRESPONSE']._serialized_start=1304
  _globals['_QUERYSTORKPRICESTATESRESPONSE']._serialized_end=1413
  _globals['_QUERYSTORKPUBLISHERSREQUEST']._serialized_start=1415
  _globals['_QUERYSTORKPUBLISHERSREQUEST']._serialized_end=1444
  _globals['_QUERYSTORKPUBLISHERSRESPONSE']._serialized_start=1446
  _globals['_QUERYSTORKPUBLISHERSRESPONSE']._serialized_end=1508
  _globals['_QUERYPROVIDERPRICESTATEREQUEST']._serialized_start=1510
  _globals['_QUERYPROVIDERPRICESTATEREQUEST']._serialized_end=1594
  _globals['_QUERYPROVIDERPRICESTATERESPONSE']._serialized_start=1596
  _globals['_QUERYPROVIDERPRICESTATERESPONSE']._serialized_end=1700
  _globals['_QUERYMODULESTATEREQUEST']._serialized_start=1702
  _globals['_QUERYMODULESTATEREQUEST']._serialized_end=1727
  _globals['_QUERYMODULESTATERESPONSE']._serialized_start=1729
  _globals['_QUERYMODULESTATERESPONSE']._serialized_end=1817
  _globals['_QUERYHISTORICALPRICERECORDSREQUEST']._serialized_start=1819
  _globals['_QUERYHISTORICALPRICERECORDSREQUEST']._serialized_end=1946
  _globals['_QUERYHISTORICALPRICERECORDSRESPONSE']._serialized_start=1948
  _globals['_QUERYHISTORICALPRICERECORDSRESPONSE']._serialized_end=2062
  _globals['_ORACLEHISTORYOPTIONS']._serialized_start=2065
  _globals['_ORACLEHISTORYOPTIONS']._serialized_end=2203
  _globals['_QUERYORACLEVOLATILITYREQUEST']._serialized_start=2206
  _globals['_QUERYORACLEVOLATILITYREQUEST']._serialized_end=2474
  _globals['_QUERYORACLEVOLATILITYRESPONSE']._serialized_start=2477
  _globals['_QUERYORACLEVOLATILITYRESPONSE']._serialized_end=2734
  _globals['_QUERYORACLEPROVIDERSINFOREQUEST']._serialized_start=2736
  _globals['_QUERYORACLEPROVIDERSINFOREQUEST']._serialized_end=2769
  _globals['_QUERYORACLEPROVIDERSINFORESPONSE']._serialized_start=2771
  _globals['_QUERYORACLEPROVIDERSINFORESPONSE']._serialized_end=2875
  _globals['_QUERYORACLEPROVIDERPRICESREQUEST']._serialized_start=2877
  _globals['_QUERYORACLEPROVIDERPRICESREQUEST']._serialized_end=2939
  _globals['_QUERYORACLEPROVIDERPRICESRESPONSE']._serialized_start=2941
  _globals['_QUERYORACLEPROVIDERPRICESRESPONSE']._serialized_end=3055
  _globals['_SCALINGOPTIONS']._serialized_start=3057
  _globals['_SCALINGOPTIONS']._serialized_end=3149
  _globals['_QUERYORACLEPRICEREQUEST']._serialized_start=3152
  _globals['_QUERYORACLEPRICEREQUEST']._serialized_end=3379
  _globals['_PRICEPAIRSTATE']._serialized_start=3382
  _globals['_PRICEPAIRSTATE']._serialized_end=3864
  _globals['_QUERYORACLEPRICERESPONSE']._serialized_start=3866
  _globals['_QUERYORACLEPRICERESPONSE']._serialized_end=3976
  _globals['_QUERY']._serialized_start=3979
  _globals['_QUERY']._serialized_end=7128
# @@protoc_insertion_point(module_scope)
