# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/orm/query/v1alpha1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/orm/query/v1alpha1/query.proto\x12\x19\x63osmos.orm.query.v1alpha1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x19google/protobuf/any.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\"\x84\x01\n\nGetRequest\x12!\n\x0cmessage_name\x18\x01 \x01(\tR\x0bmessageName\x12\x14\n\x05index\x18\x02 \x01(\tR\x05index\x12=\n\x06values\x18\x03 \x03(\x0b\x32%.cosmos.orm.query.v1alpha1.IndexValueR\x06values\";\n\x0bGetResponse\x12,\n\x06result\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\x06result\"\xee\x03\n\x0bListRequest\x12!\n\x0cmessage_name\x18\x01 \x01(\tR\x0bmessageName\x12\x14\n\x05index\x18\x02 \x01(\tR\x05index\x12G\n\x06prefix\x18\x03 \x01(\x0b\x32-.cosmos.orm.query.v1alpha1.ListRequest.PrefixH\x00R\x06prefix\x12\x44\n\x05range\x18\x04 \x01(\x0b\x32,.cosmos.orm.query.v1alpha1.ListRequest.RangeH\x00R\x05range\x12\x46\n\npagination\x18\x05 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\x1aG\n\x06Prefix\x12=\n\x06values\x18\x01 \x03(\x0b\x32%.cosmos.orm.query.v1alpha1.IndexValueR\x06values\x1a}\n\x05Range\x12;\n\x05start\x18\x01 \x03(\x0b\x32%.cosmos.orm.query.v1alpha1.IndexValueR\x05start\x12\x37\n\x03\x65nd\x18\x02 \x03(\x0b\x32%.cosmos.orm.query.v1alpha1.IndexValueR\x03\x65ndB\x07\n\x05query\"\x87\x01\n\x0cListResponse\x12.\n\x07results\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyR\x07results\x12G\n\npagination\x18\x05 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\x8c\x02\n\nIndexValue\x12\x14\n\x04uint\x18\x01 \x01(\x04H\x00R\x04uint\x12\x12\n\x03int\x18\x02 \x01(\x03H\x00R\x03int\x12\x12\n\x03str\x18\x03 \x01(\tH\x00R\x03str\x12\x16\n\x05\x62ytes\x18\x04 \x01(\x0cH\x00R\x05\x62ytes\x12\x14\n\x04\x65num\x18\x05 \x01(\tH\x00R\x04\x65num\x12\x14\n\x04\x62ool\x18\x06 \x01(\x08H\x00R\x04\x62ool\x12:\n\ttimestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\ttimestamp\x12\x37\n\x08\x64uration\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x08\x64urationB\x07\n\x05value2\xb6\x01\n\x05Query\x12T\n\x03Get\x12%.cosmos.orm.query.v1alpha1.GetRequest\x1a&.cosmos.orm.query.v1alpha1.GetResponse\x12W\n\x04List\x12&.cosmos.orm.query.v1alpha1.ListRequest\x1a\'.cosmos.orm.query.v1alpha1.ListResponseB\xb2\x01\n\x1d\x63om.cosmos.orm.query.v1alpha1B\nQueryProtoP\x01\xa2\x02\x03\x43OQ\xaa\x02\x19\x43osmos.Orm.Query.V1alpha1\xca\x02\x19\x43osmos\\Orm\\Query\\V1alpha1\xe2\x02%Cosmos\\Orm\\Query\\V1alpha1\\GPBMetadata\xea\x02\x1c\x43osmos::Orm::Query::V1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.orm.query.v1alpha1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.cosmos.orm.query.v1alpha1B\nQueryProtoP\001\242\002\003COQ\252\002\031Cosmos.Orm.Query.V1alpha1\312\002\031Cosmos\\Orm\\Query\\V1alpha1\342\002%Cosmos\\Orm\\Query\\V1alpha1\\GPBMetadata\352\002\034Cosmos::Orm::Query::V1alpha1'
  _globals['_GETREQUEST']._serialized_start=205
  _globals['_GETREQUEST']._serialized_end=337
  _globals['_GETRESPONSE']._serialized_start=339
  _globals['_GETRESPONSE']._serialized_end=398
  _globals['_LISTREQUEST']._serialized_start=401
  _globals['_LISTREQUEST']._serialized_end=895
  _globals['_LISTREQUEST_PREFIX']._serialized_start=688
  _globals['_LISTREQUEST_PREFIX']._serialized_end=759
  _globals['_LISTREQUEST_RANGE']._serialized_start=761
  _globals['_LISTREQUEST_RANGE']._serialized_end=886
  _globals['_LISTRESPONSE']._serialized_start=898
  _globals['_LISTRESPONSE']._serialized_end=1033
  _globals['_INDEXVALUE']._serialized_start=1036
  _globals['_INDEXVALUE']._serialized_end=1304
  _globals['_QUERY']._serialized_start=1307
  _globals['_QUERY']._serialized_end=1489
# @@protoc_insertion_point(module_scope)
