# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/evm/v1/params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.evm.v1 import chain_config_pb2 as injective_dot_evm_dot_v1_dot_chain__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dinjective/evm/v1/params.proto\x12\x10injective.evm.v1\x1a\x14gogoproto/gogo.proto\x1a#injective/evm/v1/chain_config.proto\"\xc9\x03\n\x06Params\x12\x31\n\tevm_denom\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"evm_denom\"R\x08\x65vmDenom\x12=\n\renable_create\x18\x02 \x01(\x08\x42\x18\xf2\xde\x1f\x14yaml:\"enable_create\"R\x0c\x65nableCreate\x12\x37\n\x0b\x65nable_call\x18\x03 \x01(\x08\x42\x16\xf2\xde\x1f\x12yaml:\"enable_call\"R\nenableCall\x12\x41\n\nextra_eips\x18\x04 \x03(\x03\x42\"\xe2\xde\x1f\tExtraEIPs\xf2\xde\x1f\x11yaml:\"extra_eips\"R\textraEips\x12\x46\n\x0c\x63hain_config\x18\x05 \x01(\x0b\x32\x1d.injective.evm.v1.ChainConfigB\x04\xc8\xde\x1f\x00R\x0b\x63hainConfig\x12\x32\n\x15\x61llow_unprotected_txs\x18\x06 \x01(\x08R\x13\x61llowUnprotectedTxs\x12\x31\n\x14\x61uthorized_deployers\x18\x07 \x03(\tR\x13\x61uthorizedDeployers\x12\"\n\x0cpermissioned\x18\x08 \x01(\x08R\x0cpermissionedB\xd0\x01\n\x14\x63om.injective.evm.v1B\x0bParamsProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\xa2\x02\x03IEX\xaa\x02\x10Injective.Evm.V1\xca\x02\x10Injective\\Evm\\V1\xe2\x02\x1cInjective\\Evm\\V1\\GPBMetadata\xea\x02\x12Injective::Evm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.evm.v1.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.injective.evm.v1B\013ParamsProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\242\002\003IEX\252\002\020Injective.Evm.V1\312\002\020Injective\\Evm\\V1\342\002\034Injective\\Evm\\V1\\GPBMetadata\352\002\022Injective::Evm::V1'
  _globals['_PARAMS'].fields_by_name['evm_denom']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['evm_denom']._serialized_options = b'\362\336\037\020yaml:\"evm_denom\"'
  _globals['_PARAMS'].fields_by_name['enable_create']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['enable_create']._serialized_options = b'\362\336\037\024yaml:\"enable_create\"'
  _globals['_PARAMS'].fields_by_name['enable_call']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['enable_call']._serialized_options = b'\362\336\037\022yaml:\"enable_call\"'
  _globals['_PARAMS'].fields_by_name['extra_eips']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['extra_eips']._serialized_options = b'\342\336\037\tExtraEIPs\362\336\037\021yaml:\"extra_eips\"'
  _globals['_PARAMS'].fields_by_name['chain_config']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['chain_config']._serialized_options = b'\310\336\037\000'
  _globals['_PARAMS']._serialized_start=111
  _globals['_PARAMS']._serialized_end=568
# @@protoc_insertion_point(module_scope)
