# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/store/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63ometbft/store/v1/types.proto\x12\x11\x63ometbft.store.v1\"=\n\x0f\x42lockStoreState\x12\x12\n\x04\x62\x61se\x18\x01 \x01(\x03R\x04\x62\x61se\x12\x16\n\x06height\x18\x02 \x01(\x03R\x06heightB\xbd\x01\n\x15\x63om.cometbft.store.v1B\nTypesProtoP\x01Z2github.com/cometbft/cometbft/api/cometbft/store/v1\xa2\x02\x03\x43SX\xaa\x02\x11\x43ometbft.Store.V1\xca\x02\x11\x43ometbft\\Store\\V1\xe2\x02\x1d\x43ometbft\\Store\\V1\\GPBMetadata\xea\x02\x13\x43ometbft::Store::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.store.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.cometbft.store.v1B\nTypesProtoP\001Z2github.com/cometbft/cometbft/api/cometbft/store/v1\242\002\003CSX\252\002\021Cometbft.Store.V1\312\002\021Cometbft\\Store\\V1\342\002\035Cometbft\\Store\\V1\\GPBMetadata\352\002\023Cometbft::Store::V1'
  _globals['_BLOCKSTORESTATE']._serialized_start=52
  _globals['_BLOCKSTORESTATE']._serialized_end=113
# @@protoc_insertion_point(module_scope)
