# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/connection/v1/connection.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.ibc.core.commitment.v1 import commitment_pb2 as ibc_dot_core_dot_commitment_dot_v1_dot_commitment__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ibc/core/connection/v1/connection.proto\x12\x16ibc.core.connection.v1\x1a\x14gogoproto/gogo.proto\x1a\'ibc/core/commitment/v1/commitment.proto\"\x97\x02\n\rConnectionEnd\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12;\n\x08versions\x18\x02 \x03(\x0b\x32\x1f.ibc.core.connection.v1.VersionR\x08versions\x12\x33\n\x05state\x18\x03 \x01(\x0e\x32\x1d.ibc.core.connection.v1.StateR\x05state\x12N\n\x0c\x63ounterparty\x18\x04 \x01(\x0b\x32$.ibc.core.connection.v1.CounterpartyB\x04\xc8\xde\x1f\x00R\x0c\x63ounterparty\x12!\n\x0c\x64\x65lay_period\x18\x05 \x01(\x04R\x0b\x64\x65layPeriod:\x04\x88\xa0\x1f\x00\"\xae\x02\n\x14IdentifiedConnection\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1b\n\tclient_id\x18\x02 \x01(\tR\x08\x63lientId\x12;\n\x08versions\x18\x03 \x03(\x0b\x32\x1f.ibc.core.connection.v1.VersionR\x08versions\x12\x33\n\x05state\x18\x04 \x01(\x0e\x32\x1d.ibc.core.connection.v1.StateR\x05state\x12N\n\x0c\x63ounterparty\x18\x05 \x01(\x0b\x32$.ibc.core.connection.v1.CounterpartyB\x04\xc8\xde\x1f\x00R\x0c\x63ounterparty\x12!\n\x0c\x64\x65lay_period\x18\x06 \x01(\x04R\x0b\x64\x65layPeriod:\x04\x88\xa0\x1f\x00\"\x9a\x01\n\x0c\x43ounterparty\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12#\n\rconnection_id\x18\x02 \x01(\tR\x0c\x63onnectionId\x12\x42\n\x06prefix\x18\x03 \x01(\x0b\x32$.ibc.core.commitment.v1.MerklePrefixB\x04\xc8\xde\x1f\x00R\x06prefix:\x04\x88\xa0\x1f\x00\"#\n\x0b\x43lientPaths\x12\x14\n\x05paths\x18\x01 \x03(\tR\x05paths\"D\n\x0f\x43onnectionPaths\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x14\n\x05paths\x18\x02 \x03(\tR\x05paths\"K\n\x07Version\x12\x1e\n\nidentifier\x18\x01 \x01(\tR\nidentifier\x12\x1a\n\x08\x66\x65\x61tures\x18\x02 \x03(\tR\x08\x66\x65\x61tures:\x04\x88\xa0\x1f\x00\"F\n\x06Params\x12<\n\x1bmax_expected_time_per_block\x18\x01 \x01(\x04R\x17maxExpectedTimePerBlock*\x99\x01\n\x05State\x12\x36\n\x1fSTATE_UNINITIALIZED_UNSPECIFIED\x10\x00\x1a\x11\x8a\x9d \rUNINITIALIZED\x12\x18\n\nSTATE_INIT\x10\x01\x1a\x08\x8a\x9d \x04INIT\x12\x1e\n\rSTATE_TRYOPEN\x10\x02\x1a\x0b\x8a\x9d \x07TRYOPEN\x12\x18\n\nSTATE_OPEN\x10\x03\x1a\x08\x8a\x9d \x04OPEN\x1a\x04\x88\xa3\x1e\x00\x42\xe6\x01\n\x1a\x63om.ibc.core.connection.v1B\x0f\x43onnectionProtoP\x01Z<github.com/cosmos/ibc-go/v8/modules/core/03-connection/types\xa2\x02\x03ICC\xaa\x02\x16Ibc.Core.Connection.V1\xca\x02\x16Ibc\\Core\\Connection\\V1\xe2\x02\"Ibc\\Core\\Connection\\V1\\GPBMetadata\xea\x02\x19Ibc::Core::Connection::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.connection.v1.connection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.ibc.core.connection.v1B\017ConnectionProtoP\001Z<github.com/cosmos/ibc-go/v8/modules/core/03-connection/types\242\002\003ICC\252\002\026Ibc.Core.Connection.V1\312\002\026Ibc\\Core\\Connection\\V1\342\002\"Ibc\\Core\\Connection\\V1\\GPBMetadata\352\002\031Ibc::Core::Connection::V1'
  _globals['_STATE']._loaded_options = None
  _globals['_STATE']._serialized_options = b'\210\243\036\000'
  _globals['_STATE'].values_by_name["STATE_UNINITIALIZED_UNSPECIFIED"]._loaded_options = None
  _globals['_STATE'].values_by_name["STATE_UNINITIALIZED_UNSPECIFIED"]._serialized_options = b'\212\235 \rUNINITIALIZED'
  _globals['_STATE'].values_by_name["STATE_INIT"]._loaded_options = None
  _globals['_STATE'].values_by_name["STATE_INIT"]._serialized_options = b'\212\235 \004INIT'
  _globals['_STATE'].values_by_name["STATE_TRYOPEN"]._loaded_options = None
  _globals['_STATE'].values_by_name["STATE_TRYOPEN"]._serialized_options = b'\212\235 \007TRYOPEN'
  _globals['_STATE'].values_by_name["STATE_OPEN"]._loaded_options = None
  _globals['_STATE'].values_by_name["STATE_OPEN"]._serialized_options = b'\212\235 \004OPEN'
  _globals['_CONNECTIONEND'].fields_by_name['counterparty']._loaded_options = None
  _globals['_CONNECTIONEND'].fields_by_name['counterparty']._serialized_options = b'\310\336\037\000'
  _globals['_CONNECTIONEND']._loaded_options = None
  _globals['_CONNECTIONEND']._serialized_options = b'\210\240\037\000'
  _globals['_IDENTIFIEDCONNECTION'].fields_by_name['counterparty']._loaded_options = None
  _globals['_IDENTIFIEDCONNECTION'].fields_by_name['counterparty']._serialized_options = b'\310\336\037\000'
  _globals['_IDENTIFIEDCONNECTION']._loaded_options = None
  _globals['_IDENTIFIEDCONNECTION']._serialized_options = b'\210\240\037\000'
  _globals['_COUNTERPARTY'].fields_by_name['prefix']._loaded_options = None
  _globals['_COUNTERPARTY'].fields_by_name['prefix']._serialized_options = b'\310\336\037\000'
  _globals['_COUNTERPARTY']._loaded_options = None
  _globals['_COUNTERPARTY']._serialized_options = b'\210\240\037\000'
  _globals['_VERSION']._loaded_options = None
  _globals['_VERSION']._serialized_options = b'\210\240\037\000'
  _globals['_STATE']._serialized_start=1131
  _globals['_STATE']._serialized_end=1284
  _globals['_CONNECTIONEND']._serialized_start=131
  _globals['_CONNECTIONEND']._serialized_end=410
  _globals['_IDENTIFIEDCONNECTION']._serialized_start=413
  _globals['_IDENTIFIEDCONNECTION']._serialized_end=715
  _globals['_COUNTERPARTY']._serialized_start=718
  _globals['_COUNTERPARTY']._serialized_end=872
  _globals['_CLIENTPATHS']._serialized_start=874
  _globals['_CLIENTPATHS']._serialized_end=909
  _globals['_CONNECTIONPATHS']._serialized_start=911
  _globals['_CONNECTIONPATHS']._serialized_end=979
  _globals['_VERSION']._serialized_start=981
  _globals['_VERSION']._serialized_end=1056
  _globals['_PARAMS']._serialized_start=1058
  _globals['_PARAMS']._serialized_end=1128
# @@protoc_insertion_point(module_scope)
