# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.injective.wasmx.v1 import wasmx_pb2 as injective_dot_wasmx_dot_v1_dot_wasmx__pb2
from pyinjective.proto.injective.wasmx.v1 import proposal_pb2 as injective_dot_wasmx_dot_v1_dot_proposal__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1binjective/wasmx/v1/tx.proto\x12\x12injective.wasmx.v1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x1einjective/wasmx/v1/wasmx.proto\x1a!injective/wasmx/v1/proposal.proto\x1a\x11\x61mino/amino.proto\"\xa6\x01\n\x18MsgExecuteContractCompat\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1a\n\x08\x63ontract\x18\x02 \x01(\tR\x08\x63ontract\x12\x10\n\x03msg\x18\x03 \x01(\tR\x03msg\x12\x14\n\x05\x66unds\x18\x04 \x01(\tR\x05\x66unds:.\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1ewasmx/MsgExecuteContractCompat\"6\n MsgExecuteContractCompatResponse\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\"\xe4\x01\n\x11MsgUpdateContract\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12)\n\x10\x63ontract_address\x18\x02 \x01(\tR\x0f\x63ontractAddress\x12\x1b\n\tgas_limit\x18\x03 \x01(\x04R\x08gasLimit\x12\x1b\n\tgas_price\x18\x04 \x01(\x04R\x08gasPrice\x12)\n\radmin_address\x18\x05 \x01(\tB\x04\xc8\xde\x1f\x01R\x0c\x61\x64minAddress:\'\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x17wasmx/MsgUpdateContract\"\x1b\n\x19MsgUpdateContractResponse\"\x83\x01\n\x13MsgActivateContract\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12)\n\x10\x63ontract_address\x18\x02 \x01(\tR\x0f\x63ontractAddress:)\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x19wasmx/MsgActivateContract\"\x1d\n\x1bMsgActivateContractResponse\"\x87\x01\n\x15MsgDeactivateContract\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12)\n\x10\x63ontract_address\x18\x02 \x01(\tR\x0f\x63ontractAddress:+\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1bwasmx/MsgDeactivateContract\"\x1f\n\x1dMsgDeactivateContractResponse\"\xad\x01\n\x0fMsgUpdateParams\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12\x38\n\x06params\x18\x02 \x01(\x0b\x32\x1a.injective.wasmx.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:(\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x15wasmx/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"\xd3\x01\n\x13MsgRegisterContract\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12y\n\x1d\x63ontract_registration_request\x18\x02 \x01(\x0b\x32/.injective.wasmx.v1.ContractRegistrationRequestB\x04\xc8\xde\x1f\x00R\x1b\x63ontractRegistrationRequest:)\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x19wasmx/MsgRegisterContract\"\x1d\n\x1bMsgRegisterContractResponse2\xc1\x05\n\x03Msg\x12t\n\x1cUpdateRegistryContractParams\x12%.injective.wasmx.v1.MsgUpdateContract\x1a-.injective.wasmx.v1.MsgUpdateContractResponse\x12t\n\x18\x41\x63tivateRegistryContract\x12\'.injective.wasmx.v1.MsgActivateContract\x1a/.injective.wasmx.v1.MsgActivateContractResponse\x12z\n\x1a\x44\x65\x61\x63tivateRegistryContract\x12).injective.wasmx.v1.MsgDeactivateContract\x1a\x31.injective.wasmx.v1.MsgDeactivateContractResponse\x12{\n\x15\x45xecuteContractCompat\x12,.injective.wasmx.v1.MsgExecuteContractCompat\x1a\x34.injective.wasmx.v1.MsgExecuteContractCompatResponse\x12`\n\x0cUpdateParams\x12#.injective.wasmx.v1.MsgUpdateParams\x1a+.injective.wasmx.v1.MsgUpdateParamsResponse\x12l\n\x10RegisterContract\x12\'.injective.wasmx.v1.MsgRegisterContract\x1a/.injective.wasmx.v1.MsgRegisterContractResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xd8\x01\n\x16\x63om.injective.wasmx.v1B\x07TxProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types\xa2\x02\x03IWX\xaa\x02\x12Injective.Wasmx.V1\xca\x02\x12Injective\\Wasmx\\V1\xe2\x02\x1eInjective\\Wasmx\\V1\\GPBMetadata\xea\x02\x14Injective::Wasmx::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.wasmx.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.injective.wasmx.v1B\007TxProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types\242\002\003IWX\252\002\022Injective.Wasmx.V1\312\002\022Injective\\Wasmx\\V1\342\002\036Injective\\Wasmx\\V1\\GPBMetadata\352\002\024Injective::Wasmx::V1'
  _globals['_MSGEXECUTECONTRACTCOMPAT']._loaded_options = None
  _globals['_MSGEXECUTECONTRACTCOMPAT']._serialized_options = b'\202\347\260*\006sender\212\347\260*\036wasmx/MsgExecuteContractCompat'
  _globals['_MSGUPDATECONTRACT'].fields_by_name['admin_address']._loaded_options = None
  _globals['_MSGUPDATECONTRACT'].fields_by_name['admin_address']._serialized_options = b'\310\336\037\001'
  _globals['_MSGUPDATECONTRACT']._loaded_options = None
  _globals['_MSGUPDATECONTRACT']._serialized_options = b'\202\347\260*\006sender\212\347\260*\027wasmx/MsgUpdateContract'
  _globals['_MSGACTIVATECONTRACT']._loaded_options = None
  _globals['_MSGACTIVATECONTRACT']._serialized_options = b'\202\347\260*\006sender\212\347\260*\031wasmx/MsgActivateContract'
  _globals['_MSGDEACTIVATECONTRACT']._loaded_options = None
  _globals['_MSGDEACTIVATECONTRACT']._serialized_options = b'\202\347\260*\006sender\212\347\260*\033wasmx/MsgDeactivateContract'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\025wasmx/MsgUpdateParams'
  _globals['_MSGREGISTERCONTRACT'].fields_by_name['contract_registration_request']._loaded_options = None
  _globals['_MSGREGISTERCONTRACT'].fields_by_name['contract_registration_request']._serialized_options = b'\310\336\037\000'
  _globals['_MSGREGISTERCONTRACT']._loaded_options = None
  _globals['_MSGREGISTERCONTRACT']._serialized_options = b'\202\347\260*\006sender\212\347\260*\031wasmx/MsgRegisterContract'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGEXECUTECONTRACTCOMPAT']._serialized_start=239
  _globals['_MSGEXECUTECONTRACTCOMPAT']._serialized_end=405
  _globals['_MSGEXECUTECONTRACTCOMPATRESPONSE']._serialized_start=407
  _globals['_MSGEXECUTECONTRACTCOMPATRESPONSE']._serialized_end=461
  _globals['_MSGUPDATECONTRACT']._serialized_start=464
  _globals['_MSGUPDATECONTRACT']._serialized_end=692
  _globals['_MSGUPDATECONTRACTRESPONSE']._serialized_start=694
  _globals['_MSGUPDATECONTRACTRESPONSE']._serialized_end=721
  _globals['_MSGACTIVATECONTRACT']._serialized_start=724
  _globals['_MSGACTIVATECONTRACT']._serialized_end=855
  _globals['_MSGACTIVATECONTRACTRESPONSE']._serialized_start=857
  _globals['_MSGACTIVATECONTRACTRESPONSE']._serialized_end=886
  _globals['_MSGDEACTIVATECONTRACT']._serialized_start=889
  _globals['_MSGDEACTIVATECONTRACT']._serialized_end=1024
  _globals['_MSGDEACTIVATECONTRACTRESPONSE']._serialized_start=1026
  _globals['_MSGDEACTIVATECONTRACTRESPONSE']._serialized_end=1057
  _globals['_MSGUPDATEPARAMS']._serialized_start=1060
  _globals['_MSGUPDATEPARAMS']._serialized_end=1233
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=1235
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=1260
  _globals['_MSGREGISTERCONTRACT']._serialized_start=1263
  _globals['_MSGREGISTERCONTRACT']._serialized_end=1474
  _globals['_MSGREGISTERCONTRACTRESPONSE']._serialized_start=1476
  _globals['_MSGREGISTERCONTRACTRESPONSE']._serialized_end=1505
  _globals['_MSG']._serialized_start=1508
  _globals['_MSG']._serialized_end=2213
# @@protoc_insertion_point(module_scope)
