# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.injective.peggy.v1 import genesis_pb2 as injective_dot_peggy_dot_v1_dot_genesis__pb2
from pyinjective.proto.injective.peggy.v1 import params_pb2 as injective_dot_peggy_dot_v1_dot_params__pb2
from pyinjective.proto.injective.peggy.v1 import types_pb2 as injective_dot_peggy_dot_v1_dot_types__pb2
from pyinjective.proto.injective.peggy.v1 import msgs_pb2 as injective_dot_peggy_dot_v1_dot_msgs__pb2
from pyinjective.proto.injective.peggy.v1 import pool_pb2 as injective_dot_peggy_dot_v1_dot_pool__pb2
from pyinjective.proto.injective.peggy.v1 import batch_pb2 as injective_dot_peggy_dot_v1_dot_batch__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1einjective/peggy/v1/query.proto\x12\x12injective.peggy.v1\x1a injective/peggy/v1/genesis.proto\x1a\x1finjective/peggy/v1/params.proto\x1a\x1einjective/peggy/v1/types.proto\x1a\x1dinjective/peggy/v1/msgs.proto\x1a\x1dinjective/peggy/v1/pool.proto\x1a\x1einjective/peggy/v1/batch.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x14gogoproto/gogo.proto\"\x14\n\x12QueryParamsRequest\"O\n\x13QueryParamsResponse\x12\x38\n\x06params\x18\x01 \x01(\x0b\x32\x1a.injective.peggy.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"\x1b\n\x19QueryCurrentValsetRequest\"P\n\x1aQueryCurrentValsetResponse\x12\x32\n\x06valset\x18\x01 \x01(\x0b\x32\x1a.injective.peggy.v1.ValsetR\x06valset\"1\n\x19QueryValsetRequestRequest\x12\x14\n\x05nonce\x18\x01 \x01(\x04R\x05nonce\"P\n\x1aQueryValsetRequestResponse\x12\x32\n\x06valset\x18\x01 \x01(\x0b\x32\x1a.injective.peggy.v1.ValsetR\x06valset\"K\n\x19QueryValsetConfirmRequest\x12\x14\n\x05nonce\x18\x01 \x01(\x04R\x05nonce\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\"\\\n\x1aQueryValsetConfirmResponse\x12>\n\x07\x63onfirm\x18\x01 \x01(\x0b\x32$.injective.peggy.v1.MsgValsetConfirmR\x07\x63onfirm\"9\n!QueryValsetConfirmsByNonceRequest\x12\x14\n\x05nonce\x18\x01 \x01(\x04R\x05nonce\"f\n\"QueryValsetConfirmsByNonceResponse\x12@\n\x08\x63onfirms\x18\x01 \x03(\x0b\x32$.injective.peggy.v1.MsgValsetConfirmR\x08\x63onfirms\" \n\x1eQueryLastValsetRequestsRequest\"W\n\x1fQueryLastValsetRequestsResponse\x12\x34\n\x07valsets\x18\x01 \x03(\x0b\x32\x1a.injective.peggy.v1.ValsetR\x07valsets\"F\n*QueryLastPendingValsetRequestByAddrRequest\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\"c\n+QueryLastPendingValsetRequestByAddrResponse\x12\x34\n\x07valsets\x18\x01 \x03(\x0b\x32\x1a.injective.peggy.v1.ValsetR\x07valsets\"\x16\n\x14QueryBatchFeeRequest\"T\n\x15QueryBatchFeeResponse\x12;\n\tbatchFees\x18\x01 \x03(\x0b\x32\x1d.injective.peggy.v1.BatchFeesR\tbatchFees\"E\n)QueryLastPendingBatchRequestByAddrRequest\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\"g\n*QueryLastPendingBatchRequestByAddrResponse\x12\x39\n\x05\x62\x61tch\x18\x01 \x01(\x0b\x32#.injective.peggy.v1.OutgoingTxBatchR\x05\x62\x61tch\"\x1f\n\x1dQueryOutgoingTxBatchesRequest\"_\n\x1eQueryOutgoingTxBatchesResponse\x12=\n\x07\x62\x61tches\x18\x01 \x03(\x0b\x32#.injective.peggy.v1.OutgoingTxBatchR\x07\x62\x61tches\"b\n\x1fQueryBatchRequestByNonceRequest\x12\x14\n\x05nonce\x18\x01 \x01(\x04R\x05nonce\x12)\n\x10\x63ontract_address\x18\x02 \x01(\tR\x0f\x63ontractAddress\"]\n QueryBatchRequestByNonceResponse\x12\x39\n\x05\x62\x61tch\x18\x01 \x01(\x0b\x32#.injective.peggy.v1.OutgoingTxBatchR\x05\x62\x61tch\"\\\n\x19QueryBatchConfirmsRequest\x12\x14\n\x05nonce\x18\x01 \x01(\x04R\x05nonce\x12)\n\x10\x63ontract_address\x18\x02 \x01(\tR\x0f\x63ontractAddress\"]\n\x1aQueryBatchConfirmsResponse\x12?\n\x08\x63onfirms\x18\x01 \x03(\x0b\x32#.injective.peggy.v1.MsgConfirmBatchR\x08\x63onfirms\"7\n\x1bQueryLastEventByAddrRequest\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\"l\n\x1cQueryLastEventByAddrResponse\x12L\n\x10last_claim_event\x18\x01 \x01(\x0b\x32\".injective.peggy.v1.LastClaimEventR\x0elastClaimEvent\"0\n\x18QueryERC20ToDenomRequest\x12\x14\n\x05\x65rc20\x18\x01 \x01(\tR\x05\x65rc20\"^\n\x19QueryERC20ToDenomResponse\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12+\n\x11\x63osmos_originated\x18\x02 \x01(\x08R\x10\x63osmosOriginated\"0\n\x18QueryDenomToERC20Request\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\"^\n\x19QueryDenomToERC20Response\x12\x14\n\x05\x65rc20\x18\x01 \x01(\tR\x05\x65rc20\x12+\n\x11\x63osmos_originated\x18\x02 \x01(\x08R\x10\x63osmosOriginated\"R\n#QueryDelegateKeysByValidatorAddress\x12+\n\x11validator_address\x18\x01 \x01(\tR\x10validatorAddress\"\x81\x01\n+QueryDelegateKeysByValidatorAddressResponse\x12\x1f\n\x0b\x65th_address\x18\x01 \x01(\tR\nethAddress\x12\x31\n\x14orchestrator_address\x18\x02 \x01(\tR\x13orchestratorAddress\"@\n\x1dQueryDelegateKeysByEthAddress\x12\x1f\n\x0b\x65th_address\x18\x01 \x01(\tR\nethAddress\"\x87\x01\n%QueryDelegateKeysByEthAddressResponse\x12+\n\x11validator_address\x18\x01 \x01(\tR\x10validatorAddress\x12\x31\n\x14orchestrator_address\x18\x02 \x01(\tR\x13orchestratorAddress\"[\n&QueryDelegateKeysByOrchestratorAddress\x12\x31\n\x14orchestrator_address\x18\x01 \x01(\tR\x13orchestratorAddress\"~\n.QueryDelegateKeysByOrchestratorAddressResponse\x12+\n\x11validator_address\x18\x01 \x01(\tR\x10validatorAddress\x12\x1f\n\x0b\x65th_address\x18\x02 \x01(\tR\nethAddress\">\n\x15QueryPendingSendToEth\x12%\n\x0esender_address\x18\x01 \x01(\tR\rsenderAddress\"\xd2\x01\n\x1dQueryPendingSendToEthResponse\x12X\n\x14transfers_in_batches\x18\x01 \x03(\x0b\x32&.injective.peggy.v1.OutgoingTransferTxR\x12transfersInBatches\x12W\n\x13unbatched_transfers\x18\x02 \x03(\x0b\x32&.injective.peggy.v1.OutgoingTransferTxR\x12unbatchedTransfers\"\x19\n\x17QueryModuleStateRequest\"R\n\x18QueryModuleStateResponse\x12\x36\n\x05state\x18\x01 \x01(\x0b\x32 .injective.peggy.v1.GenesisStateR\x05state\"\x16\n\x14MissingNoncesRequest\"F\n\x15MissingNoncesResponse\x12-\n\x12operator_addresses\x18\x01 \x03(\tR\x11operatorAddresses2\xc6\x1a\n\x05Query\x12s\n\x06Params\x12&.injective.peggy.v1.QueryParamsRequest\x1a\'.injective.peggy.v1.QueryParamsResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/peggy/v1/params\x12\x90\x01\n\rCurrentValset\x12-.injective.peggy.v1.QueryCurrentValsetRequest\x1a..injective.peggy.v1.QueryCurrentValsetResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/peggy/v1/valset/current\x12\x88\x01\n\rValsetRequest\x12-.injective.peggy.v1.QueryValsetRequestRequest\x1a..injective.peggy.v1.QueryValsetRequestResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/peggy/v1/valset\x12\x90\x01\n\rValsetConfirm\x12-.injective.peggy.v1.QueryValsetConfirmRequest\x1a..injective.peggy.v1.QueryValsetConfirmResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/peggy/v1/valset/confirm\x12\xaa\x01\n\x15ValsetConfirmsByNonce\x12\x35.injective.peggy.v1.QueryValsetConfirmsByNonceRequest\x1a\x36.injective.peggy.v1.QueryValsetConfirmsByNonceResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/peggy/v1/confirms/{nonce}\x12\xa0\x01\n\x12LastValsetRequests\x12\x32.injective.peggy.v1.QueryLastValsetRequestsRequest\x1a\x33.injective.peggy.v1.QueryLastValsetRequestsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/peggy/v1/valset/requests\x12\xc0\x01\n\x1eLastPendingValsetRequestByAddr\x12>.injective.peggy.v1.QueryLastPendingValsetRequestByAddrRequest\x1a?.injective.peggy.v1.QueryLastPendingValsetRequestByAddrResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/peggy/v1/valset/last\x12\x9e\x01\n\x0fLastEventByAddr\x12/.injective.peggy.v1.QueryLastEventByAddrRequest\x1a\x30.injective.peggy.v1.QueryLastEventByAddrResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /peggy/v1/oracle/event/{address}\x12\x9a\x01\n\x13GetPendingSendToEth\x12).injective.peggy.v1.QueryPendingSendToEth\x1a\x31.injective.peggy.v1.QueryPendingSendToEthResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/peggy/v1/pending_send_to_eth\x12}\n\tBatchFees\x12(.injective.peggy.v1.QueryBatchFeeRequest\x1a).injective.peggy.v1.QueryBatchFeeResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/peggy/v1/batchfees\x12\x9e\x01\n\x11OutgoingTxBatches\x12\x31.injective.peggy.v1.QueryOutgoingTxBatchesRequest\x1a\x32.injective.peggy.v1.QueryOutgoingTxBatchesResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/peggy/v1/batch/outgoingtx\x12\xbc\x01\n\x1dLastPendingBatchRequestByAddr\x12=.injective.peggy.v1.QueryLastPendingBatchRequestByAddrRequest\x1a>.injective.peggy.v1.QueryLastPendingBatchRequestByAddrResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/peggy/v1/batch/last\x12\x99\x01\n\x13\x42\x61tchRequestByNonce\x12\x33.injective.peggy.v1.QueryBatchRequestByNonceRequest\x1a\x34.injective.peggy.v1.QueryBatchRequestByNonceResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/peggy/v1/batch\x12\x90\x01\n\rBatchConfirms\x12-.injective.peggy.v1.QueryBatchConfirmsRequest\x1a..injective.peggy.v1.QueryBatchConfirmsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/peggy/v1/batch/confirms\x12\x9f\x01\n\x0c\x45RC20ToDenom\x12,.injective.peggy.v1.QueryERC20ToDenomRequest\x1a-.injective.peggy.v1.QueryERC20ToDenomResponse\"2\x82\xd3\xe4\x93\x02,\x12*/peggy/v1/cosmos_originated/erc20_to_denom\x12\x9f\x01\n\x0c\x44\x65nomToERC20\x12,.injective.peggy.v1.QueryDenomToERC20Request\x1a-.injective.peggy.v1.QueryDenomToERC20Response\"2\x82\xd3\xe4\x93\x02,\x12*/peggy/v1/cosmos_originated/denom_to_erc20\x12\xc9\x01\n\x19GetDelegateKeyByValidator\x12\x37.injective.peggy.v1.QueryDelegateKeysByValidatorAddress\x1a?.injective.peggy.v1.QueryDelegateKeysByValidatorAddressResponse\"2\x82\xd3\xe4\x93\x02,\x12*/peggy/v1/query_delegate_keys_by_validator\x12\xb1\x01\n\x13GetDelegateKeyByEth\x12\x31.injective.peggy.v1.QueryDelegateKeysByEthAddress\x1a\x39.injective.peggy.v1.QueryDelegateKeysByEthAddressResponse\",\x82\xd3\xe4\x93\x02&\x12$/peggy/v1/query_delegate_keys_by_eth\x12\xd5\x01\n\x1cGetDelegateKeyByOrchestrator\x12:.injective.peggy.v1.QueryDelegateKeysByOrchestratorAddress\x1a\x42.injective.peggy.v1.QueryDelegateKeysByOrchestratorAddressResponse\"5\x82\xd3\xe4\x93\x02/\x12-/peggy/v1/query_delegate_keys_by_orchestrator\x12\x8d\x01\n\x10PeggyModuleState\x12+.injective.peggy.v1.QueryModuleStateRequest\x1a,.injective.peggy.v1.QueryModuleStateResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/peggy/v1/module_state\x12\x8b\x01\n\x12MissingPeggoNonces\x12(.injective.peggy.v1.MissingNoncesRequest\x1a).injective.peggy.v1.MissingNoncesResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/peggy/v1/missing_noncesB\xdb\x01\n\x16\x63om.injective.peggy.v1B\nQueryProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types\xa2\x02\x03IPX\xaa\x02\x12Injective.Peggy.V1\xca\x02\x12Injective\\Peggy\\V1\xe2\x02\x1eInjective\\Peggy\\V1\\GPBMetadata\xea\x02\x14Injective::Peggy::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.peggy.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.injective.peggy.v1B\nQueryProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types\242\002\003IPX\252\002\022Injective.Peggy.V1\312\002\022Injective\\Peggy\\V1\342\002\036Injective\\Peggy\\V1\\GPBMetadata\352\002\024Injective::Peggy::V1'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\022\022\020/peggy/v1/params'
  _globals['_QUERY'].methods_by_name['CurrentValset']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CurrentValset']._serialized_options = b'\202\323\344\223\002\032\022\030/peggy/v1/valset/current'
  _globals['_QUERY'].methods_by_name['ValsetRequest']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ValsetRequest']._serialized_options = b'\202\323\344\223\002\022\022\020/peggy/v1/valset'
  _globals['_QUERY'].methods_by_name['ValsetConfirm']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ValsetConfirm']._serialized_options = b'\202\323\344\223\002\032\022\030/peggy/v1/valset/confirm'
  _globals['_QUERY'].methods_by_name['ValsetConfirmsByNonce']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ValsetConfirmsByNonce']._serialized_options = b'\202\323\344\223\002\034\022\032/peggy/v1/confirms/{nonce}'
  _globals['_QUERY'].methods_by_name['LastValsetRequests']._loaded_options = None
  _globals['_QUERY'].methods_by_name['LastValsetRequests']._serialized_options = b'\202\323\344\223\002\033\022\031/peggy/v1/valset/requests'
  _globals['_QUERY'].methods_by_name['LastPendingValsetRequestByAddr']._loaded_options = None
  _globals['_QUERY'].methods_by_name['LastPendingValsetRequestByAddr']._serialized_options = b'\202\323\344\223\002\027\022\025/peggy/v1/valset/last'
  _globals['_QUERY'].methods_by_name['LastEventByAddr']._loaded_options = None
  _globals['_QUERY'].methods_by_name['LastEventByAddr']._serialized_options = b'\202\323\344\223\002\"\022 /peggy/v1/oracle/event/{address}'
  _globals['_QUERY'].methods_by_name['GetPendingSendToEth']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPendingSendToEth']._serialized_options = b'\202\323\344\223\002\037\022\035/peggy/v1/pending_send_to_eth'
  _globals['_QUERY'].methods_by_name['BatchFees']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BatchFees']._serialized_options = b'\202\323\344\223\002\025\022\023/peggy/v1/batchfees'
  _globals['_QUERY'].methods_by_name['OutgoingTxBatches']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OutgoingTxBatches']._serialized_options = b'\202\323\344\223\002\034\022\032/peggy/v1/batch/outgoingtx'
  _globals['_QUERY'].methods_by_name['LastPendingBatchRequestByAddr']._loaded_options = None
  _globals['_QUERY'].methods_by_name['LastPendingBatchRequestByAddr']._serialized_options = b'\202\323\344\223\002\026\022\024/peggy/v1/batch/last'
  _globals['_QUERY'].methods_by_name['BatchRequestByNonce']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BatchRequestByNonce']._serialized_options = b'\202\323\344\223\002\021\022\017/peggy/v1/batch'
  _globals['_QUERY'].methods_by_name['BatchConfirms']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BatchConfirms']._serialized_options = b'\202\323\344\223\002\032\022\030/peggy/v1/batch/confirms'
  _globals['_QUERY'].methods_by_name['ERC20ToDenom']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ERC20ToDenom']._serialized_options = b'\202\323\344\223\002,\022*/peggy/v1/cosmos_originated/erc20_to_denom'
  _globals['_QUERY'].methods_by_name['DenomToERC20']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomToERC20']._serialized_options = b'\202\323\344\223\002,\022*/peggy/v1/cosmos_originated/denom_to_erc20'
  _globals['_QUERY'].methods_by_name['GetDelegateKeyByValidator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetDelegateKeyByValidator']._serialized_options = b'\202\323\344\223\002,\022*/peggy/v1/query_delegate_keys_by_validator'
  _globals['_QUERY'].methods_by_name['GetDelegateKeyByEth']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetDelegateKeyByEth']._serialized_options = b'\202\323\344\223\002&\022$/peggy/v1/query_delegate_keys_by_eth'
  _globals['_QUERY'].methods_by_name['GetDelegateKeyByOrchestrator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetDelegateKeyByOrchestrator']._serialized_options = b'\202\323\344\223\002/\022-/peggy/v1/query_delegate_keys_by_orchestrator'
  _globals['_QUERY'].methods_by_name['PeggyModuleState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PeggyModuleState']._serialized_options = b'\202\323\344\223\002\030\022\026/peggy/v1/module_state'
  _globals['_QUERY'].methods_by_name['MissingPeggoNonces']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MissingPeggoNonces']._serialized_options = b'\202\323\344\223\002\032\022\030/peggy/v1/missing_nonces'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=299
  _globals['_QUERYPARAMSREQUEST']._serialized_end=319
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=321
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=400
  _globals['_QUERYCURRENTVALSETREQUEST']._serialized_start=402
  _globals['_QUERYCURRENTVALSETREQUEST']._serialized_end=429
  _globals['_QUERYCURRENTVALSETRESPONSE']._serialized_start=431
  _globals['_QUERYCURRENTVALSETRESPONSE']._serialized_end=511
  _globals['_QUERYVALSETREQUESTREQUEST']._serialized_start=513
  _globals['_QUERYVALSETREQUESTREQUEST']._serialized_end=562
  _globals['_QUERYVALSETREQUESTRESPONSE']._serialized_start=564
  _globals['_QUERYVALSETREQUESTRESPONSE']._serialized_end=644
  _globals['_QUERYVALSETCONFIRMREQUEST']._serialized_start=646
  _globals['_QUERYVALSETCONFIRMREQUEST']._serialized_end=721
  _globals['_QUERYVALSETCONFIRMRESPONSE']._serialized_start=723
  _globals['_QUERYVALSETCONFIRMRESPONSE']._serialized_end=815
  _globals['_QUERYVALSETCONFIRMSBYNONCEREQUEST']._serialized_start=817
  _globals['_QUERYVALSETCONFIRMSBYNONCEREQUEST']._serialized_end=874
  _globals['_QUERYVALSETCONFIRMSBYNONCERESPONSE']._serialized_start=876
  _globals['_QUERYVALSETCONFIRMSBYNONCERESPONSE']._serialized_end=978
  _globals['_QUERYLASTVALSETREQUESTSREQUEST']._serialized_start=980
  _globals['_QUERYLASTVALSETREQUESTSREQUEST']._serialized_end=1012
  _globals['_QUERYLASTVALSETREQUESTSRESPONSE']._serialized_start=1014
  _globals['_QUERYLASTVALSETREQUESTSRESPONSE']._serialized_end=1101
  _globals['_QUERYLASTPENDINGVALSETREQUESTBYADDRREQUEST']._serialized_start=1103
  _globals['_QUERYLASTPENDINGVALSETREQUESTBYADDRREQUEST']._serialized_end=1173
  _globals['_QUERYLASTPENDINGVALSETREQUESTBYADDRRESPONSE']._serialized_start=1175
  _globals['_QUERYLASTPENDINGVALSETREQUESTBYADDRRESPONSE']._serialized_end=1274
  _globals['_QUERYBATCHFEEREQUEST']._serialized_start=1276
  _globals['_QUERYBATCHFEEREQUEST']._serialized_end=1298
  _globals['_QUERYBATCHFEERESPONSE']._serialized_start=1300
  _globals['_QUERYBATCHFEERESPONSE']._serialized_end=1384
  _globals['_QUERYLASTPENDINGBATCHREQUESTBYADDRREQUEST']._serialized_start=1386
  _globals['_QUERYLASTPENDINGBATCHREQUESTBYADDRREQUEST']._serialized_end=1455
  _globals['_QUERYLASTPENDINGBATCHREQUESTBYADDRRESPONSE']._serialized_start=1457
  _globals['_QUERYLASTPENDINGBATCHREQUESTBYADDRRESPONSE']._serialized_end=1560
  _globals['_QUERYOUTGOINGTXBATCHESREQUEST']._serialized_start=1562
  _globals['_QUERYOUTGOINGTXBATCHESREQUEST']._serialized_end=1593
  _globals['_QUERYOUTGOINGTXBATCHESRESPONSE']._serialized_start=1595
  _globals['_QUERYOUTGOINGTXBATCHESRESPONSE']._serialized_end=1690
  _globals['_QUERYBATCHREQUESTBYNONCEREQUEST']._serialized_start=1692
  _globals['_QUERYBATCHREQUESTBYNONCEREQUEST']._serialized_end=1790
  _globals['_QUERYBATCHREQUESTBYNONCERESPONSE']._serialized_start=1792
  _globals['_QUERYBATCHREQUESTBYNONCERESPONSE']._serialized_end=1885
  _globals['_QUERYBATCHCONFIRMSREQUEST']._serialized_start=1887
  _globals['_QUERYBATCHCONFIRMSREQUEST']._serialized_end=1979
  _globals['_QUERYBATCHCONFIRMSRESPONSE']._serialized_start=1981
  _globals['_QUERYBATCHCONFIRMSRESPONSE']._serialized_end=2074
  _globals['_QUERYLASTEVENTBYADDRREQUEST']._serialized_start=2076
  _globals['_QUERYLASTEVENTBYADDRREQUEST']._serialized_end=2131
  _globals['_QUERYLASTEVENTBYADDRRESPONSE']._serialized_start=2133
  _globals['_QUERYLASTEVENTBYADDRRESPONSE']._serialized_end=2241
  _globals['_QUERYERC20TODENOMREQUEST']._serialized_start=2243
  _globals['_QUERYERC20TODENOMREQUEST']._serialized_end=2291
  _globals['_QUERYERC20TODENOMRESPONSE']._serialized_start=2293
  _globals['_QUERYERC20TODENOMRESPONSE']._serialized_end=2387
  _globals['_QUERYDENOMTOERC20REQUEST']._serialized_start=2389
  _globals['_QUERYDENOMTOERC20REQUEST']._serialized_end=2437
  _globals['_QUERYDENOMTOERC20RESPONSE']._serialized_start=2439
  _globals['_QUERYDENOMTOERC20RESPONSE']._serialized_end=2533
  _globals['_QUERYDELEGATEKEYSBYVALIDATORADDRESS']._serialized_start=2535
  _globals['_QUERYDELEGATEKEYSBYVALIDATORADDRESS']._serialized_end=2617
  _globals['_QUERYDELEGATEKEYSBYVALIDATORADDRESSRESPONSE']._serialized_start=2620
  _globals['_QUERYDELEGATEKEYSBYVALIDATORADDRESSRESPONSE']._serialized_end=2749
  _globals['_QUERYDELEGATEKEYSBYETHADDRESS']._serialized_start=2751
  _globals['_QUERYDELEGATEKEYSBYETHADDRESS']._serialized_end=2815
  _globals['_QUERYDELEGATEKEYSBYETHADDRESSRESPONSE']._serialized_start=2818
  _globals['_QUERYDELEGATEKEYSBYETHADDRESSRESPONSE']._serialized_end=2953
  _globals['_QUERYDELEGATEKEYSBYORCHESTRATORADDRESS']._serialized_start=2955
  _globals['_QUERYDELEGATEKEYSBYORCHESTRATORADDRESS']._serialized_end=3046
  _globals['_QUERYDELEGATEKEYSBYORCHESTRATORADDRESSRESPONSE']._serialized_start=3048
  _globals['_QUERYDELEGATEKEYSBYORCHESTRATORADDRESSRESPONSE']._serialized_end=3174
  _globals['_QUERYPENDINGSENDTOETH']._serialized_start=3176
  _globals['_QUERYPENDINGSENDTOETH']._serialized_end=3238
  _globals['_QUERYPENDINGSENDTOETHRESPONSE']._serialized_start=3241
  _globals['_QUERYPENDINGSENDTOETHRESPONSE']._serialized_end=3451
  _globals['_QUERYMODULESTATEREQUEST']._serialized_start=3453
  _globals['_QUERYMODULESTATEREQUEST']._serialized_end=3478
  _globals['_QUERYMODULESTATERESPONSE']._serialized_start=3480
  _globals['_QUERYMODULESTATERESPONSE']._serialized_end=3562
  _globals['_MISSINGNONCESREQUEST']._serialized_start=3564
  _globals['_MISSINGNONCESREQUEST']._serialized_end=3586
  _globals['_MISSINGNONCESRESPONSE']._serialized_start=3588
  _globals['_MISSINGNONCESRESPONSE']._serialized_end=3658
  _globals['_QUERY']._serialized_start=3661
  _globals['_QUERY']._serialized_end=7059
# @@protoc_insertion_point(module_scope)
