# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/services/version/v1/version.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cometbft/services/version/v1/version.proto\x12\x1c\x63ometbft.services.version.v1\"\x13\n\x11GetVersionRequest\"d\n\x12GetVersionResponse\x12\x12\n\x04node\x18\x01 \x01(\tR\x04node\x12\x12\n\x04\x61\x62\x63i\x18\x02 \x01(\tR\x04\x61\x62\x63i\x12\x10\n\x03p2p\x18\x03 \x01(\x04R\x03p2p\x12\x14\n\x05\x62lock\x18\x04 \x01(\x04R\x05\x62lockB\x82\x02\n com.cometbft.services.version.v1B\x0cVersionProtoP\x01Z=github.com/cometbft/cometbft/api/cometbft/services/version/v1\xa2\x02\x03\x43SV\xaa\x02\x1c\x43ometbft.Services.Version.V1\xca\x02\x1c\x43ometbft\\Services\\Version\\V1\xe2\x02(Cometbft\\Services\\Version\\V1\\GPBMetadata\xea\x02\x1f\x43ometbft::Services::Version::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.services.version.v1.version_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.cometbft.services.version.v1B\014VersionProtoP\001Z=github.com/cometbft/cometbft/api/cometbft/services/version/v1\242\002\003CSV\252\002\034Cometbft.Services.Version.V1\312\002\034Cometbft\\Services\\Version\\V1\342\002(Cometbft\\Services\\Version\\V1\\GPBMetadata\352\002\037Cometbft::Services::Version::V1'
  _globals['_GETVERSIONREQUEST']._serialized_start=76
  _globals['_GETVERSIONREQUEST']._serialized_end=95
  _globals['_GETVERSIONRESPONSE']._serialized_start=97
  _globals['_GETVERSIONRESPONSE']._serialized_end=197
# @@protoc_insertion_point(module_scope)
