# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/blocksync/v1beta1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.types.v1beta1 import block_pb2 as cometbft_dot_types_dot_v1beta1_dot_block__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cometbft/blocksync/v1beta1/types.proto\x12\x1a\x63ometbft.blocksync.v1beta1\x1a\"cometbft/types/v1beta1/block.proto\"&\n\x0c\x42lockRequest\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\")\n\x0fNoBlockResponse\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\"D\n\rBlockResponse\x12\x33\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x1d.cometbft.types.v1beta1.BlockR\x05\x62lock\"\x0f\n\rStatusRequest\"<\n\x0eStatusResponse\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12\x12\n\x04\x62\x61se\x18\x02 \x01(\x03R\x04\x62\x61se\"\xbb\x03\n\x07Message\x12O\n\rblock_request\x18\x01 \x01(\x0b\x32(.cometbft.blocksync.v1beta1.BlockRequestH\x00R\x0c\x62lockRequest\x12Y\n\x11no_block_response\x18\x02 \x01(\x0b\x32+.cometbft.blocksync.v1beta1.NoBlockResponseH\x00R\x0fnoBlockResponse\x12R\n\x0e\x62lock_response\x18\x03 \x01(\x0b\x32).cometbft.blocksync.v1beta1.BlockResponseH\x00R\rblockResponse\x12R\n\x0estatus_request\x18\x04 \x01(\x0b\x32).cometbft.blocksync.v1beta1.StatusRequestH\x00R\rstatusRequest\x12U\n\x0fstatus_response\x18\x05 \x01(\x0b\x32*.cometbft.blocksync.v1beta1.StatusResponseH\x00R\x0estatusResponseB\x05\n\x03sumB\xf3\x01\n\x1e\x63om.cometbft.blocksync.v1beta1B\nTypesProtoP\x01Z;github.com/cometbft/cometbft/api/cometbft/blocksync/v1beta1\xa2\x02\x03\x43\x42X\xaa\x02\x1a\x43ometbft.Blocksync.V1beta1\xca\x02\x1a\x43ometbft\\Blocksync\\V1beta1\xe2\x02&Cometbft\\Blocksync\\V1beta1\\GPBMetadata\xea\x02\x1c\x43ometbft::Blocksync::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.blocksync.v1beta1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036com.cometbft.blocksync.v1beta1B\nTypesProtoP\001Z;github.com/cometbft/cometbft/api/cometbft/blocksync/v1beta1\242\002\003CBX\252\002\032Cometbft.Blocksync.V1beta1\312\002\032Cometbft\\Blocksync\\V1beta1\342\002&Cometbft\\Blocksync\\V1beta1\\GPBMetadata\352\002\034Cometbft::Blocksync::V1beta1'
  _globals['_BLOCKREQUEST']._serialized_start=106
  _globals['_BLOCKREQUEST']._serialized_end=144
  _globals['_NOBLOCKRESPONSE']._serialized_start=146
  _globals['_NOBLOCKRESPONSE']._serialized_end=187
  _globals['_BLOCKRESPONSE']._serialized_start=189
  _globals['_BLOCKRESPONSE']._serialized_end=257
  _globals['_STATUSREQUEST']._serialized_start=259
  _globals['_STATUSREQUEST']._serialized_end=274
  _globals['_STATUSRESPONSE']._serialized_start=276
  _globals['_STATUSRESPONSE']._serialized_end=336
  _globals['_MESSAGE']._serialized_start=339
  _globals['_MESSAGE']._serialized_end=782
# @@protoc_insertion_point(module_scope)
