# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/evm/v1/trace_config.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.evm.v1 import chain_config_pb2 as injective_dot_evm_dot_v1_dot_chain__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#injective/evm/v1/trace_config.proto\x12\x10injective.evm.v1\x1a\x14gogoproto/gogo.proto\x1a#injective/evm/v1/chain_config.proto\"\x9a\x05\n\x0bTraceConfig\x12\x16\n\x06tracer\x18\x01 \x01(\tR\x06tracer\x12\x18\n\x07timeout\x18\x02 \x01(\tR\x07timeout\x12\x16\n\x06reexec\x18\x03 \x01(\x04R\x06reexec\x12\x35\n\rdisable_stack\x18\x05 \x01(\x08\x42\x10\xea\xde\x1f\x0c\x64isableStackR\x0c\x64isableStack\x12;\n\x0f\x64isable_storage\x18\x06 \x01(\x08\x42\x12\xea\xde\x1f\x0e\x64isableStorageR\x0e\x64isableStorage\x12\x14\n\x05\x64\x65\x62ug\x18\x08 \x01(\x08R\x05\x64\x65\x62ug\x12\x14\n\x05limit\x18\t \x01(\x05R\x05limit\x12;\n\toverrides\x18\n \x01(\x0b\x32\x1d.injective.evm.v1.ChainConfigR\toverrides\x12\x35\n\renable_memory\x18\x0b \x01(\x08\x42\x10\xea\xde\x1f\x0c\x65nableMemoryR\x0c\x65nableMemory\x12\x42\n\x12\x65nable_return_data\x18\x0c \x01(\x08\x42\x14\xea\xde\x1f\x10\x65nableReturnDataR\x10\x65nableReturnData\x12>\n\x12tracer_json_config\x18\r \x01(\tB\x10\xea\xde\x1f\x0ctracerConfigR\x10tracerJsonConfig\x12;\n\x0fstate_overrides\x18\x0e \x01(\x0c\x42\x12\xea\xde\x1f\x0estateOverridesR\x0estateOverrides\x12;\n\x0f\x62lock_overrides\x18\x0f \x01(\x0c\x42\x12\xea\xde\x1f\x0e\x62lockOverridesR\x0e\x62lockOverridesJ\x04\x08\x04\x10\x05J\x04\x08\x07\x10\x08R\x0e\x64isable_memoryR\x13\x64isable_return_dataB\xd5\x01\n\x14\x63om.injective.evm.v1B\x10TraceConfigProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\xa2\x02\x03IEX\xaa\x02\x10Injective.Evm.V1\xca\x02\x10Injective\\Evm\\V1\xe2\x02\x1cInjective\\Evm\\V1\\GPBMetadata\xea\x02\x12Injective::Evm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.evm.v1.trace_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.injective.evm.v1B\020TraceConfigProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\242\002\003IEX\252\002\020Injective.Evm.V1\312\002\020Injective\\Evm\\V1\342\002\034Injective\\Evm\\V1\\GPBMetadata\352\002\022Injective::Evm::V1'
  _globals['_TRACECONFIG'].fields_by_name['disable_stack']._loaded_options = None
  _globals['_TRACECONFIG'].fields_by_name['disable_stack']._serialized_options = b'\352\336\037\014disableStack'
  _globals['_TRACECONFIG'].fields_by_name['disable_storage']._loaded_options = None
  _globals['_TRACECONFIG'].fields_by_name['disable_storage']._serialized_options = b'\352\336\037\016disableStorage'
  _globals['_TRACECONFIG'].fields_by_name['enable_memory']._loaded_options = None
  _globals['_TRACECONFIG'].fields_by_name['enable_memory']._serialized_options = b'\352\336\037\014enableMemory'
  _globals['_TRACECONFIG'].fields_by_name['enable_return_data']._loaded_options = None
  _globals['_TRACECONFIG'].fields_by_name['enable_return_data']._serialized_options = b'\352\336\037\020enableReturnData'
  _globals['_TRACECONFIG'].fields_by_name['tracer_json_config']._loaded_options = None
  _globals['_TRACECONFIG'].fields_by_name['tracer_json_config']._serialized_options = b'\352\336\037\014tracerConfig'
  _globals['_TRACECONFIG'].fields_by_name['state_overrides']._loaded_options = None
  _globals['_TRACECONFIG'].fields_by_name['state_overrides']._serialized_options = b'\352\336\037\016stateOverrides'
  _globals['_TRACECONFIG'].fields_by_name['block_overrides']._loaded_options = None
  _globals['_TRACECONFIG'].fields_by_name['block_overrides']._serialized_options = b'\352\336\037\016blockOverrides'
  _globals['_TRACECONFIG']._serialized_start=117
  _globals['_TRACECONFIG']._serialized_end=783
# @@protoc_insertion_point(module_scope)
