# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/type/postal_address.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n google/type/postal_address.proto\x12\x0bgoogle.type\"\x8d\x03\n\rPostalAddress\x12\x1a\n\x08revision\x18\x01 \x01(\x05R\x08revision\x12\x1f\n\x0bregion_code\x18\x02 \x01(\tR\nregionCode\x12#\n\rlanguage_code\x18\x03 \x01(\tR\x0clanguageCode\x12\x1f\n\x0bpostal_code\x18\x04 \x01(\tR\npostalCode\x12!\n\x0csorting_code\x18\x05 \x01(\tR\x0bsortingCode\x12/\n\x13\x61\x64ministrative_area\x18\x06 \x01(\tR\x12\x61\x64ministrativeArea\x12\x1a\n\x08locality\x18\x07 \x01(\tR\x08locality\x12 \n\x0bsublocality\x18\x08 \x01(\tR\x0bsublocality\x12#\n\raddress_lines\x18\t \x03(\tR\x0c\x61\x64\x64ressLines\x12\x1e\n\nrecipients\x18\n \x03(\tR\nrecipients\x12\"\n\x0corganization\x18\x0b \x01(\tR\x0corganizationB\xbd\x01\n\x0f\x63om.google.typeB\x12PostalAddressProtoP\x01ZFgoogle.golang.org/genproto/googleapis/type/postaladdress;postaladdress\xf8\x01\x01\xa2\x02\x03GTX\xaa\x02\x0bGoogle.Type\xca\x02\x0bGoogle\\Type\xe2\x02\x17Google\\Type\\GPBMetadata\xea\x02\x0cGoogle::Typeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.postal_address_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.google.typeB\022PostalAddressProtoP\001ZFgoogle.golang.org/genproto/googleapis/type/postaladdress;postaladdress\370\001\001\242\002\003GTX\252\002\013Google.Type\312\002\013Google\\Type\342\002\027Google\\Type\\GPBMetadata\352\002\014Google::Type'
  _globals['_POSTALADDRESS']._serialized_start=50
  _globals['_POSTALADDRESS']._serialized_end=447
# @@protoc_insertion_point(module_scope)
