# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/txfees/v1beta1/txfees.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%injective/txfees/v1beta1/txfees.proto\x12\x18injective.txfees.v1beta1\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\"\x99\x0c\n\x06Params\x12R\n\x15max_gas_wanted_per_tx\x18\x01 \x01(\x04\x42 \xf2\xde\x1f\x1cyaml:\"max_gas_wanted_per_tx\"R\x11maxGasWantedPerTx\x12S\n\x15high_gas_tx_threshold\x18\x02 \x01(\x04\x42 \xf2\xde\x1f\x1cyaml:\"high_gas_tx_threshold\"R\x12highGasTxThreshold\x12\x8b\x01\n\x1dmin_gas_price_for_high_gas_tx\x18\x03 \x01(\tBK\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f$yaml:\"min_gas_price_for_high_gas_tx\"R\x17minGasPriceForHighGasTx\x12O\n\x13mempool1559_enabled\x18\x04 \x01(\x08\x42\x1e\xf2\xde\x1f\x1ayaml:\"mempool1559_enabled\"R\x12mempool1559Enabled\x12_\n\rmin_gas_price\x18\x05 \x01(\tB;\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f\x14yaml:\"min_gas_price\"R\x0bminGasPrice\x12\x88\x01\n\x1b\x64\x65\x66\x61ult_base_fee_multiplier\x18\x06 \x01(\tBI\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f\"yaml:\"default_base_fee_multiplier\"R\x18\x64\x65\x66\x61ultBaseFeeMultiplier\x12|\n\x17max_base_fee_multiplier\x18\x07 \x01(\tBE\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f\x1eyaml:\"max_base_fee_multiplier\"R\x14maxBaseFeeMultiplier\x12@\n\x0ereset_interval\x18\x08 \x01(\x03\x42\x19\xf2\xde\x1f\x15yaml:\"reset_interval\"R\rresetInterval\x12v\n\x15max_block_change_rate\x18\t \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f\x1cyaml:\"max_block_change_rate\"R\x12maxBlockChangeRate\x12\x93\x01\n\x1ftarget_block_space_percent_rate\x18\n \x01(\tBM\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f&yaml:\"target_block_space_percent_rate\"R\x1btargetBlockSpacePercentRate\x12~\n\x18recheck_fee_low_base_fee\x18\x0b \x01(\tBF\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f\x1fyaml:\"recheck_fee_low_base_fee\"R\x14recheckFeeLowBaseFee\x12\x81\x01\n\x19recheck_fee_high_base_fee\x18\x0c \x01(\tBG\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f yaml:\"recheck_fee_high_base_fee\"R\x15recheckFeeHighBaseFee\x12\xb0\x01\n)recheck_fee_base_fee_threshold_multiplier\x18\r \x01(\tBW\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f\x30yaml:\"recheck_fee_base_fee_threshold_multiplier\"R$recheckFeeBaseFeeThresholdMultiplier:\x16\xe8\xa0\x1f\x01\x8a\xe7\xb0*\rtxfees/ParamsB\xff\x01\n\x1c\x63om.injective.txfees.v1beta1B\x0bTxfeesProtoP\x01ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/txfees/types\xa2\x02\x03ITX\xaa\x02\x18Injective.Txfees.V1beta1\xca\x02\x18Injective\\Txfees\\V1beta1\xe2\x02$Injective\\Txfees\\V1beta1\\GPBMetadata\xea\x02\x1aInjective::Txfees::V1beta1\xc0\xe3\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.txfees.v1beta1.txfees_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.injective.txfees.v1beta1B\013TxfeesProtoP\001ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/txfees/types\242\002\003ITX\252\002\030Injective.Txfees.V1beta1\312\002\030Injective\\Txfees\\V1beta1\342\002$Injective\\Txfees\\V1beta1\\GPBMetadata\352\002\032Injective::Txfees::V1beta1\300\343\036\001'
  _globals['_PARAMS'].fields_by_name['max_gas_wanted_per_tx']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['max_gas_wanted_per_tx']._serialized_options = b'\362\336\037\034yaml:\"max_gas_wanted_per_tx\"'
  _globals['_PARAMS'].fields_by_name['high_gas_tx_threshold']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['high_gas_tx_threshold']._serialized_options = b'\362\336\037\034yaml:\"high_gas_tx_threshold\"'
  _globals['_PARAMS'].fields_by_name['min_gas_price_for_high_gas_tx']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['min_gas_price_for_high_gas_tx']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037$yaml:\"min_gas_price_for_high_gas_tx\"'
  _globals['_PARAMS'].fields_by_name['mempool1559_enabled']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['mempool1559_enabled']._serialized_options = b'\362\336\037\032yaml:\"mempool1559_enabled\"'
  _globals['_PARAMS'].fields_by_name['min_gas_price']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['min_gas_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037\024yaml:\"min_gas_price\"'
  _globals['_PARAMS'].fields_by_name['default_base_fee_multiplier']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['default_base_fee_multiplier']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037\"yaml:\"default_base_fee_multiplier\"'
  _globals['_PARAMS'].fields_by_name['max_base_fee_multiplier']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['max_base_fee_multiplier']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037\036yaml:\"max_base_fee_multiplier\"'
  _globals['_PARAMS'].fields_by_name['reset_interval']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['reset_interval']._serialized_options = b'\362\336\037\025yaml:\"reset_interval\"'
  _globals['_PARAMS'].fields_by_name['max_block_change_rate']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['max_block_change_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037\034yaml:\"max_block_change_rate\"'
  _globals['_PARAMS'].fields_by_name['target_block_space_percent_rate']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['target_block_space_percent_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037&yaml:\"target_block_space_percent_rate\"'
  _globals['_PARAMS'].fields_by_name['recheck_fee_low_base_fee']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['recheck_fee_low_base_fee']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037\037yaml:\"recheck_fee_low_base_fee\"'
  _globals['_PARAMS'].fields_by_name['recheck_fee_high_base_fee']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['recheck_fee_high_base_fee']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037 yaml:\"recheck_fee_high_base_fee\"'
  _globals['_PARAMS'].fields_by_name['recheck_fee_base_fee_threshold_multiplier']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['recheck_fee_base_fee_threshold_multiplier']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\0370yaml:\"recheck_fee_base_fee_threshold_multiplier\"'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\350\240\037\001\212\347\260*\rtxfees/Params'
  _globals['_PARAMS']._serialized_start=139
  _globals['_PARAMS']._serialized_end=1700
# @@protoc_insertion_point(module_scope)
