# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/client/v1/client.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.upgrade.v1beta1 import upgrade_pb2 as cosmos_dot_upgrade_dot_v1beta1_dot_upgrade__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fibc/core/client/v1/client.proto\x12\x12ibc.core.client.v1\x1a$cosmos/upgrade/v1beta1/upgrade.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"m\n\x15IdentifiedClientState\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x37\n\x0c\x63lient_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyR\x0b\x63lientState\"\x93\x01\n\x18\x43onsensusStateWithHeight\x12\x38\n\x06height\x18\x01 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x06height\x12=\n\x0f\x63onsensus_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyR\x0e\x63onsensusState\"\x93\x01\n\x15\x43lientConsensusStates\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12]\n\x10\x63onsensus_states\x18\x02 \x03(\x0b\x32,.ibc.core.client.v1.ConsensusStateWithHeightB\x04\xc8\xde\x1f\x00R\x0f\x63onsensusStates\"d\n\x06Height\x12\'\n\x0frevision_number\x18\x01 \x01(\x04R\x0erevisionNumber\x12\'\n\x0frevision_height\x18\x02 \x01(\x04R\x0erevisionHeight:\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"1\n\x06Params\x12\'\n\x0f\x61llowed_clients\x18\x01 \x03(\tR\x0e\x61llowedClients\"\x91\x02\n\x14\x43lientUpdateProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12H\n\x11subject_client_id\x18\x03 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"subject_client_id\"R\x0fsubjectClientId\x12Q\n\x14substitute_client_id\x18\x04 \x01(\tB\x1f\xf2\xde\x1f\x1byaml:\"substitute_client_id\"R\x12substituteClientId:$\x18\x01\x88\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\x9b\x02\n\x0fUpgradeProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x36\n\x04plan\x18\x03 \x01(\x0b\x32\x1c.cosmos.upgrade.v1beta1.PlanB\x04\xc8\xde\x1f\x00R\x04plan\x12j\n\x15upgraded_client_state\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyB \xf2\xde\x1f\x1cyaml:\"upgraded_client_state\"R\x13upgradedClientState:,\x18\x01\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x01\xca\xb4-\x1a\x63osmos.gov.v1beta1.ContentB\xca\x01\n\x16\x63om.ibc.core.client.v1B\x0b\x43lientProtoP\x01Z8github.com/cosmos/ibc-go/v8/modules/core/02-client/types\xa2\x02\x03ICC\xaa\x02\x12Ibc.Core.Client.V1\xca\x02\x12Ibc\\Core\\Client\\V1\xe2\x02\x1eIbc\\Core\\Client\\V1\\GPBMetadata\xea\x02\x15Ibc::Core::Client::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.client.v1.client_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.ibc.core.client.v1B\013ClientProtoP\001Z8github.com/cosmos/ibc-go/v8/modules/core/02-client/types\242\002\003ICC\252\002\022Ibc.Core.Client.V1\312\002\022Ibc\\Core\\Client\\V1\342\002\036Ibc\\Core\\Client\\V1\\GPBMetadata\352\002\025Ibc::Core::Client::V1'
  _globals['_CONSENSUSSTATEWITHHEIGHT'].fields_by_name['height']._loaded_options = None
  _globals['_CONSENSUSSTATEWITHHEIGHT'].fields_by_name['height']._serialized_options = b'\310\336\037\000'
  _globals['_CLIENTCONSENSUSSTATES'].fields_by_name['consensus_states']._loaded_options = None
  _globals['_CLIENTCONSENSUSSTATES'].fields_by_name['consensus_states']._serialized_options = b'\310\336\037\000'
  _globals['_HEIGHT']._loaded_options = None
  _globals['_HEIGHT']._serialized_options = b'\210\240\037\000\230\240\037\000'
  _globals['_CLIENTUPDATEPROPOSAL'].fields_by_name['subject_client_id']._loaded_options = None
  _globals['_CLIENTUPDATEPROPOSAL'].fields_by_name['subject_client_id']._serialized_options = b'\362\336\037\030yaml:\"subject_client_id\"'
  _globals['_CLIENTUPDATEPROPOSAL'].fields_by_name['substitute_client_id']._loaded_options = None
  _globals['_CLIENTUPDATEPROPOSAL'].fields_by_name['substitute_client_id']._serialized_options = b'\362\336\037\033yaml:\"substitute_client_id\"'
  _globals['_CLIENTUPDATEPROPOSAL']._loaded_options = None
  _globals['_CLIENTUPDATEPROPOSAL']._serialized_options = b'\030\001\210\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _globals['_UPGRADEPROPOSAL'].fields_by_name['plan']._loaded_options = None
  _globals['_UPGRADEPROPOSAL'].fields_by_name['plan']._serialized_options = b'\310\336\037\000'
  _globals['_UPGRADEPROPOSAL'].fields_by_name['upgraded_client_state']._loaded_options = None
  _globals['_UPGRADEPROPOSAL'].fields_by_name['upgraded_client_state']._serialized_options = b'\362\336\037\034yaml:\"upgraded_client_state\"'
  _globals['_UPGRADEPROPOSAL']._loaded_options = None
  _globals['_UPGRADEPROPOSAL']._serialized_options = b'\030\001\210\240\037\000\230\240\037\000\350\240\037\001\312\264-\032cosmos.gov.v1beta1.Content'
  _globals['_IDENTIFIEDCLIENTSTATE']._serialized_start=169
  _globals['_IDENTIFIEDCLIENTSTATE']._serialized_end=278
  _globals['_CONSENSUSSTATEWITHHEIGHT']._serialized_start=281
  _globals['_CONSENSUSSTATEWITHHEIGHT']._serialized_end=428
  _globals['_CLIENTCONSENSUSSTATES']._serialized_start=431
  _globals['_CLIENTCONSENSUSSTATES']._serialized_end=578
  _globals['_HEIGHT']._serialized_start=580
  _globals['_HEIGHT']._serialized_end=680
  _globals['_PARAMS']._serialized_start=682
  _globals['_PARAMS']._serialized_end=731
  _globals['_CLIENTUPDATEPROPOSAL']._serialized_start=734
  _globals['_CLIENTUPDATEPROPOSAL']._serialized_end=1007
  _globals['_UPGRADEPROPOSAL']._serialized_start=1010
  _globals['_UPGRADEPROPOSAL']._serialized_end=1293
# @@protoc_insertion_point(module_scope)
