# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/rpc/grpc/v1beta3/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.rpc.grpc.v1beta1 import types_pb2 as cometbft_dot_rpc_dot_grpc_dot_v1beta1_dot_types__pb2
from pyinjective.proto.cometbft.abci.v1beta3 import types_pb2 as cometbft_dot_abci_dot_v1beta3_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cometbft/rpc/grpc/v1beta3/types.proto\x12\x19\x63ometbft.rpc.grpc.v1beta3\x1a%cometbft/rpc/grpc/v1beta1/types.proto\x1a!cometbft/abci/v1beta3/types.proto\"\x9a\x01\n\x13ResponseBroadcastTx\x12\x41\n\x08\x63heck_tx\x18\x01 \x01(\x0b\x32&.cometbft.abci.v1beta3.ResponseCheckTxR\x07\x63heckTx\x12@\n\ttx_result\x18\x02 \x01(\x0b\x32#.cometbft.abci.v1beta3.ExecTxResultR\x08txResult2\xd5\x01\n\x0c\x42roadcastAPI\x12W\n\x04Ping\x12&.cometbft.rpc.grpc.v1beta1.RequestPing\x1a\'.cometbft.rpc.grpc.v1beta1.ResponsePing\x12l\n\x0b\x42roadcastTx\x12-.cometbft.rpc.grpc.v1beta1.RequestBroadcastTx\x1a..cometbft.rpc.grpc.v1beta3.ResponseBroadcastTxB\xee\x01\n\x1d\x63om.cometbft.rpc.grpc.v1beta3B\nTypesProtoP\x01Z:github.com/cometbft/cometbft/api/cometbft/rpc/grpc/v1beta3\xa2\x02\x03\x43RG\xaa\x02\x19\x43ometbft.Rpc.Grpc.V1beta3\xca\x02\x19\x43ometbft\\Rpc\\Grpc\\V1beta3\xe2\x02%Cometbft\\Rpc\\Grpc\\V1beta3\\GPBMetadata\xea\x02\x1c\x43ometbft::Rpc::Grpc::V1beta3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.rpc.grpc.v1beta3.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.cometbft.rpc.grpc.v1beta3B\nTypesProtoP\001Z:github.com/cometbft/cometbft/api/cometbft/rpc/grpc/v1beta3\242\002\003CRG\252\002\031Cometbft.Rpc.Grpc.V1beta3\312\002\031Cometbft\\Rpc\\Grpc\\V1beta3\342\002%Cometbft\\Rpc\\Grpc\\V1beta3\\GPBMetadata\352\002\034Cometbft::Rpc::Grpc::V1beta3'
  _globals['_RESPONSEBROADCASTTX']._serialized_start=143
  _globals['_RESPONSEBROADCASTTX']._serialized_end=297
  _globals['_BROADCASTAPI']._serialized_start=300
  _globals['_BROADCASTAPI']._serialized_end=513
# @@protoc_insertion_point(module_scope)
